CREATE TABLE complex_field  (
                                ID decimal(20, 0) NOT NULL,
                                FORM_ID decimal(20, 0) NULL DEFAULT NULL,
                                TITLE varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                `DESCRIBE` varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                COMPONENT_KEY varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                REQUIRED char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                IS_DELETE char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                `OPERATOR` decimal(20, 0) NULL DEFAULT NULL,
                                CREATE_TIME datetime NULL DEFAULT NULL,
                                show_order double NULL DEFAULT 0,
                                other_properties text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                                layout_component_id varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                PRIMARY KEY (ID) USING BTREE,
                                INDEX IDX_COMPLEX_FIELD_FORM_ID(FORM_ID) USING BTREE
)
;

CREATE TABLE fd_effect  (
                            id bigint(20) NOT NULL COMMENT 'ID',
                            create_time datetime NULL DEFAULT NULL COMMENT '创建时间',
                            update_time datetime NULL DEFAULT NULL COMMENT '修改时间',
                            creator bigint(20) NULL DEFAULT NULL COMMENT '创建人id',
                            delete_type int(11) NULL DEFAULT 0 COMMENT '是否删除',
                            ref_id varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '引用id',
                            form_id bigint(20) NULL DEFAULT NULL COMMENT '表单id',
                            effect_type varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '维度类型',
                            effect_name varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '维度名称',
                            effect_module varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '模块',
                            tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户KEY',
                            PRIMARY KEY (id) USING BTREE,
                            INDEX IDX_FD_EFFECT_TENANT_KEY(tenant_key) USING BTREE,
                            INDEX IDX_FD_EFFECT_REF_ID(ref_id) USING BTREE,
                            INDEX IDX_FD_EFFECT_FORM_ID(form_id) USING BTREE
)
;

CREATE TABLE fd_effect_value  (
                                  id bigint(20) NOT NULL COMMENT 'ID',
                                  effect_id bigint(20) NULL DEFAULT NULL COMMENT '上一级id',
                                  effect_value varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '维度条件内容',
                                  effect_name varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '维度显示名称',
                                  tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                  PRIMARY KEY (id) USING BTREE,
                                  INDEX IDX_FD_EFFECT_VALUE_TENANT_KEY(tenant_key) USING BTREE,
                                  INDEX IDX_FD_EFFECT_VALUE_EFFECT_ID(effect_id) USING BTREE,
                                  INDEX IDX_FD_EFFECT_VALUE_EV(effect_value) USING BTREE
)
;

CREATE TABLE fd_linkage  (
                             id bigint(20) NOT NULL COMMENT 'ID',
                             linkage_name varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '名称',
                             linkage_module varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '所属模块',
                             form_id bigint(20) NULL DEFAULT 0 COMMENT '表单id',
                             ref_id bigint(20) NULL DEFAULT 0 COMMENT '引用id',
                             linkage_state int(1) NULL DEFAULT NULL COMMENT '状态，开关',
                             linkage_type varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据联动类型，模型、SQL',
                             creator bigint(20) NULL DEFAULT NULL COMMENT '创建人',
                             create_time datetime NULL DEFAULT NULL COMMENT '创建时间',
                             update_time datetime NULL DEFAULT NULL COMMENT '更新时间',
                             tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户Key',
                             PRIMARY KEY (id) USING BTREE,
                             INDEX IDX_FD_LINKAGE_TENANT_KEY(tenant_key) USING BTREE,
                             INDEX IDX_FD_LINKAGE_FORM_ID(form_id) USING BTREE,
                             INDEX IDX_FD_LINKAGE_REF_ID(ref_id) USING BTREE
)
;

CREATE TABLE fd_linkage_ext  (
                                 id bigint(20) NOT NULL COMMENT 'ID',
                                 entity_id bigint(20) NULL DEFAULT NULL COMMENT '关联field_linkage表id',
                                 sub_form_like_type varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '明细表联动类型，添加、更新',
                                 sub_form_add_type varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '明细表添加类型，覆盖、追加',
                                 effect_content text CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '生效维度json',
                                 tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户Key',
                                 PRIMARY KEY (id) USING BTREE,
                                 INDEX IDX_FD_LINKAGE_EXT_TK(tenant_key) USING BTREE,
                                 INDEX IDX_FD_LINKAGE_EXT_EI(entity_id) USING BTREE
)
;

CREATE TABLE fd_linkage_monitor_action  (
                                            id bigint(20) NOT NULL COMMENT 'ID',
                                            entity_id bigint(20) NULL DEFAULT NULL COMMENT '关联field_linkage表id',
                                            action_type varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '触发动作类型',
                                            action_name varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '触发动作名称',
                                            tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                            PRIMARY KEY (id) USING BTREE,
                                            INDEX IDX_FD_LA_MONITOR_ACTION_TK(tenant_key) USING BTREE,
                                            INDEX IDX_FD_LA_MONITOR_ACTION_EI(entity_id) USING BTREE
)
;

CREATE TABLE fd_linkage_monitor_field  (
                                           id bigint(20) NOT NULL COMMENT 'ID',
                                           entity_id bigint(20) NULL DEFAULT NULL COMMENT '关联field_linkage_monitor_action表id',
                                           target_field varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '关联字段id',
                                           target_name varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '关联字段名称',
                                           tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                           PRIMARY KEY (id) USING BTREE,
                                           INDEX IDX_FD_LA_MONITOR_FIELD_TK(tenant_key) USING BTREE,
                                           INDEX IDX_FD_LA_MONITOR_FIELD_EI(entity_id) USING BTREE
)
;

CREATE TABLE fd_linkage_source  (
                                    id bigint(20) NOT NULL COMMENT 'ID',
                                    entity_id bigint(20) NULL DEFAULT NULL COMMENT '关联field_linkage表id',
                                    linkage_type varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '冗余的数据联动类型，模型、SQL',
                                    data_source_id bigint(20) NULL DEFAULT NULL COMMENT '关联数据源',
                                    data_source_name varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '关联数据源名称',
                                    data_source_db_type varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '关联数据库类型',
                                    data_type varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据库类型',
                                    tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                    PRIMARY KEY (id) USING BTREE,
                                    INDEX IDX_FD_LINKAGE_SOURCE_TK(tenant_key) USING BTREE,
                                    INDEX IDX_FD_LINKAGE_SOURCE_EI(entity_id) USING BTREE
)
;

CREATE TABLE fd_linkage_source_config  (
                                           id bigint(20) NOT NULL COMMENT 'ID',
                                           entity_id bigint(20) NULL DEFAULT NULL COMMENT '联动数据源获取数据Id',
                                           where_condition text CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '筛选条件',
                                           order_condition text CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '排序语句',
                                           tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                           PRIMARY KEY (id) USING BTREE,
                                           INDEX IDX_FD_LA_SOURCE_CONFIG_TK(tenant_key) USING BTREE,
                                           INDEX IDX_FD_LA_SOURCE_CONFIG_EI(entity_id) USING BTREE
)
;

CREATE TABLE fd_linkage_source_config_col  (
                                               id bigint(20) NOT NULL COMMENT 'ID',
                                               entity_id bigint(20) NULL DEFAULT NULL COMMENT '上层关系id',
                                               column_table varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据列所在表',
                                               column_type varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据列的数据类型',
                                               column_field varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据库字段',
                                               column_title varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据库名称',
                                               operate varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '操作符，等于、等于、小于',
                                               source_type varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '类型，常量、变量',
                                               source_field varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据来源变量id',
                                               source_name varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据来源变量名称',
                                               source_content text CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '常量时内容',
                                               tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                               PRIMARY KEY (id) USING BTREE,
                                               INDEX IDX_FD_LA_SOURCE_CONFIG_COL_TK(tenant_key) USING BTREE,
                                               INDEX IDX_FD_LA_SOURCE_CONFIG_COL_EI(entity_id) USING BTREE
)
;

CREATE TABLE fd_linkage_source_config_table  (
                                                 id bigint(20) NOT NULL COMMENT 'ID',
                                                 entity_id bigint(20) NULL DEFAULT NULL COMMENT 'form_data_linkage_template关联id',
                                                 source_field varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据源table的id',
                                                 source_name varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据来源的表名称',
                                                 table_title varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据库表名称',
                                                 table_nick_name varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据库表别名',
                                                 join_type varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '表关联类型',
                                                 join_condition text CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '表关联条件',
                                                 tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                                 PRIMARY KEY (id) USING BTREE,
                                                 INDEX IDX_FD_LA_SE_CONFIG_TABLE_TK(tenant_key) USING BTREE,
                                                 INDEX IDX_FD_LA_SE_CONFIG_TABLE_EI(entity_id) USING BTREE
)
;

CREATE TABLE fd_linkage_source_excel  (
                                          id bigint(20) NOT NULL COMMENT 'ID',
                                          entity_id bigint(20) NULL DEFAULT NULL COMMENT '关联上表id',
                                          excel_id bigint(20) NULL DEFAULT NULL COMMENT '函数公式id',
                                          excel_name varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '函数公式名称',
                                          tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                          PRIMARY KEY (id) USING BTREE,
                                          INDEX IDX_FD_LA_SOURCE_EXCEL_TK(tenant_key) USING BTREE,
                                          INDEX IDX_FD_LA_SOURCE_EXCEL_EI(entity_id) USING BTREE
)
;

CREATE TABLE fd_linkage_source_mapping  (
                                            id bigint(20) NOT NULL COMMENT 'ID',
                                            entity_id bigint(20) NULL DEFAULT NULL COMMENT '关联field_linkage_resource_draw表id',
                                            source_field varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '关联数据源字段id',
                                            source_name varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '关联数据源字段名称',
                                            handle_mark varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '赋值符号',
                                            target_field varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '对应表单字段id',
                                            target_name varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '对应表单字段名称',
                                            target_type varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '对应字段类型，系统、自定义字段',
                                            target_address varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '目标字段名称',
                                            target_address_type varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '目标字段类型',
                                            tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                            PRIMARY KEY (id) USING BTREE,
                                            INDEX IDX_FD_LA_SOURCE_MAPPING_TK(tenant_key) USING BTREE,
                                            INDEX IDX_FD_LA_SOURCE_MAPPING_EI(entity_id) USING BTREE
)
;

CREATE TABLE fd_linkage_source_sql  (
                                        id bigint(20) NOT NULL COMMENT 'ID',
                                        entity_id bigint(20) NULL DEFAULT NULL COMMENT '联动数据源获取数据Id',
                                        sql_context text CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '完整富文本',
                                        sql_script text CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '执行时sql模板',
                                        tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                        PRIMARY KEY (id) USING BTREE,
                                        INDEX IDX_FD_LINKAGE_SOURCE_SQL_TK(tenant_key) USING BTREE,
                                        INDEX IDX_FD_LINKAGE_SOURCE_SQL_EI(entity_id) USING BTREE
)
;

CREATE TABLE fd_linkage_source_sql_column  (
                                               id bigint(20) NOT NULL COMMENT 'ID',
                                               entity_id bigint(20) NULL DEFAULT NULL COMMENT 'form_data_linkage_sql关联id',
                                               source_field varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT 'form_data_linkage_data_source关联id',
                                               source_name varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据来源名称',
                                               tenant_key varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                               PRIMARY KEY (id) USING BTREE,
                                               INDEX IDX_FD_LA_SOURCE_SQL_COLUMN_TK(tenant_key) USING BTREE,
                                               INDEX IDX_FD_LA_SOURCE_SQL_COLUMN_EI(entity_id) USING BTREE
)
;

CREATE TABLE field_layout  (
                               ID decimal(20, 0) NOT NULL,
                               PARENT_ID decimal(20, 0) NULL DEFAULT NULL,
                               FIELD_ID decimal(20, 0) NULL DEFAULT NULL,
                               FIELD_TYPE varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               LAYOUT_ID decimal(20, 0) NULL DEFAULT NULL,
                               LAYOUT_DETAIL longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                               TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               `OPERATOR` decimal(20, 0) NULL DEFAULT NULL,
                               CREATE_TIME datetime NULL DEFAULT NULL,
                               UPDATE_TIME datetime NULL DEFAULT NULL,
                               STATUS char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '字段状态：0-最新版本，1-历史版本',
                               PRIMARY KEY (ID) USING BTREE,
                               INDEX IDX_FIELD_LAYOUT_FIELD_ID(FIELD_ID) USING BTREE,
                               INDEX IDX_FIELD_LAYOUT_LAYOUT_ID(LAYOUT_ID) USING BTREE,
                               INDEX IDX_FIELD_LAYOUT_FIELD_TYPE(FIELD_TYPE) USING BTREE,
                               INDEX IDX_FIELD_LAYOUT_UPDATE_TIME(UPDATE_TIME) USING BTREE
)
;

CREATE TABLE field_option  (
                               ID decimal(20, 0) NOT NULL,
                               FIELD_ID decimal(20, 0) NULL DEFAULT NULL,
                               PARENT_ID decimal(20, 0) NULL DEFAULT NULL,
                               NAME varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               `ORDER` decimal(5, 0) NULL DEFAULT NULL,
                               OTHER char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               IS_DELETE char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               `OPERATOR` decimal(20, 0) NULL DEFAULT NULL,
                               CREATE_TIME datetime NULL DEFAULT NULL,
                               TMP_OPTION varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               UID varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               style_config longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '选项设置',
                               extra mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                               archive tinyint(4) NOT NULL DEFAULT 0,
                               PRIMARY KEY (ID) USING BTREE,
                               INDEX IDX_FIELD_OPTION_FIELD_ID(FIELD_ID) USING BTREE,
                               INDEX IDX_FIELD_OPTION_PARENT_ID(PARENT_ID) USING BTREE
)
;

CREATE TABLE field_permission  (
                                   ID decimal(20, 0) NOT NULL COMMENT '主键ID',
                                   FORM_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '表单ID',
                                   TENANT_KEY varchar(20) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                   MODULE varchar(50) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NULL DEFAULT NULL COMMENT '所属模块',
                                   CREATOR decimal(20, 0) NULL DEFAULT NULL COMMENT '创建人',
                                   CREATE_TIME datetime NULL DEFAULT NULL COMMENT '创建时间',
                                   UPDATE_TIME datetime NULL DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                                   IS_DELETE varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '是否删除(0-未删除,1-已删除)',
                                   datasrc int(11) NULL DEFAULT NULL COMMENT '是否迁移数据',
                                   PRIMARY KEY (ID) USING BTREE,
                                   INDEX IDX_FIELD_PERMISSION_FORM_ID(FORM_ID) USING BTREE
)
;

CREATE TABLE field_permission_detail  (
                                          ID decimal(20, 0) NOT NULL COMMENT '主键ID',
                                          FIELD_ID decimal(20, 0) NOT NULL COMMENT '表单字段ID',
                                          FIELD_READ varchar(1) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '字段读权限（查看）',
                                          FIELD_WRITE varchar(1) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '字段写权限（填写）',
                                          IS_DELETE varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '是否删除(0-未删除,1-已删除)',
                                          PERMISSION_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '字段权限ID',
                                          datasrc int(11) NULL DEFAULT NULL COMMENT '是否迁移数据',
                                          TENANT_KEY varchar(20) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                          required varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                          disable_edit varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                          PRIMARY KEY (ID) USING BTREE,
                                          INDEX IDX_FIELD_PERMISSION_DETAIL_FD(FIELD_ID) USING BTREE,
                                          INDEX IDX_FIELD_PERMISSION_DETAIL_PD(PERMISSION_ID) USING BTREE
)
;

CREATE TABLE form  (
                       ID decimal(20, 0) NOT NULL,
                       NAME varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                       `DESCRIBE` varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                       STATUS varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                       SOURCE_ID decimal(20, 0) NULL DEFAULT NULL,
                       OWNERSHIP varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                       TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                       `OPERATOR` decimal(20, 0) NULL DEFAULT NULL,
                       CREATE_TIME datetime NULL DEFAULT NULL,
                       UPDATE_TIME datetime NULL DEFAULT NULL,
                       IS_DELETE char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                       CATEGORY_ID decimal(20, 0) NULL DEFAULT NULL,
                       ICON varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                       TMP_TABLE decimal(20, 0) NULL DEFAULT NULL,
                       TMP_LAYOUT decimal(20, 0) NULL DEFAULT NULL,
                       SORT decimal(5, 0) NULL DEFAULT NULL,
                       RECOMMEND char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                       BIAOGE_RECOMMEND char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                       MODULE varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                       RELATEFLOW char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                       REVIEW_COUNT decimal(10, 0) NULL DEFAULT NULL,
                       EXPORT_COUNT decimal(10, 0) NULL DEFAULT NULL,
                       COPY_COUNT decimal(10, 0) NULL DEFAULT NULL,
                       VIEW_COUNT decimal(10, 0) NULL DEFAULT NULL,
                       FILL_COUNT decimal(10, 0) NULL DEFAULT NULL,
                       DELETE_USER decimal(20, 0) NULL DEFAULT NULL,
                       REPORT decimal(20, 0) NULL DEFAULT NULL,
                       collect_status varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT 'disable',
                       TARGET_ID decimal(20, 0) NULL DEFAULT NULL,
                       DFAPTION int(1) NULL DEFAULT NULL,
                       IS_ADVANCE tinyint(4) NULL DEFAULT 0,
                       inherit char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '0' COMMENT '字段权限继承',
                       IS_MULTI char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '是否为多布局表单：0-否，1-是',
                       ATTR_NAME varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                       PHYSICAL_TABLE tinyint(1) NOT NULL DEFAULT 0 COMMENT '是否是物理表 0 不是 1是',
                       org_id bigint(20) NULL DEFAULT NULL,
                       PRIMARY KEY (ID) USING BTREE,
                       INDEX IDX_FORM_TENANTKEY(TENANT_KEY) USING BTREE,
                       INDEX IDX_FORM_CATEGORY(CATEGORY_ID) USING BTREE,
                       INDEX IDX_FORM_OPERATOR(OPERATOR) USING BTREE,
                       INDEX IDX_FORM_OWNERSHIP(OWNERSHIP) USING BTREE,
                       INDEX IDX_FORM_MODULE(MODULE) USING BTREE,
                       INDEX IDX_FORM_TARGET_ID(TARGET_ID) USING BTREE,
                       INDEX IDX_FORM_SORT(SORT) USING BTREE,
                       INDEX IDX_FORM_CREATE_TIME(CREATE_TIME) USING BTREE,
                       INDEX IDX_FORM_STATUS(STATUS) USING BTREE,
                       INDEX IDX_FORM_REPORT(REPORT) USING BTREE,
                       INDEX IDX_FORM_BIAOGE_RECOMMEND(BIAOGE_RECOMMEND) USING BTREE,
                       INDEX IDX_FORM_ORG_ID(ORG_ID) USING BTREE
)
;

CREATE TABLE form_attachment_config  (
                                         id bigint(20) NOT NULL COMMENT 'ID',
                                         create_time datetime NULL DEFAULT NULL COMMENT '创建时间',
                                         update_time datetime NULL DEFAULT NULL COMMENT '修改时间',
                                         creator bigint(20) NULL DEFAULT NULL COMMENT '创建人id',
                                         delete_type int(11) NULL DEFAULT 0 COMMENT '是否删除',
                                         tenant_key varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户KEY',
                                         ref_id bigint(20) NULL DEFAULT NULL COMMENT '关联id(表单默认用formid，审批用wfid)',
                                         folder_select_type int(11) NULL DEFAULT 0 COMMENT '附件上传目录0：固定目录 1选择目录',
                                         folder_id bigint(20) NULL DEFAULT NULL COMMENT '附件上传目录id 固定目录为目录id',
                                         custom_limit_format varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '自定义的文件扩展名limit_upload_format = 6时多个请用逗号隔开，如: txt, pdf, mp3等',
                                         attment_size_limit int(11) NULL DEFAULT 3 COMMENT '附件大小限制下拉框 0 1MB,1 5MB,2 10MB,3 20MB ,4 50MB,5 100MB, 6 自定义',
                                         custom_attment_size varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '自定义附件大小',
                                         forbin_batch_download int(11) NULL DEFAULT 0 COMMENT '禁止附件批量下载0 关闭，1 开启',
                                         sec_level int(11) NULL DEFAULT 1 COMMENT '密级   显示格式 默认开启 无法关闭',
                                         show_format int(11) NULL DEFAULT 0 COMMENT '密级下拉框 0 密级和保密期限 1仅密级',
                                         attach_upload_user int(1) NULL DEFAULT NULL COMMENT '附件上传人 0关闭 1开启',
                                         attach_upload_time int(1) NULL DEFAULT NULL COMMENT '附件上传时间  0关闭 1开启',
                                         config_type int(11) NULL DEFAULT NULL COMMENT '设置类型 0 通用 1自定义',
                                         form_id bigint(20) NULL DEFAULT NULL COMMENT '关联表单ID',
                                         field_id bigint(20) NULL DEFAULT NULL COMMENT '关联字段id',
                                         folder_type int(11) NULL DEFAULT 0 COMMENT '上传目录设置下拉框0 通用，1 自定义',
                                         limit_type int(11) NULL DEFAULT 0 COMMENT '限制格式设置 0 通用，1 自定义',
                                         other_type int(11) NULL DEFAULT 0 COMMENT '其他设置 0 通用，1 自定义',
                                         option_id bigint(20) NULL DEFAULT NULL COMMENT '选择目录存字段id',
                                         PRIMARY KEY (id) USING BTREE,
                                         INDEX IDX_FORM_ATTACHMENT_CONFIG_TK(tenant_key) USING BTREE,
                                         INDEX IDX_FORM_ATTACHMENT_CONFIG_FMI(form_id) USING BTREE,
                                         INDEX IDX_FORM_ATTACHMENT_CONFIG_FDI(field_id) USING BTREE
)
;

CREATE TABLE form_category  (
                                ID decimal(20, 0) NOT NULL,
                                NAME varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                SORT decimal(5, 0) NULL DEFAULT NULL,
                                TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                `OPERATOR` decimal(20, 0) NULL DEFAULT NULL,
                                CREATE_TIME datetime NULL DEFAULT NULL,
                                type varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                module varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                PRIMARY KEY (ID) USING BTREE,
                                INDEX IDX_FORM_CATEGORY_TENANT_KEY(TENANT_KEY) USING BTREE
)
;

CREATE TABLE form_data_details_encdata  (
                                            id bigint(20) NOT NULL COMMENT 'ID',
                                            tenant_key varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '租户KEY',
                                            table_name varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '数据原表名',
                                            field_name varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '数据原字段名',
                                            enc_value varchar(4000) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '加密值',
                                            crc varchar(4000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '签名值',
                                            creater bigint(20) NULL DEFAULT NULL COMMENT '创建人',
                                            created datetime NULL DEFAULT NULL COMMENT '创建时间',
                                            modifier bigint(20) NULL DEFAULT NULL COMMENT '修改人',
                                            modified datetime NULL DEFAULT NULL COMMENT '修改时间',
                                            skey varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '数据秘钥（已加密）',
                                            PRIMARY KEY (id) USING BTREE,
                                            INDEX IDX_FD_DETAILS_ENCDATA_TK(tenant_key) USING BTREE,
                                            INDEX IDX_FD_DETAILS_ENCDATA_TN(table_name) USING BTREE,
                                            INDEX IDX_FD_DETAILS_ENCDATA_FN(field_name) USING BTREE
)
;

CREATE TABLE form_data_layout_rel  (
                                       ID decimal(20, 0) NOT NULL,
                                       FORM_DATA decimal(20, 0) NULL DEFAULT NULL COMMENT '表单数据Id',
                                       MULTIPLE_LAYOUT_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '多布局Id',
                                       VERSION_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '布局版本Id',
                                       TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户Key',
                                       PRIMARY KEY (ID) USING BTREE,
                                       INDEX IDX_FORM_DATA_LAYOUT_REL_FD(FORM_DATA) USING BTREE,
                                       INDEX IDX_FORM_DATA_LAYOUT_REL_MLI(MULTIPLE_LAYOUT_ID) USING BTREE,
                                       INDEX IDX_FORM_DATA_LAYOUT_REL_VI(VERSION_ID) USING BTREE
)
;

CREATE TABLE form_data_relate_config  (
                                          ID decimal(20, 0) NOT NULL COMMENT '主键ID',
                                          FIELD_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '表单字段ID',
                                          EXPRESS_ID bigint(20) NULL DEFAULT NULL COMMENT 'Excel函数公式ID',
                                          MONITOR_FIELDS mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '普通公式',
                                          RELATE_FIELD mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '数据钻取',
                                          RELATE_DATATABLE mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '明细表钻取',
                                          RELATE_MULTIPLE varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '钻取多选',
                                          VERSION_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '表单布局版本ID',
                                          `OPERATOR` decimal(20, 0) NULL DEFAULT NULL COMMENT '创建人',
                                          TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户Key',
                                          CREATE_TIME datetime NULL DEFAULT NULL COMMENT '创建时间',
                                          UPDATE_TIME datetime NULL DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                                          IS_DELETE int(11) NULL DEFAULT NULL,
                                          PRIMARY KEY (ID) USING BTREE,
                                          INDEX IDX_FDRC_TENANT_KEY(TENANT_KEY) USING BTREE,
                                          INDEX IDX_FDRC_FIELD_ID(FIELD_ID) USING BTREE,
                                          INDEX IDX_FDRC_VERSION_ID(VERSION_ID) USING BTREE
)
;


CREATE TABLE form_field  (
                             ID decimal(20, 0) NOT NULL,
                             FORM_ID decimal(20, 0) NULL DEFAULT NULL,
                             SUB_FORM_ID decimal(20, 0) NULL DEFAULT NULL,
                             TITLE varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             `DESCRIBE` varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             DATA_TYPE varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             REQUIRED char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             IS_DELETE char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             `OPERATOR` decimal(20, 0) NULL DEFAULT NULL,
                             CREATE_TIME datetime NULL DEFAULT NULL,
                             COMPONENT_KEY varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             TMP_FIELD varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             COMPLEX_ID decimal(20, 0) NULL DEFAULT NULL,
                             UPDATE_TIME datetime(3) NULL DEFAULT NULL,
                             SOURCE_MODULE varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             DATA_TEMPLATE_ID decimal(20, 0) NULL DEFAULT NULL,
                             EXPRESS_ID bigint(20) NULL DEFAULT NULL COMMENT 'Excel函数公式ID',
                             ATTR_NAME varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             show_order double NULL DEFAULT 0,
                             group_id decimal(20, 0) NULL DEFAULT NULL,
                             other_properties text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                             single tinyint(4) NULL DEFAULT 1 COMMENT '0单选1多选',
                             data_key varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             layout_component_id varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             default_order smallint(6) NULL DEFAULT NULL,
                             custom_order smallint(6) NULL DEFAULT NULL,
                             archive tinyint(1) NULL DEFAULT NULL,
                             browser_module varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             browser_type varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             parent_id decimal(20, 0) NULL DEFAULT NULL,
                             PRIMARY KEY (ID) USING BTREE,
                             INDEX IDX_FORM_FIELD_FORM_ID(FORM_ID) USING BTREE,
                             INDEX IDX_FORM_FIELD_COMPONENT_KEY(COMPONENT_KEY) USING BTREE,
                             INDEX IDX_FORM_FIELD_UPDATE_TIME(UPDATE_TIME) USING BTREE,
                             INDEX IDX_FORM_FIELD_COMPLEX_FIELD(COMPLEX_ID) USING BTREE,
                             INDEX IDX_FORM_FIELD_SUB_FORM_ID(SUB_FORM_ID) USING BTREE,
                             INDEX IDX_FORM_FIELD_DATA_TEMPLATE_I(DATA_TEMPLATE_ID) USING BTREE,
                             INDEX IDX_FORM_FIELD_EXPRESS_ID(EXPRESS_ID) USING BTREE,
                             INDEX IDX_FORM_FIELD_BM_BT_TK(browser_module, browser_type, TENANT_KEY) USING BTREE,
                             INDEX IDX_FORM_FIELD_DK_TK(data_key, TENANT_KEY) USING BTREE
)
;

CREATE TABLE form_field_group  (
                                   id decimal(20, 0) NOT NULL COMMENT 'ID',
                                   group_name varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '分组名称',
                                   icon varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分组图标',
                                   `OPERATOR` decimal(20, 0) NOT NULL COMMENT '创建人id',
                                   is_delete tinyint(4) NULL DEFAULT NULL COMMENT '是否删除',
                                   tenant_key varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户KEY',
                                   create_time datetime NOT NULL COMMENT '创建时间',
                                   update_time datetime NULL DEFAULT NULL COMMENT '更新时间',
                                   form_id decimal(20, 0) NOT NULL,
                                   show_order double NULL DEFAULT 0,
                                   PRIMARY KEY (id) USING BTREE,
                                   INDEX IDX_FORM_FIELD_GROUP_TK(tenant_key) USING BTREE,
                                   INDEX IDX_FORM_FIELD_GROUP_NAME(group_name) USING BTREE,
                                   INDEX IDX_FORM_FIELD_GROUP_FI_TK(form_id, tenant_key) USING BTREE
)
;

CREATE TABLE form_field_language  (
                                      ID decimal(20, 0) NOT NULL COMMENT '主键ID',
                                      FORM_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '表单ID',
                                      FIELD_ID decimal(20, 0) NOT NULL COMMENT '表单字段ID',
                                      COMPONENT_KEY varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '控件Key',
                                      LANGUAGE_DETAIL longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '多语言设置明细',
                                      IS_DELETE char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '国际化信息是否删除：0-否 1-是',
                                      CREATE_TIME datetime NULL DEFAULT NULL COMMENT '创建时间',
                                      UPDATE_TIME datetime NULL DEFAULT NULL COMMENT '更新时间',
                                      TENANT_KEY varchar(20) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NULL DEFAULT NULL COMMENT '租户key',
                                      PRIMARY KEY (ID) USING BTREE,
                                      INDEX IDX_FORM_FIELD_LANGUAGE_FORM_I(FORM_ID) USING BTREE,
                                      INDEX IDX_FORM_FIELD_LANGUAGE_FIELD_I(FIELD_ID) USING BTREE
)
;

CREATE TABLE form_fieldmanagelogs  (
                                       id bigint(20) NOT NULL COMMENT 'ID',
                                       uuid varchar(36) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '日志UUID',
                                       log_date datetime NULL DEFAULT NULL,
                                       device varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '终端信息',
                                       log_OPERATOR bigint(20) NULL DEFAULT NULL,
                                       operatorname varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '操作人姓名',
                                       tenant_key varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '租户id',
                                       targetid bigint(20) NOT NULL DEFAULT -1 COMMENT '操作目标id',
                                       targetname text CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '操作目标名称',
                                       modulename varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '模块',
                                       functionname varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '服务（方法）',
                                       interfacename varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '访问接口名',
                                       requesturl varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '请求全路径',
                                       requesturi varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '请求地址',
                                       operatetype varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '操作类型',
                                       operatetypename varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '操作类型名称',
                                       operatedesc varchar(3000) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '操作详细说明',
                                       params longtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '涉及的相关参数',
                                       belongmainid varchar(36) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '所属主表uuid',
                                       clientip varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '操作IP',
                                       groupid varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '分组',
                                       groupnamelabel varchar(1000) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '分组标题',
                                       redoservice varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '重做业务接口',
                                       redocontext longtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '重做参数',
                                       cancelservice varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '撤销业务接口',
                                       cancelcontext longtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '撤销参数',
                                       create_time datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                       update_time datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '修改时间',
                                       creator bigint(20) NOT NULL DEFAULT -1 COMMENT '创建人id',
                                       delete_type int(11) NOT NULL DEFAULT 0 COMMENT '是否删除',
                                       totalruntime bigint(20) NOT NULL DEFAULT 0 COMMENT '总运行时长',
                                       mainruntime bigint(20) NOT NULL DEFAULT 0 COMMENT '主方法运行时长',
                                       log_result varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                       fromterminal varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '来自pc web',
                                       resultdesc text CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '运行结果描述',
                                       old_content varchar(3000) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '原先内容',
                                       link_type varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '链接类型',
                                       link_id bigint(20) NOT NULL DEFAULT 0 COMMENT '链接id',
                                       old_link_id bigint(20) NOT NULL DEFAULT 0 COMMENT '原先链接id',
                                       PRIMARY KEY (id) USING BTREE,
                                       INDEX IDX_FORM_FIELDMANAGELOGS_TK(tenant_key) USING BTREE,
                                       INDEX IDX_FORM_FIELDMANAGELOGS_TI(targetid) USING BTREE,
                                       INDEX IDX_FORM_FIELDMANAGELOGS_MN(modulename) USING BTREE,
                                       INDEX IDX_FORM_FIELDMANAGELOGS_FN(functionname) USING BTREE,
                                       INDEX IDX_FORM_FIELDMANAGE_LOGS_LD(log_date) USING BTREE,
                                       INDEX IDX_FORM_FIELDMANAGELOGS_U(uuid) USING BTREE
)
;

CREATE TABLE form_fieldmanagelogs_detail  (
                                              id bigint(20) NOT NULL COMMENT 'ID',
                                              uuid varchar(36) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '日志UUID',
                                              mainid varchar(36) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '主表id',
                                              dataid varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '数据id',
                                              belongdataid varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '主表数据id',
                                              tablename varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '表名',
                                              tablenamelabelid varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '-1' COMMENT '表名labelid',
                                              tablenamedesc varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '对应数据库的表',
                                              fieldname varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '字段名',
                                              fieldnamelabelid varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '-1' COMMENT '字段名labelid',
                                              newvalue longtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '更新后的值',
                                              oldvalue longtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '更新前的值',
                                              newrealvalue longtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '更新后的显示值',
                                              oldrealvalue longtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '更新前的显示值',
                                              fielddesc varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '字段名',
                                              showorder int(11) NOT NULL COMMENT '字段名',
                                              create_time datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                              update_time datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '修改时间',
                                              creator bigint(20) NOT NULL DEFAULT -1 COMMENT '创建人id',
                                              delete_type int(11) NOT NULL DEFAULT 0 COMMENT '是否删除',
                                              tenant_key varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '租户id',
                                              isdetail int(11) NOT NULL DEFAULT 0 COMMENT '是否明细字段',
                                              PRIMARY KEY (id) USING BTREE,
                                              INDEX IDX_F_FIELDMANAGELOGS_U_MI(uuid, mainid) USING BTREE,
                                              INDEX IDX_F_FIELDMANAGELOGS_U(uuid) USING BTREE,
                                              INDEX IDX_F_FIELDMANAGELOGS_TK(tenant_key) USING BTREE,
                                              INDEX IDX_F_FMANAGELOGS_DETAIL_MI(mainid) USING BTREE
)
;

CREATE TABLE form_layout_multiple  (
                                       ID decimal(20, 0) NOT NULL COMMENT '布局ID',
                                       NAME varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '布局名称',
                                       `DESCRIBE` varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '布局描述',
                                       FORM_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '表单ID',
                                       TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户Key',
                                       `OPERATOR` decimal(20, 0) NULL DEFAULT NULL COMMENT '创建人',
                                       CREATE_TIME datetime NULL DEFAULT NULL COMMENT '创建时间',
                                       UPDATE_TIME datetime NULL DEFAULT NULL COMMENT '更新时间',
                                       IS_DEFAULT char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '是否为默认布局(0-否, 1-是)',
                                       IS_DELETE char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '是否为删除(0-未删除, 1-回收站, 2-彻底删除)',
                                       VERSION_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '最新版本布局ID',
                                       LAYOUT_TYPE varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                       TERMINAL_TYPE varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                       PRIMARY KEY (ID) USING BTREE,
                                       INDEX IDX_FORM_LAYOUT_MULTIPLE_FORM_ID(FORM_ID) USING BTREE,
                                       INDEX IDX_FORM_LAYOUT_MULTIPLE_VI(VERSION_ID) USING BTREE
)
;

CREATE TABLE form_layout_style  (
                                    ID decimal(20, 0) NOT NULL,
                                    FORM_ID decimal(20, 0) NULL DEFAULT NULL,
                                    LAYOUT_TYPE varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                    COLOR_SCHEME varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                    LAYOUT_DETAIL longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                                    TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                    `OPERATOR` decimal(20, 0) NULL DEFAULT NULL,
                                    CREATE_TIME datetime NULL DEFAULT NULL,
                                    UPDATE_TIME datetime NULL DEFAULT NULL,
                                    LAYOUT_HTML longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                                    LAYOUT_STYLE text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                                    MOBILE_INDEXS text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                                    PRIMARY KEY (ID) USING BTREE,
                                    INDEX IDX_FORM_LAYOUT_STYLE_FORM_ID(FORM_ID) USING BTREE,
                                    INDEX IDX_FORM_LAYOUT_STYLE_TK(TENANT_KEY) USING BTREE
)
;

CREATE TABLE form_layout_version  (
                                      ID decimal(20, 0) NOT NULL COMMENT '布局版本ID',
                                      NAME varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '布局名称',
                                      `DESCRIBE` varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '布局描述',
                                      FORM_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '表单ID',
                                      LAYOUT_TYPE varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '布局类型',
                                      COLOR_SCHEME varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '配色方案',
                                      LAYOUT_DETAIL longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '布局明细',
                                      TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户Key',
                                      `OPERATOR` decimal(20, 0) NULL DEFAULT NULL COMMENT '创建人',
                                      CREATE_TIME datetime NULL DEFAULT NULL COMMENT '创建时间',
                                      UPDATE_TIME datetime NULL DEFAULT NULL COMMENT '更新时间',
                                      LAYOUT_HTML longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '高级表单-布局HTML明细',
                                      MOBILE_INDEXS text CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '高级表单移动端-字段显示顺序',
                                      MULTIPLE_LAYOUT_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '多布局ID',
                                      PRIMARY KEY (ID) USING BTREE,
                                      INDEX IDX_FORM_LAYOUT_VERSION_F_ID(FORM_ID) USING BTREE,
                                      INDEX IDX_FORM_LAYOUT_VERSION_MLD(MULTIPLE_LAYOUT_ID) USING BTREE
)
;

CREATE TABLE form_option_sub_filter_config  (
                                                id bigint(20) NOT NULL COMMENT 'ID',
                                                create_time datetime NOT NULL COMMENT '创建时间',
                                                update_time datetime NULL DEFAULT NULL COMMENT '修改时间',
                                                creator bigint(20) NOT NULL COMMENT '创建人id',
                                                delete_type int(11) NOT NULL COMMENT '是否删除',
                                                tenant_key varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '租户KEY',
                                                main_field bigint(20) NOT NULL COMMENT '主字段',
                                                sub_field bigint(20) NOT NULL COMMENT '子字段',
                                                form_id bigint(20) NOT NULL COMMENT 'FORMID',
                                                option_ids mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '可选择的选项列表',
                                                main_option_id bigint(20) NOT NULL COMMENT '主字段选项ID',
                                                PRIMARY KEY (id) USING BTREE,
                                                UNIQUE INDEX IDX_FOSFC_MF_SF_MOI(main_field, sub_field, main_option_id) USING BTREE,
                                                INDEX IDX_FOSFC_TENANT_KEY(tenant_key) USING BTREE,
                                                INDEX IDX_FOSFC_FORM_ID(form_id) USING BTREE,
                                                INDEX IDX_FOSFC_MAIN_FIELD(main_field) USING BTREE,
                                                INDEX IDX_FOSFC_SUB_FIELD(sub_field) USING BTREE
)
;

CREATE TABLE form_option_template_config  (
                                              id bigint(20) NOT NULL COMMENT 'ID',
                                              create_time datetime NOT NULL COMMENT '创建时间',
                                              update_time datetime NULL DEFAULT NULL COMMENT '修改时间',
                                              creator bigint(20) NOT NULL COMMENT '创建人id',
                                              delete_type int(11) NOT NULL COMMENT '是否删除',
                                              tenant_key varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '租户KEY',
                                              form_id bigint(20) NOT NULL COMMENT '表单ID',
                                              field_id bigint(20) NOT NULL COMMENT '字段ID',
                                              template_id bigint(20) NOT NULL COMMENT '数据源模板ID',
                                              inherited_type varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '类型(parent, sub)',
                                              drop_down_level char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '下拉级别',
                                              parent_field bigint(20) NULL DEFAULT NULL COMMENT '父级控件',
                                              PRIMARY KEY (id) USING BTREE,
                                              INDEX IDX_FOTC_FIELD_ID(field_id) USING BTREE,
                                              INDEX IDX_FOTC_FORM_ID(form_id) USING BTREE,
                                              INDEX IDX_FOTC_TENANT_KEY(tenant_key) USING BTREE
)
;

CREATE TABLE form_setting_logs  (
                                    id bigint(20) NOT NULL COMMENT 'ID',
                                    create_time datetime NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                    update_time datetime NULL DEFAULT CURRENT_TIMESTAMP COMMENT '修改时间',
                                    creator bigint(20) NULL DEFAULT NULL COMMENT '创建人id',
                                    delete_type int(11) NULL DEFAULT 0 COMMENT '是否删除',
                                    tenant_key varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户KEY',
                                    uuid varchar(36) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT 'uuid',
                                    log_date datetime NULL DEFAULT CURRENT_TIMESTAMP COMMENT '操作时间',
                                    device varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '终端信息',
                                    log_OPERATOR bigint(20) NULL DEFAULT NULL COMMENT '操作人',
                                    operatorname varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '操作人姓名',
                                    targetid bigint(20) NULL DEFAULT NULL COMMENT '操作目标id',
                                    targetname varchar(3000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '操作目标名称',
                                    modulename varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '模块',
                                    functionname varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '服务（方法）',
                                    interfacename varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '访问接口名',
                                    requesturl longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '请求全路径',
                                    requesturi longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '请求地址',
                                    operatetype varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '操作类型',
                                    operatetypename varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '操作类型名称',
                                    operatedesc varchar(3000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '操作详细说明',
                                    params longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '涉及的相关参数',
                                    belongmainid varchar(36) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '所属主表uuid',
                                    clientip varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '操作IP',
                                    groupid varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分组',
                                    groupnamelabel varchar(1000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分组标题',
                                    redoservice varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '重做业务接口',
                                    redocontext longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '重做参数',
                                    cancelservice varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '撤销业务接口',
                                    cancelcontext longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '撤销参数',
                                    totalruntime bigint(20) NULL DEFAULT NULL COMMENT '总运行时长',
                                    mainruntime bigint(20) NULL DEFAULT NULL COMMENT '主方法运行时长',
                                    log_result varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '运行结果标识',
                                    fromterminal varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '来自pc web',
                                    resultdesc longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '运行结果描述',
                                    old_content longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '原先内容',
                                    link_type varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '链接类型',
                                    link_id bigint(20) NULL DEFAULT NULL COMMENT '链接id',
                                    old_link_id bigint(20) NULL DEFAULT NULL COMMENT '原先链接id',
                                    PRIMARY KEY (id) USING BTREE,
                                    INDEX IDX_FORM_SETTING_LOGS_TK(tenant_key) USING BTREE,
                                    INDEX IDX_FORM_SETTING_LOGS_LD(log_date) USING BTREE,
                                    INDEX IDX_FORM_SETTING_LOGS_TI(targetid) USING BTREE,
                                    INDEX IDX_FORM_SETTING_LOGS_MN(modulename) USING BTREE,
                                    INDEX IDX_FORM_SETTING_LOGS_FN(functionname) USING BTREE,
                                    INDEX IDX_FORM_SETTING_LOGS_U(uuid) USING BTREE
)
;

CREATE TABLE form_setting_logs_detail  (
                                           id bigint(20) NOT NULL COMMENT 'ID',
                                           create_time datetime NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                           update_time datetime NULL DEFAULT CURRENT_TIMESTAMP COMMENT '修改时间',
                                           creator bigint(20) NULL DEFAULT NULL COMMENT '创建人id',
                                           delete_type int(11) NULL DEFAULT 0 COMMENT '是否删除',
                                           tenant_key varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户KEY',
                                           uuid varchar(36) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '日志UUID',
                                           mainid varchar(36) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '主表id',
                                           dataid varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '数据id',
                                           belongdataid varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '主表数据id',
                                           tablename varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '表名',
                                           tablenamelabelid varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '表名labelid',
                                           tablenamedesc varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '对应数据库的表',
                                           fieldname varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '字段名',
                                           fieldnamelabelid varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '字段名labelid',
                                           newvalue longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '更新后的值',
                                           oldvalue longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '更新前的值',
                                           newrealvalue longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '更新后的显示值',
                                           oldrealvalue longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '更新前的显示值',
                                           fielddesc varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '字段名',
                                           showorder int(11) NULL DEFAULT NULL COMMENT '排序',
                                           isdetail int(11) NULL DEFAULT 0 COMMENT '是否明细字段',
                                           PRIMARY KEY (id) USING BTREE,
                                           INDEX IDX_F_SETTING_LOGS_DETAIL_TK(tenant_key) USING BTREE,
                                           INDEX IDX_F_SETTING_LOGS_DETAIL_MI(mainid) USING BTREE
)
;

CREATE TABLE form_style  (
                             ID decimal(20, 0) NOT NULL,
                             FORM_ID decimal(20, 0) NOT NULL,
                             LAYOUT_ID decimal(20, 0) NOT NULL,
                             STYLE_DETAIL mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                             STYLE_CONFIG text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                             UPDATE_TIME datetime NULL DEFAULT CURRENT_TIMESTAMP,
                             TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                             STYLE_FIELD_CONFIG mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                             style_config_temp mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                             PRIMARY KEY (ID) USING BTREE,
                             INDEX IDX_FORM_STYLE_LAYOUT_ID(LAYOUT_ID) USING BTREE,
                             INDEX IDX_FORM_STYLE_FORM_ID(FORM_ID) USING BTREE
)
;

CREATE TABLE form_table  (
                             ID decimal(20, 0) NOT NULL,
                             FORM_ID decimal(20, 0) NOT NULL,
                             TABLE_NAME varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '表名称',
                             TENANT_KEY varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                             CREATE_TIME datetime NOT NULL,
                             UPDATE_TIME datetime NULL DEFAULT NULL,
                             `OPERATOR` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                             PRIMARY KEY (ID) USING BTREE,
                             INDEX IDX_FORM_TABLE_FORM_ID(FORM_ID) USING BTREE,
                             INDEX IDX_FORM_TABLE_NAME(TABLE_NAME) USING BTREE
)
;

CREATE TABLE form_table_data_redundancy  (
                                             ID decimal(20, 0) NOT NULL,
                                             FORM_TABLE_ID decimal(20, 0) NOT NULL COMMENT '数据ID',
                                             FIELD_ID decimal(20, 0) NOT NULL COMMENT '列ID',
                                             CONTENT longtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '冗余内容',
                                             CREATE_TIME datetime NOT NULL,
                                             UPDATE_TIME datetime NULL DEFAULT NULL,
                                             `OPERATOR` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                             TENANT_KEY varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                             TYPE varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT 'content',
                                             target_id text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                                             content_type text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                                             PRIMARY KEY (ID) USING BTREE,
                                             INDEX IDX_FTDR_TYPE(TYPE) USING BTREE,
                                             INDEX IDX_FTDR_FT_FI_T(FORM_TABLE_ID, FIELD_ID, TYPE) USING BTREE,
                                             INDEX IDX_FTDR_CREATE_TIME(CREATE_TIME) USING BTREE,
                                             INDEX IDX_FTDR_FIELD_ID(FIELD_ID) USING BTREE,
                                             FULLTEXT INDEX IDX_FTDR_CONTENT(CONTENT)
)
;

CREATE TABLE form_table_data_rel (
                                      ID decimal(20, 0) NOT NULL,
                                      FORM_TABLE_ID decimal(20, 0) NOT NULL COMMENT '数据ID',
                                      PARENT_ID decimal(20, 0) NOT NULL COMMENT '父数据ID',
                                      TENANT_KEY varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                      IS_DELETE tinyint(2) NOT NULL DEFAULT 0 COMMENT '0:未删除1：已删除',
                                      PRIMARY KEY (ID) USING BTREE,
                                      INDEX IDX_FORM_TABLE_DATA_REL_FTI(FORM_TABLE_ID) USING BTREE,
                                      INDEX IDX_FORM_TABLE_DATA_REL_PI(PARENT_ID) USING BTREE,
                                      INDEX IDX_FTDR_FTI_PI_ID(FORM_TABLE_ID, PARENT_ID, IS_DELETE) USING BTREE
)
;

CREATE TABLE form_table_field (
                                     `ID` decimal(20, 0) NOT NULL,
                                     `FIELD_ID` decimal(20, 0) NOT NULL,
                                     `IS_INDEX` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '0' COMMENT '列是否已有索引 索引类型',
                                     `COLUMN_NAME` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '用户定义的列名，用户未定义则填充默认列名',
                                     `TENANT_KEY` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                     `TYPE_LEN` smallint(11) NOT NULL COMMENT '类型长度',
                                     `COLUMN_TYPE` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '列类型',
                                     `DYNAMIC` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '列对应的数据长度（日期类型）',
                                     PRIMARY KEY (`ID`) USING BTREE,
                                     UNIQUE INDEX `UNX_FORM_TABLE_FIELD_FIELD_ID`(`FIELD_ID`) USING BTREE
)
;

CREATE TABLE form_table_rel  (
                                 ID decimal(20, 0) NOT NULL,
                                 FORM_ID decimal(20, 0) NOT NULL COMMENT '主表ID',
                                 SUB_FORM_ID decimal(20, 0) NOT NULL COMMENT '子表ID',
                                 `OPERATOR` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                 TENANT_KEY varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                 CREATE_TIME datetime NOT NULL,
                                 UPDATE_TIME datetime NULL DEFAULT NULL,
                                 IS_DELETE tinyint(2) NOT NULL DEFAULT 0 COMMENT '是否删除  0：未删除 1：已删除',
                                 PRIMARY KEY (ID) USING BTREE,
                                 INDEX IDX_FORM_TABLE_REL_FORM_ID(FORM_ID) USING BTREE,
                                 INDEX IDX_FORM_TABLE_REL_SUB_FORM_ID(SUB_FORM_ID) USING BTREE
)
;

CREATE TABLE form_view_relate_config  (
                                          ID decimal(20, 0) NOT NULL COMMENT '主键ID',
                                          FIELD_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '表单字段ID',
                                          DISPLAY varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '是否显示',
                                          READONLY varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '是否只读',
                                          REQUIRED varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '是否必填',
                                          DISPLAY_CONDITION mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '显示条件',
                                          READONLY_CONDITION mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '只读条件',
                                          REQUIRED_CONDITION mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '必填条件',
                                          VERSION_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '表单布局版本ID',
                                          `OPERATOR` decimal(20, 0) NULL DEFAULT NULL COMMENT '创建人',
                                          TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户Key',
                                          CREATE_TIME datetime NULL DEFAULT NULL COMMENT '创建时间',
                                          UPDATE_TIME datetime NULL DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                                          IS_DELETE int(11) NULL DEFAULT NULL,
                                          disable_edit varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                          single_row varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                          show_order double NULL DEFAULT 0,
                                          PRIMARY KEY (ID) USING BTREE,
                                          INDEX IDX_FVRC_FIELD_ID(FIELD_ID) USING BTREE,
                                          INDEX IDX_FVRC_VERSION_ID(VERSION_ID) USING BTREE,
                                          INDEX IDX_FVRC_TENANT_KEY(TENANT_KEY) USING BTREE
)
;

CREATE TABLE formdata  (
                           ID decimal(38, 0) NOT NULL COMMENT 'ID',
                           FORM_ID decimal(38, 0) NULL DEFAULT NULL COMMENT '表单ID',
                           LAYOUT_ID decimal(38, 0) NULL DEFAULT NULL COMMENT '布局ID',
                           DATA_STATUS varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '是否删除',
                           TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户ID',
                           `OPERATOR` decimal(38, 0) NULL DEFAULT NULL COMMENT '操作人',
                           CREATE_TIME datetime NULL DEFAULT NULL COMMENT '创建时间',
                           UPDATE_TIME datetime NULL DEFAULT NULL COMMENT '更新时间',
                           MODULE varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '模块',
                           CLIENT varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '客户端',
                           VERSION varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '版本',
                           SPENT_TIME decimal(38, 0) NULL DEFAULT NULL COMMENT '时间',
                           IP varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT 'IP',
                           name varchar(800) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '名称',
                           IS_DELETE tinyint(4) NULL DEFAULT 0,
                           PRIMARY KEY (ID) USING BTREE,
                           INDEX IDX_FORMDATA_TENANT_KEY(TENANT_KEY) USING BTREE,
                           INDEX IDX_FORMDATA_FORMID(FORM_ID) USING BTREE,
                           INDEX IDX_FORMDATA_LAYOUTID(LAYOUT_ID) USING BTREE,
                           INDEX IDX_FORMDATA_OPERATOR(OPERATOR) USING BTREE,
                           INDEX IDX_FORMDATA_MODULE(MODULE) USING BTREE,
                           INDEX IDX_FORMDATA_DATASTATUS(DATA_STATUS) USING BTREE,
                           INDEX IDX_FORMDATA_IS_DELETE(IS_DELETE) USING BTREE
)
;

CREATE TABLE formdata_detail  (
                                  ID decimal(38, 0) NOT NULL COMMENT 'ID',
                                  FORM_DATA decimal(38, 0) NULL DEFAULT NULL COMMENT '表单ID',
                                  FIELD_ID decimal(38, 0) NULL DEFAULT NULL COMMENT '字段ID',
                                  SUB_FORM_ID decimal(38, 0) NULL DEFAULT NULL COMMENT '明细表ID',
                                  LAYOUT_ID decimal(38, 0) NULL DEFAULT NULL COMMENT '布局ID',
                                  DATA_INDEX decimal(38, 0) NULL DEFAULT NULL COMMENT '明细表数据行号',
                                  CONTENT varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '内容',
                                  TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户KEY',
                                  `OPERATOR` decimal(38, 0) NULL DEFAULT NULL COMMENT '创建人',
                                  CREATE_TIME datetime NULL DEFAULT NULL COMMENT '创建时间',
                                  TYPE varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '类型',
                                  STAT_DESCRIBE varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '描述字段',
                                  LONGITUDE double NULL DEFAULT NULL COMMENT '经度',
                                  LATITUDE double NULL DEFAULT NULL COMMENT '纬度',
                                  PRIMARY KEY (ID) USING BTREE,
                                  INDEX IDX_FORMDATA_DETAIL_TENANT_KEY(TENANT_KEY) USING BTREE,
                                  INDEX IDX_FORMDATA_DETAIL_FORMDATA(FORM_DATA) USING BTREE,
                                  INDEX IDX_FORMDATA_DETAIL_FIELDID(FIELD_ID) USING BTREE,
                                  INDEX IDX_FORMDATA_DETAIL_SUB_FORM_I(SUB_FORM_ID) USING BTREE,
                                  INDEX IDX_FORMDATA_DETAIL_CONTENT(CONTENT(100)) USING BTREE
)
;

CREATE TABLE formdata_log  (
                               ID decimal(20, 0) NOT NULL,
                               FORM_DATA decimal(20, 0) NULL DEFAULT NULL,
                               CONTENT text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                               NEW_CONTENT text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                               FIELD_NAME varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               FIELD_ID decimal(20, 0) NULL DEFAULT NULL,
                               SUB_FORM_ID decimal(20, 0) NULL DEFAULT NULL,
                               DATA_INDEX decimal(5, 0) NULL DEFAULT NULL,
                               COMPONENT_KEY varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               CLIENT varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               VERSION varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               `OPERATOR` decimal(20, 0) NULL DEFAULT NULL,
                               CREATE_TIME datetime NULL DEFAULT NULL,
                               SOURCE_ID decimal(20, 0) NULL DEFAULT NULL,
                               SOURCE_NAME varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               SOURCE_MODULE varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                               EXTERNAL_OPERATOR decimal(20, 0) NULL DEFAULT NULL,
                               SOURCES text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                               LAYOUT_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '所属布局版本Id',
                               record_id bigint(20) NULL DEFAULT NULL,
                               PRIMARY KEY (ID) USING BTREE,
                               INDEX IDX_FORMDATA_LOG_FORM_DATA(FORM_DATA) USING BTREE,
                               INDEX IDX_FORMDATA_LOG_FIELD_ID(FIELD_ID) USING BTREE,
                               INDEX IDX_FORMDATA_LOG_SUB_FORM_ID(SUB_FORM_ID) USING BTREE,
                               INDEX IDX_FORMDATA_LOG_SOURCE_ID(SOURCE_ID) USING BTREE,
                               INDEX IDX_FORMDATA_LOG_LAYOUT_ID(LAYOUT_ID) USING BTREE,
                               INDEX IDX_FORMDATA_LOG_RECORD_ID(record_id) USING BTREE
)
;

CREATE TABLE formdata_option  (
                                  ID decimal(38, 0) NOT NULL COMMENT 'ID',
                                  DATA_DETAILS decimal(38, 0) NULL DEFAULT NULL COMMENT '数据明细ID',
                                  OPTION_ID varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                  CONTENT varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '内容',
                                  TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户KEY',
                                  TYPE varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '类型',
                                  target_id decimal(38, 0) NULL DEFAULT NULL COMMENT '目标ID',
                                  form_data decimal(20, 0) NULL DEFAULT NULL,
                                  PRIMARY KEY (ID) USING BTREE,
                                  INDEX IDX_FORMDATA_OPTION_TENANT_KEY(TENANT_KEY) USING BTREE,
                                  INDEX IDX_FORMDATA_OPTION_DATADETAIL(DATA_DETAILS) USING BTREE,
                                  INDEX IDX_FORMDATA_OPTION_OPTION_ID(OPTION_ID) USING BTREE
)
;

CREATE TABLE formdata_record_log  (
                                      id bigint(20) NOT NULL COMMENT 'ID',
                                      create_time datetime NULL DEFAULT NULL COMMENT '创建时间',
                                      tenant_key varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户KEY',
                                      form_data_id bigint(20) NULL DEFAULT NULL COMMENT '表单数据id',
                                      device varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '终端信息',
                                      OPERATOR_ID bigint(20) NULL DEFAULT NULL COMMENT '操作人',
                                      module_source varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '模块',
                                      operation_type varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '操作类型',
                                      ref_id varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分组编码',
                                      terminal varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '客户端',
                                      PRIMARY KEY (id) USING BTREE,
                                      INDEX IDX_FORMDATA_RECORD_LOG_TK(tenant_key) USING BTREE,
                                      INDEX IDX_FORMDATA_RECORD_LOG_FDI_RI(form_data_id, ref_id) USING BTREE
)
;

CREATE TABLE formdata_serial  (
                                  ID decimal(20, 0) NOT NULL,
                                  FORM_DATA decimal(20, 0) NOT NULL COMMENT '表单数据',
                                  FIELD_ID decimal(20, 0) NOT NULL COMMENT '表单字段',
                                  CONTENT varchar(1000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '序列号',
                                  CREATE_TIME datetime NULL DEFAULT CURRENT_TIMESTAMP,
                                  TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                  OPTION_ID decimal(20, 0) NULL DEFAULT NULL COMMENT '选项控件选项ID',
                                  DATE_CONTENT varchar(1000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '日期控件内容',
                                  PRIMARY KEY (ID) USING BTREE,
                                  INDEX IDX_FORMDATA_SERIAL_FORM_DATA(FORM_DATA) USING BTREE,
                                  INDEX IDX_FORMDATA_SERIAL_FIELD_ID(FIELD_ID) USING BTREE,
                                  INDEX IDX_FORMDATA_SERIAL_CREATETIME(CREATE_TIME) USING BTREE,
                                  INDEX IDX_FORMDATA_SERIAL_OPTION_ID(OPTION_ID) USING BTREE,
                                  INDEX IDX_FORMDATA_SERIAL_FI_CT(FIELD_ID, CREATE_TIME) USING BTREE
)
;

CREATE TABLE formdata_sharding_key  (
                                        ID decimal(20, 0) NOT NULL,
                                        TENANT_KEY varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                        PRIMARY KEY (ID) USING BTREE
)
;

CREATE TABLE formdata_sharding_sql  (
                                        ID decimal(20, 0) NOT NULL,
                                        CONTENT varchar(5000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                                        CREATE_TIME datetime NULL DEFAULT CURRENT_TIMESTAMP,
                                        TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT 'all_teams' COMMENT '租户KEY',
                                        PRIMARY KEY (ID) USING BTREE
)
;

CREATE TABLE formdata_text  (
                                ID decimal(38, 0) NOT NULL COMMENT 'ID',
                                DATA_DETAILS decimal(38, 0) NULL DEFAULT NULL COMMENT '明细ID',
                                CONTENT text CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '文本',
                                TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户ID',
                                RICH_CONTENT text CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '富文本',
                                PRIMARY KEY (ID) USING BTREE,
                                INDEX IDX_FORMDATA_TEXT_TENANT_KEY(TENANT_KEY) USING BTREE,
                                INDEX IDX_FORMDATA_TEXT_DATADETAILS(DATA_DETAILS) USING BTREE
)
;

CREATE TABLE panel_field  (
                              ID decimal(20, 0) NOT NULL,
                              FORM_ID decimal(20, 0) NULL DEFAULT NULL,
                              COMPONENT_KEY varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                              IS_DELETE char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                              TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                              TITLE varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                              `DESCRIBE` varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                              show_order double NULL DEFAULT 0,
                              other_properties text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                              layout_component_id varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                              PRIMARY KEY (ID) USING BTREE,
                              INDEX IDX_PANEL_FIELD_FORM_ID(FORM_ID) USING BTREE
)
;

CREATE TABLE sub_form  (
                           ID decimal(20, 0) NOT NULL,
                           FORM_ID decimal(20, 0) NULL DEFAULT NULL,
                           IS_DELETE char(1) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                           TENANT_KEY varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                           TMP_SUB_TABLE varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                           TITLE varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                           `DESCRIBE` varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                           DEFAULT_ROWS decimal(5, 0) NULL DEFAULT NULL,
                           data_table varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                           data_key varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                           layout_component_id varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
                           show_order double NULL DEFAULT 0,
                           other_properties text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
                           create_time datetime NULL DEFAULT NULL,
                           update_time datetime NULL DEFAULT NULL,
                           PRIMARY KEY (ID) USING BTREE,
                           INDEX IDX_SUB_FORM_FORM_ID(FORM_ID) USING BTREE
)
;

CREATE TABLE sub_form_config  (
                                  id bigint(20) NOT NULL COMMENT 'ID',
                                  create_time datetime NULL DEFAULT NULL COMMENT '创建时间',
                                  update_time datetime NULL DEFAULT NULL COMMENT '修改时间',
                                  delete_type int(11) NULL DEFAULT 0 COMMENT '是否删除',
                                  tenant_key varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '租户KEY',
                                  sub_form_id bigint(20) NULL DEFAULT NULL COMMENT '明细表Id',
                                  default_rows int(11) NULL DEFAULT NULL COMMENT '默认行数',
                                  max_rows int(11) NULL DEFAULT NULL COMMENT '最大行数',
                                  required_rows int(11) NULL DEFAULT NULL COMMENT '必填行数',
                                  filter_condition mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '数据过滤设置',
                                  other_properties mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '明细表其他配置属性',
                                  version_id bigint(20) NULL DEFAULT NULL COMMENT '布局版本id',
                                  creator bigint(20) NULL DEFAULT NULL COMMENT '创建人id',
                                  PRIMARY KEY (id) USING BTREE,
                                  INDEX IDX_SUB_FORM_CONFIG_TENANT_KEY(tenant_key) USING BTREE,
                                  INDEX IDX_SUB_FORM_CONFIG_SUB_FORM_I(sub_form_id) USING BTREE,
                                  INDEX IDX_SUB_FORM_CONFIG_VERSION_ID(version_id) USING BTREE
)
;