create table FORM
(
    ID               NUMBER                        not null,
    NAME             VARCHAR2(100 char),
    DESCRIBE         VARCHAR2(2000 char),
    STATUS           VARCHAR2(50 char),
    SOURCE_ID        NUMBER,
    OWNERSHIP        VARCHAR2(50 char),
    TENANT_KEY       VARCHAR2(10 char),
    OPERATOR         NUMBER,
    CREATE_TIME      DATE,
    UPDATE_TIME      DATE,
    IS_DELETE        CHAR(1 char),
    CATEGORY_ID      NUMBER,
    ICON             VARCHAR2(50 char),
    TMP_TABLE        NUMBER,
    TMP_LAYOUT       NUMBER,
    SORT             NUMBER,
    RECOMMEND        CHAR(1 char),
    BIAOGE_RECOMMEND CHAR(1 char),
    MODULE           VARCHAR2(50 char),
    RELATEFLOW       CHAR(1 char),
    REVIEW_COUNT     NUMBER,
    EXPORT_COUNT     NUMBER,
    COPY_COUNT       NUMBER,
    VIEW_COUNT       NUMBER,
    FILL_COUNT       NUMBER,
    DELETE_USER      NUMBER,
    REPORT           NUMBER,
    COLLECT_STATUS   VARCHAR2(10 char) default 'disable',
    TARGET_ID        NUMBER,
    DFAPTION         NUMBER(10),
    IS_ADVANCE       NUMBER(3)         default '0',
    INHERIT          CHAR(1 char)      default '0',
    IS_MULTI         CHAR(1 char),
    ATTR_NAME        VARCHAR2(50 char),
    PHYSICAL_TABLE   NUMBER(3)         default '0' not null,
    ORG_ID           NUMBER
)
    /

comment on column FORM.INHERIT is '字段权限继承'
/

comment on column FORM.IS_MULTI is '是否为多布局表单：0-否，1-是'
/

comment on column FORM.PHYSICAL_TABLE is '是否是物理表 0 不是 1是'
/

create unique index UK_FORM_ID
    on FORM (ID)
    /

create index IDX_FORM_TENANTKEY
    on FORM (TENANT_KEY)
    /

create index IDX_FORM_CATEGORY
    on FORM (CATEGORY_ID)
    /

create index IDX_FORM_OPERATOR
    on FORM (OPERATOR)
    /

create index IDX_FORM_OWNERSHIP
    on FORM (OWNERSHIP)
    /

create index IDX_FORM_MODULE
    on FORM (MODULE)
    /

create index IDX_FORM_TARGET_ID
    on FORM (TARGET_ID)
    /

create index IDX_FORM_SORT
    on FORM (SORT)
    /

create index IDX_FORM_CREATE_TIME
    on FORM (CREATE_TIME)
    /

create index IDX_FORM_STATUS
    on FORM (STATUS)
    /

create index IDX_FORM_REPORT
    on FORM (REPORT)
    /

create index IDX_FORM_BIAOGE_RECOMMEND
    on FORM (BIAOGE_RECOMMEND)
    /

create index IDX_FORM_ORG_ID
    on FORM (ORG_ID)
    /

alter table FORM
    add constraint PRIMARY_FORM_ID
        primary key (ID)
    /

create table FORM_LAYOUT_VERSION
(
    ID                 NUMBER not null,
    NAME               VARCHAR2(100 char),
    DESCRIBE           VARCHAR2(2000 char),
    FORM_ID            NUMBER,
    LAYOUT_TYPE        VARCHAR2(50 char),
    COLOR_SCHEME       VARCHAR2(50 char),
    LAYOUT_DETAIL      CLOB,
    TENANT_KEY         VARCHAR2(10 char),
    OPERATOR           NUMBER,
    CREATE_TIME        DATE,
    UPDATE_TIME        DATE,
    LAYOUT_HTML        CLOB,
    MOBILE_INDEXS      CLOB,
    MULTIPLE_LAYOUT_ID NUMBER
)
    /

comment on column FORM_LAYOUT_VERSION.ID is '布局版本ID'
/

comment on column FORM_LAYOUT_VERSION.NAME is '布局名称'
/

comment on column FORM_LAYOUT_VERSION.DESCRIBE is '布局描述'
/

comment on column FORM_LAYOUT_VERSION.FORM_ID is '表单ID'
/

comment on column FORM_LAYOUT_VERSION.LAYOUT_TYPE is '布局类型'
/

comment on column FORM_LAYOUT_VERSION.COLOR_SCHEME is '配色方案'
/

comment on column FORM_LAYOUT_VERSION.LAYOUT_DETAIL is '布局明细'
/

comment on column FORM_LAYOUT_VERSION.TENANT_KEY is '租户Key'
/

comment on column FORM_LAYOUT_VERSION.OPERATOR is '创建人'
/

comment on column FORM_LAYOUT_VERSION.CREATE_TIME is '创建时间'
/

comment on column FORM_LAYOUT_VERSION.UPDATE_TIME is '更新时间'
/

comment on column FORM_LAYOUT_VERSION.LAYOUT_HTML is '高级表单-布局HTML明细'
/

comment on column FORM_LAYOUT_VERSION.MOBILE_INDEXS is '高级表单移动端-字段显示顺序'
/

comment on column FORM_LAYOUT_VERSION.MULTIPLE_LAYOUT_ID is '多布局ID'
/

create unique index UK_FORM_LAYOUT_VERSION_ID
    on FORM_LAYOUT_VERSION (ID)
    /

create index IDX_FORM_LAYOUT_VERSION_F_ID
    on FORM_LAYOUT_VERSION (FORM_ID)
    /

create index IDX_FORM_LAYOUT_VERSION_MLD
    on FORM_LAYOUT_VERSION (MULTIPLE_LAYOUT_ID)
    /

create table FORM_STYLE
(
    ID                 NUMBER not null,
    FORM_ID            NUMBER not null,
    LAYOUT_ID          NUMBER not null,
    STYLE_DETAIL       CLOB,
    STYLE_CONFIG       CLOB,
    UPDATE_TIME        DATE default SYSDATE,
    TENANT_KEY         VARCHAR2(10 char),
    STYLE_FIELD_CONFIG CLOB,
    STYLE_CONFIG_TEMP  CLOB
)
    /

create unique index UK_FORM_STYLE_ID
    on FORM_STYLE (ID)
    /

create index IDX_FORM_STYLE_LAYOUT_ID
    on FORM_STYLE (LAYOUT_ID)
    /

create index IDX_FORM_STYLE_FORM_ID
    on FORM_STYLE (FORM_ID)
    /

alter table FORM_STYLE
    add constraint PRIMARY_FORM_STYLE_ID
        primary key (ID)
    /

create table FORM_TABLE
(
    ID          NUMBER            not null,
    FORM_ID     NUMBER            not null,
    TABLE_NAME  VARCHAR2(64 char) not null,
    TENANT_KEY  VARCHAR2(20 char) not null,
    CREATE_TIME DATE              not null,
    UPDATE_TIME DATE,
    OPERATOR    VARCHAR2(64 char) not null
)
    /

comment on column FORM_TABLE.TABLE_NAME is '表名称'
/

create unique index UK_FORM_TABLE_ID
    on FORM_TABLE (ID)
    /

create index IDX_FORM_TABLE_FORM_ID
    on FORM_TABLE (FORM_ID)
    /

create index IDX_FORM_TABLE_NAME
    on FORM_TABLE (TABLE_NAME)
    /

alter table FORM_TABLE
    add constraint PRIMARY_FORM_TABLE_ID
        primary key (ID)
    /

create table FORMDATA_SERIAL
(
    ID           NUMBER not null,
    FORM_DATA    NUMBER not null,
    FIELD_ID     NUMBER not null,
    CONTENT      VARCHAR2(1000 char),
    CREATE_TIME  DATE default SYSDATE,
    TENANT_KEY   VARCHAR2(10 char),
    OPTION_ID    NUMBER,
    DATE_CONTENT VARCHAR2(1000 char)
)
    /

comment on column FORMDATA_SERIAL.FORM_DATA is '表单数据'
/

comment on column FORMDATA_SERIAL.FIELD_ID is '表单字段'
/

comment on column FORMDATA_SERIAL.CONTENT is '序列号'
/

comment on column FORMDATA_SERIAL.OPTION_ID is '选项控件选项ID'
/

comment on column FORMDATA_SERIAL.DATE_CONTENT is '日期控件内容'
/

create unique index UK_FORMDATA_SERIAL_ID
    on FORMDATA_SERIAL (ID)
    /

create index IDX_FORMDATA_SERIAL_FORM_DATA
    on FORMDATA_SERIAL (FORM_DATA)
    /

create index IDX_FORMDATA_SERIAL_FIELD_ID
    on FORMDATA_SERIAL (FIELD_ID)
    /

create index IDX_FORMDATA_SERIAL_CREATETIME
    on FORMDATA_SERIAL (CREATE_TIME)
    /

create index IDX_FORMDATA_SERIAL_OPTION_ID
    on FORMDATA_SERIAL (OPTION_ID)
    /

create index IDX_FORMDATA_SERIAL_FI_CT
    on FORMDATA_SERIAL (FIELD_ID, CREATE_TIME)
    /

alter table FORMDATA_SERIAL
    add constraint PRIMARY_FORMDATA_SERIAL_ID
        primary key (ID)
    /

create table FORMDATA_SHARDING_KEY
(
    ID         NUMBER            not null,
    TENANT_KEY VARCHAR2(50 char) not null
)
    /

create unique index UK_FORMDATA_SHARDING_KEY_ID
    on FORMDATA_SHARDING_KEY (ID)
    /

create table COMPLEX_FIELD
(
    ID                  NUMBER           not null,
    FORM_ID             NUMBER,
    TITLE               VARCHAR2(100 char),
    DESCRIBE            VARCHAR2(2000 char),
    COMPONENT_KEY       VARCHAR2(50 char),
    REQUIRED            CHAR(1 char),
    IS_DELETE           CHAR(1 char),
    TENANT_KEY          VARCHAR2(10 char),
    OPERATOR            NUMBER,
    CREATE_TIME         DATE,
    SHOW_ORDER          NUMBER default 0 not null,
    OTHER_PROPERTIES    CLOB,
    LAYOUT_COMPONENT_ID VARCHAR2(32)
)
    /

create unique index UK_COMPLEX_FIELD_ID
    on COMPLEX_FIELD (ID)
    /

create index IDX_COMPLEX_FIELD_FORM_ID
    on COMPLEX_FIELD (FORM_ID)
    /

alter table COMPLEX_FIELD
    add constraint PRIMARY_COMPLEX_FIELD_ID
        primary key (ID)
    /

create table FIELD_LAYOUT
(
    ID            NUMBER not null,
    PARENT_ID     NUMBER,
    FIELD_ID      NUMBER,
    FIELD_TYPE    VARCHAR2(10 char),
    LAYOUT_ID     NUMBER,
    LAYOUT_DETAIL CLOB,
    TENANT_KEY    VARCHAR2(10 char),
    OPERATOR      NUMBER,
    CREATE_TIME   DATE,
    UPDATE_TIME   DATE,
    STATUS        CHAR(1 char)
    )
    /

comment on column FIELD_LAYOUT.STATUS is '字段状态：0-最新版本，1-历史版本'
/

create unique index UK_FIELD_LAYOUT_ID
    on FIELD_LAYOUT (ID)
    /

create index IDX_FIELD_LAYOUT_FIELD_ID
    on FIELD_LAYOUT (FIELD_ID)
    /

create index IDX_FIELD_LAYOUT_LAYOUT_ID
    on FIELD_LAYOUT (LAYOUT_ID)
    /

create index IDX_FIELD_LAYOUT_FIELD_TYPE
    on FIELD_LAYOUT (FIELD_TYPE)
    /

create index IDX_FIELD_LAYOUT_UPDATE_TIME
    on FIELD_LAYOUT (UPDATE_TIME)
    /

alter table FIELD_LAYOUT
    add constraint PRIMARY_FIELD_LAYOUT_ID
        primary key (ID)
    /

create table FIELD_OPTION
(
    ID           NUMBER           not null,
    FIELD_ID     NUMBER,
    PARENT_ID    NUMBER,
    NAME         VARCHAR2(100 char),
    "ORDER"      NUMBER,
    OTHER        CHAR(1 char),
    IS_DELETE    CHAR(1 char),
    TENANT_KEY   VARCHAR2(10 char),
    OPERATOR     NUMBER,
    CREATE_TIME  DATE,
    TMP_OPTION   VARCHAR2(50 char),
    "UID"        VARCHAR2(100 char),
    STYLE_CONFIG CLOB,
    EXTRA        CLOB,
    ARCHIVE      NUMBER default 0 not null
)
    /

comment on column FIELD_OPTION.STYLE_CONFIG is '选项设置'
/

create unique index UK_FIELD_OPTION_ID
    on FIELD_OPTION (ID)
    /

create index IDX_FIELD_OPTION_FIELD_ID
    on FIELD_OPTION (FIELD_ID)
    /

create index IDX_FIELD_OPTION_PARENT_ID
    on FIELD_OPTION (PARENT_ID)
    /

alter table FIELD_OPTION
    add constraint PRIMARY_FIELD_OPTION_ID
        primary key (ID)
    /

create table FIELD_PERMISSION
(
    ID          NUMBER not null,
    FORM_ID     NUMBER,
    TENANT_KEY  VARCHAR2(20 char),
    MODULE      VARCHAR2(50 char),
    CREATOR     NUMBER,
    CREATE_TIME DATE,
    UPDATE_TIME DATE,
    IS_DELETE   VARCHAR2(1 char),
    DATASRC     NUMBER(10)
)
    /

comment on column FIELD_PERMISSION.ID is '主键ID'
/

comment on column FIELD_PERMISSION.FORM_ID is '表单ID'
/

comment on column FIELD_PERMISSION.TENANT_KEY is '租户key'
/

comment on column FIELD_PERMISSION.MODULE is '所属模块'
/

comment on column FIELD_PERMISSION.CREATOR is '创建人'
/

comment on column FIELD_PERMISSION.CREATE_TIME is '创建时间'
/

comment on column FIELD_PERMISSION.UPDATE_TIME is '更新时间'
/

comment on column FIELD_PERMISSION.IS_DELETE is '是否删除(0-未删除,1-已删除)'
/

comment on column FIELD_PERMISSION.DATASRC is '是否迁移数据'
/

create unique index UK_FIELD_PERMISSION_ID
    on FIELD_PERMISSION (ID)
    /

create index IDX_FIELD_PERMISSION_FORM_ID
    on FIELD_PERMISSION (FORM_ID)
    /

alter table FIELD_PERMISSION
    add constraint PRIMARY_FIELD_PERMISSION_ID
        primary key (ID)
    /

create table FIELD_PERMISSION_DETAIL
(
    ID            NUMBER           not null,
    FIELD_ID      NUMBER           not null,
    FIELD_READ    VARCHAR2(1 char) not null,
    FIELD_WRITE   VARCHAR2(1 char) not null,
    IS_DELETE     VARCHAR2(1 char),
    PERMISSION_ID NUMBER,
    DATASRC       NUMBER(10),
    TENANT_KEY    VARCHAR2(20 char),
    REQUIRED      VARCHAR2(1),
    DISABLE_EDIT  VARCHAR2(1)
)
    /

comment on column FIELD_PERMISSION_DETAIL.ID is '主键ID'
/

comment on column FIELD_PERMISSION_DETAIL.FIELD_ID is '表单字段ID'
/

comment on column FIELD_PERMISSION_DETAIL.FIELD_READ is '字段读权限（查看）'
/

comment on column FIELD_PERMISSION_DETAIL.FIELD_WRITE is '字段写权限（填写）'
/

comment on column FIELD_PERMISSION_DETAIL.IS_DELETE is '是否删除(0-未删除,1-已删除)'
/

comment on column FIELD_PERMISSION_DETAIL.PERMISSION_ID is '字段权限ID'
/

comment on column FIELD_PERMISSION_DETAIL.DATASRC is '是否迁移数据'
/

comment on column FIELD_PERMISSION_DETAIL.TENANT_KEY is '租户key'
/

create unique index UK_FIELD_PERMISSION_DETAIL_ID
    on FIELD_PERMISSION_DETAIL (ID)
    /

create index IDX_FIELD_PERMISSION_DETAIL_FD
    on FIELD_PERMISSION_DETAIL (FIELD_ID)
    /

create index IDX_FIELD_PERMISSION_DETAIL_PD
    on FIELD_PERMISSION_DETAIL (PERMISSION_ID)
    /

alter table FIELD_PERMISSION_DETAIL
    add constraint PRIMARY_FPD_ID
        primary key (ID)
    /

create table FORM_CATEGORY
(
    ID          NUMBER not null,
    NAME        VARCHAR2(100 char),
    SORT        NUMBER,
    TENANT_KEY  VARCHAR2(10 char),
    OPERATOR    NUMBER,
    CREATE_TIME DATE,
    TYPE        VARCHAR2(20 char),
    MODULE      VARCHAR2(20 char)
)
    /

create unique index UK_FORM_CATEGORY_ID
    on FORM_CATEGORY (ID)
    /

create index IDX_FORM_CATEGORY_TENANT_KEY
    on FORM_CATEGORY (TENANT_KEY)
    /

alter table FORM_CATEGORY
    add constraint PRIMARY_FORM_CATEGORY_ID
        primary key (ID)
    /

create table FORM_DATA_LAYOUT_REL
(
    ID                 NUMBER not null,
    FORM_DATA          NUMBER,
    MULTIPLE_LAYOUT_ID NUMBER,
    VERSION_ID         NUMBER,
    TENANT_KEY         VARCHAR2(10 char)
)
    /

comment on column FORM_DATA_LAYOUT_REL.FORM_DATA is '表单数据Id'
/

comment on column FORM_DATA_LAYOUT_REL.MULTIPLE_LAYOUT_ID is '多布局Id'
/

comment on column FORM_DATA_LAYOUT_REL.VERSION_ID is '布局版本Id'
/

comment on column FORM_DATA_LAYOUT_REL.TENANT_KEY is '租户Key'
/

create unique index UK_FORM_DATA_LAYOUT_REL_ID
    on FORM_DATA_LAYOUT_REL (ID)
    /

create index IDX_FORM_DATA_LAYOUT_REL_FD
    on FORM_DATA_LAYOUT_REL (FORM_DATA)
    /

create index IDX_FORM_DATA_LAYOUT_REL_MLI
    on FORM_DATA_LAYOUT_REL (MULTIPLE_LAYOUT_ID)
    /

create index IDX_FORM_DATA_LAYOUT_REL_VI
    on FORM_DATA_LAYOUT_REL (VERSION_ID)
    /

alter table FORM_DATA_LAYOUT_REL
    add constraint PRIMARY_FORM_DATA_LAYOUT_REL_I
        primary key (ID)
    /

create table FORM_FIELD
(
    ID                  NUMBER not null,
    FORM_ID             NUMBER,
    SUB_FORM_ID         NUMBER,
    TITLE               VARCHAR2(100 char),
    DESCRIBE            VARCHAR2(2000 char),
    DATA_TYPE           VARCHAR2(50 char),
    REQUIRED            CHAR(1 char),
    IS_DELETE           CHAR(1 char),
    TENANT_KEY          VARCHAR2(10 char),
    OPERATOR            NUMBER,
    CREATE_TIME         DATE,
    COMPONENT_KEY       VARCHAR2(50 char),
    TMP_FIELD           VARCHAR2(50 char),
    COMPLEX_ID          NUMBER,
    UPDATE_TIME         DATE,
    SOURCE_MODULE       VARCHAR2(20 char),
    DATA_TEMPLATE_ID    NUMBER,
    EXPRESS_ID          NUMBER(24),
    ATTR_NAME           VARCHAR2(50 char),
    SHOW_ORDER          NUMBER default 0,
    GROUP_ID            NUMBER(20),
    OTHER_PROPERTIES    CLOB,
    DATA_KEY            VARCHAR2(32),
    LAYOUT_COMPONENT_ID VARCHAR2(32),
    SINGLE              NUMBER default 1,
    ARCHIVE             NUMBER default 0,
    BROWSER_MODULE      VARCHAR2(32),
    BROWSER_TYPE        VARCHAR2(64),
    CUSTOM_ORDER        NUMBER,
    DEFAULT_ORDER       NUMBER default '0',
    PARENT_ID           NUMBER(20)
)
    /

comment on column FORM_FIELD.EXPRESS_ID is 'Excel函数公式ID'
/

create unique index UK_FORM_FIELD_ID
    on FORM_FIELD (ID)
    /

create index IDX_FORM_FIELD_FORM_ID
    on FORM_FIELD (FORM_ID)
    /

create index IDX_FORM_FIELD_COMPONENT_KEY
    on FORM_FIELD (COMPONENT_KEY)
    /

create index IDX_FORM_FIELD_UPDATE_TIME
    on FORM_FIELD (UPDATE_TIME)
    /

create index IDX_FORM_FIELD_COMPLEX_FIELD
    on FORM_FIELD (COMPLEX_ID)
    /

create index IDX_FORM_FIELD_SUB_FORM_ID
    on FORM_FIELD (SUB_FORM_ID)
    /

create index IDX_FORM_FIELD_DATA_TEMPLATE_I
    on FORM_FIELD (DATA_TEMPLATE_ID)
    /

create index IDX_FORM_FIELD_EXPRESS_ID
    on FORM_FIELD (EXPRESS_ID)
    /

create index IDX_FORM_FIELD_BM_BT_TK
    on FORM_FIELD (BROWSER_MODULE, BROWSER_TYPE, TENANT_KEY)
    /

create index IDX_FORM_FIELD_DK_TK
    on FORM_FIELD (DATA_KEY, TENANT_KEY)
    /

alter table FORM_FIELD
    add constraint PRIMARY_FORM_FIELD_ID
        primary key (ID)
    /

create table FORMDATA_LOG
(
    ID                NUMBER not null,
    FORM_DATA         NUMBER,
    CONTENT           CLOB,
    NEW_CONTENT       CLOB,
    FIELD_NAME        VARCHAR2(100 char),
    FIELD_ID          NUMBER,
    SUB_FORM_ID       NUMBER,
    DATA_INDEX        NUMBER,
    COMPONENT_KEY     VARCHAR2(50 char),
    CLIENT            VARCHAR2(50 char),
    VERSION           VARCHAR2(50 char),
    TENANT_KEY        VARCHAR2(10 char),
    OPERATOR          NUMBER,
    CREATE_TIME       DATE,
    SOURCE_ID         NUMBER,
    SOURCE_NAME       VARCHAR2(500 char),
    SOURCE_MODULE     VARCHAR2(20 char),
    EXTERNAL_OPERATOR NUMBER,
    SOURCES           CLOB,
    LAYOUT_ID         NUMBER,
    RECORD_ID         NUMBER(20)
)
    /

comment on column FORMDATA_LOG.LAYOUT_ID is '所属布局版本Id'
/

create unique index UK_FORMDATA_LOG_ID
    on FORMDATA_LOG (ID)
    /

create index IDX_FORMDATA_LOG_FORM_DATA
    on FORMDATA_LOG (FORM_DATA)
    /

create index IDX_FORMDATA_LOG_FIELD_ID
    on FORMDATA_LOG (FIELD_ID)
    /

create index IDX_FORMDATA_LOG_SUB_FORM_ID
    on FORMDATA_LOG (SUB_FORM_ID)
    /

create index IDX_FORMDATA_LOG_SOURCE_ID
    on FORMDATA_LOG (SOURCE_ID)
    /

create index IDX_FORMDATA_LOG_LAYOUT_ID
    on FORMDATA_LOG (LAYOUT_ID)
    /

create index IDX_FORMDATA_LOG_RECORD_ID
    on FORMDATA_LOG (RECORD_ID)
    /

alter table FORMDATA_LOG
    add constraint PRIMARY_FORMDATA_LOG_ID
        primary key (ID)
    /

create table FORM_TABLE_DATA_REDUNDANCY
(
    ID            NUMBER            not null,
    FORM_TABLE_ID NUMBER            not null,
    FIELD_ID      NUMBER            not null,
    CONTENT       CLOB,
    CREATE_TIME   DATE              not null,
    UPDATE_TIME   DATE,
    OPERATOR      VARCHAR2(64 char),
    TENANT_KEY    VARCHAR2(20 char) not null,
    TYPE          VARCHAR2(50 char) default 'content',
    TARGET_ID     CLOB,
    CONTENT_TYPE  CLOB
)
    /

comment on column FORM_TABLE_DATA_REDUNDANCY.FORM_TABLE_ID is '数据ID'
/

comment on column FORM_TABLE_DATA_REDUNDANCY.FIELD_ID is '列ID'
/

comment on column FORM_TABLE_DATA_REDUNDANCY.CONTENT is '冗余内容'
/

create unique index UK_FORM_TABLE_DATA_RY_ID
    on FORM_TABLE_DATA_REDUNDANCY (ID)
    /

create index IDX_FTDR_TYPE
    on FORM_TABLE_DATA_REDUNDANCY (TYPE)
    /

create index IDX_FTDR_FT_FI_T
    on FORM_TABLE_DATA_REDUNDANCY (FORM_TABLE_ID, FIELD_ID, TYPE)
    /

create index IDX_FTDR_CREATE_TIME
    on FORM_TABLE_DATA_REDUNDANCY (CREATE_TIME)
    /

create index IDX_FTDR_FIELD_ID
    on FORM_TABLE_DATA_REDUNDANCY (FIELD_ID)
    /

alter table FORM_TABLE_DATA_REDUNDANCY
    add constraint PRIMARY_FTDR_ID
        primary key (ID)
    /

create table SUB_FORM
(
    ID                  NUMBER not null,
    FORM_ID             NUMBER,
    IS_DELETE           CHAR(1 char),
    TENANT_KEY          VARCHAR2(10 char),
    TMP_SUB_TABLE       VARCHAR2(50 char),
    TITLE               VARCHAR2(100 char),
    DESCRIBE            VARCHAR2(2000 char),
    DEFAULT_ROWS        NUMBER,
    DATA_TABLE          VARCHAR2(100 char),
    DATA_KEY            VARCHAR2(30),
    LAYOUT_COMPONENT_ID VARCHAR2(32),
    SHOW_ORDER          NUMBER default 0,
    OTHER_PROPERTIES    CLOB,
    CREATE_TIME         DATE,
    UPDATE_TIME         DATE
)
    /

create unique index UK_SUB_FORM_ID
    on SUB_FORM (ID)
    /

create index IDX_SUB_FORM_FORM_ID
    on SUB_FORM (FORM_ID)
    /

alter table SUB_FORM
    add constraint PRIMARY_SUB_FORM_ID
        primary key (ID)
    /

create table PANEL_FIELD
(
    ID                  NUMBER not null,
    FORM_ID             NUMBER,
    COMPONENT_KEY       VARCHAR2(50 char),
    IS_DELETE           CHAR(1 char),
    TENANT_KEY          VARCHAR2(10 char),
    TITLE               VARCHAR2(100 char),
    DESCRIBE            VARCHAR2(2000 char),
    SHOW_ORDER          NUMBER default 0,
    OTHER_PROPERTIES    CLOB,
    LAYOUT_COMPONENT_ID VARCHAR2(32)
)
    /

create unique index UK_PANEL_FIELD_ID
    on PANEL_FIELD (ID)
    /

create index IDX_PANEL_FIELD_FORM_ID
    on PANEL_FIELD (FORM_ID)
    /

alter table PANEL_FIELD
    add constraint PRIMARY_PANEL_FIELD_ID
        primary key (ID)
    /

create table FORMDATA_SHARDING_SQL
(
    ID          NUMBER not null,
    CONTENT     CLOB,
    CREATE_TIME DATE default SYSDATE,
    TENANT_KEY varchar2(10) default 'all_teams'
)
    /

create unique index UK_FORMDATA_SHARDING_SQL_ID
    on FORMDATA_SHARDING_SQL (ID)
    /

alter table FORMDATA_SHARDING_SQL
    add constraint PRIMARY_FDSS_ID
        primary key (ID)
    /

create table FORM_FIELD_LANGUAGE
(
    ID              NUMBER not null,
    FORM_ID         NUMBER,
    FIELD_ID        NUMBER not null,
    COMPONENT_KEY   VARCHAR2(50 char),
    LANGUAGE_DETAIL CLOB,
    IS_DELETE       CHAR(1 char),
    CREATE_TIME     DATE,
    UPDATE_TIME     DATE,
    TENANT_KEY      VARCHAR2(20 char)
)
    /

comment on column FORM_FIELD_LANGUAGE.ID is '主键ID'
/

comment on column FORM_FIELD_LANGUAGE.FORM_ID is '表单ID'
/

comment on column FORM_FIELD_LANGUAGE.FIELD_ID is '表单字段ID'
/

comment on column FORM_FIELD_LANGUAGE.COMPONENT_KEY is '控件Key'
/

comment on column FORM_FIELD_LANGUAGE.LANGUAGE_DETAIL is '多语言设置明细'
/

comment on column FORM_FIELD_LANGUAGE.IS_DELETE is '国际化信息是否删除：0-否 1-是'
/

comment on column FORM_FIELD_LANGUAGE.CREATE_TIME is '创建时间'
/

comment on column FORM_FIELD_LANGUAGE.UPDATE_TIME is '更新时间'
/

comment on column FORM_FIELD_LANGUAGE.TENANT_KEY is '租户key'
/

create unique index UK_FORM_FIELD_LANGUAGE_ID
    on FORM_FIELD_LANGUAGE (ID)
    /

create index IDX_FORM_FIELD_LANGUAGE_FORM_I
    on FORM_FIELD_LANGUAGE (FORM_ID)
    /

create index IDX_FORM_FIELD_LANGUAGE_FD_I
    on FORM_FIELD_LANGUAGE (FIELD_ID)
    /


alter table FORM_FIELD_LANGUAGE
    add constraint PRIMARY_FORM_FIELD_LANGUAGE_ID
        primary key (ID)
    /

create table FORM_LAYOUT_MULTIPLE
(
    ID            NUMBER not null,
    NAME          VARCHAR2(100 char),
    DESCRIBE      VARCHAR2(2000 char),
    FORM_ID       NUMBER,
    TENANT_KEY    VARCHAR2(10 char),
    OPERATOR      NUMBER,
    CREATE_TIME   DATE,
    UPDATE_TIME   DATE,
    IS_DEFAULT    CHAR(1 char),
    IS_DELETE     CHAR(1 char),
    VERSION_ID    NUMBER,
    LAYOUT_TYPE   VARCHAR2(20),
    TERMINAL_TYPE VARCHAR2(20)
)
    /

comment on column FORM_LAYOUT_MULTIPLE.ID is '布局ID'
/

comment on column FORM_LAYOUT_MULTIPLE.NAME is '布局名称'
/

comment on column FORM_LAYOUT_MULTIPLE.DESCRIBE is '布局描述'
/

comment on column FORM_LAYOUT_MULTIPLE.FORM_ID is '表单ID'
/

comment on column FORM_LAYOUT_MULTIPLE.TENANT_KEY is '租户Key'
/

comment on column FORM_LAYOUT_MULTIPLE.OPERATOR is '创建人'
/

comment on column FORM_LAYOUT_MULTIPLE.CREATE_TIME is '创建时间'
/

comment on column FORM_LAYOUT_MULTIPLE.UPDATE_TIME is '更新时间'
/

comment on column FORM_LAYOUT_MULTIPLE.IS_DEFAULT is '是否为默认布局(0-否, 1-是)'
/

comment on column FORM_LAYOUT_MULTIPLE.IS_DELETE is '是否为删除(0-未删除, 1-回收站, 2-彻底删除)'
/

comment on column FORM_LAYOUT_MULTIPLE.VERSION_ID is '最新版本布局ID'
/

create unique index UK_FORM_LAYOUT_MULTIPLE_ID
    on FORM_LAYOUT_MULTIPLE (ID)
    /

create index IDX_FORM_LAYOUT_MULTIPLE_F_ID
    on FORM_LAYOUT_MULTIPLE (FORM_ID)
    /

create index IDX_FORM_LAYOUT_MULTIPLE_VI
    on FORM_LAYOUT_MULTIPLE (VERSION_ID)
    /

alter table FORM_LAYOUT_MULTIPLE
    add constraint PRIMARY_FORM_LAYOUT_MULTIPLE_I
        primary key (ID)
    /

create table FORM_LAYOUT_STYLE
(
    ID            NUMBER not null,
    FORM_ID       NUMBER,
    LAYOUT_TYPE   VARCHAR2(50 char),
    COLOR_SCHEME  VARCHAR2(50 char),
    LAYOUT_DETAIL CLOB,
    TENANT_KEY    VARCHAR2(10 char),
    OPERATOR      NUMBER,
    CREATE_TIME   DATE,
    UPDATE_TIME   DATE,
    LAYOUT_HTML   CLOB,
    LAYOUT_STYLE  CLOB,
    MOBILE_INDEXS CLOB
)
    /

create unique index UK_FORM_LAYOUT_STYLE_ID
    on FORM_LAYOUT_STYLE (ID)
    /

create index IDX_FORM_LAYOUT_STYLE_FORM_ID
    on FORM_LAYOUT_STYLE (FORM_ID)
    /

create index IDX_FORM_LAYOUT_STYLE_TK
    on FORM_LAYOUT_STYLE (TENANT_KEY)
    /

alter table FORM_LAYOUT_STYLE
    add constraint PRIMARY_FORM_LAYOUT_STYLE_ID
        primary key (ID)
    /

create table FORM_TABLE_DATA_REL
(
    ID            NUMBER                not null,
    FORM_TABLE_ID NUMBER                not null,
    PARENT_ID     NUMBER                not null,
    TENANT_KEY    VARCHAR2(20 char)     not null,
    IS_DELETE     NUMBER(3) default '0' not null
)
    /

comment on column FORM_TABLE_DATA_REL.FORM_TABLE_ID is '数据ID'
/

comment on column FORM_TABLE_DATA_REL.PARENT_ID is '父数据ID'
/

comment on column FORM_TABLE_DATA_REL.IS_DELETE is '0:未删除1：已删除'
/

create unique index UK_FORM_TABLE_DATA_REL_ID
    on FORM_TABLE_DATA_REL (ID)
    /

create index IDX_FORM_TABLE_DATA_REL_FTI
    on FORM_TABLE_DATA_REL (FORM_TABLE_ID)
    /

create index IDX_FORM_TABLE_DATA_REL_PI
    on FORM_TABLE_DATA_REL (PARENT_ID)
    /

create index IDX_FTDR_FTI_PI_ID
    on FORM_TABLE_DATA_REL (FORM_TABLE_ID, PARENT_ID, IS_DELETE)
    /

alter table FORM_TABLE_DATA_REL
    add constraint PRIMARY_FORM_TABLE_DATA_REL_ID
        primary key (ID)
    /

create table FORM_TABLE_FIELD
(
    ID          NUMBER                        not null,
    FIELD_ID    NUMBER                        not null,
    IS_INDEX    VARCHAR2(10 char) default '0' not null,
    COLUMN_NAME VARCHAR2(64 char)             not null,
    TENANT_KEY  VARCHAR2(20 char)             not null,
    TYPE_LEN    NUMBER(5)                     not null,
    COLUMN_TYPE VARCHAR2(20 char)             not null,
    DYNAMIC     VARCHAR2(20 char)
)
    /

comment on column FORM_TABLE_FIELD.IS_INDEX is '列是否已有索引 索引类型'
/

comment on column FORM_TABLE_FIELD.COLUMN_NAME is '用户定义的列名，用户未定义则填充默认列名'
/

comment on column FORM_TABLE_FIELD.TYPE_LEN is '类型长度'
/

comment on column FORM_TABLE_FIELD.COLUMN_TYPE is '列类型'
/

comment on column FORM_TABLE_FIELD.DYNAMIC is '列对应的数据长度（日期类型）'
/

create unique index UNX_FORM_TABLE_FIELD_FIELD_ID
    on FORM_TABLE_FIELD (FIELD_ID)
    /

create unique index UNX_FORM_TABLE_FIELD_ID
    on FORM_TABLE_FIELD (ID)
    /

alter table FORM_TABLE_FIELD
    add constraint PRIMARY_FORM_TABLE_FIELD_ID
        primary key (ID)
    /

create table FORM_TABLE_REL
(
    ID          NUMBER                not null,
    FORM_ID     NUMBER                not null,
    SUB_FORM_ID NUMBER                not null,
    OPERATOR    VARCHAR2(64 char)     not null,
    TENANT_KEY  VARCHAR2(20 char)     not null,
    CREATE_TIME DATE                  not null,
    UPDATE_TIME DATE,
    IS_DELETE   NUMBER(3) default '0' not null
)
    /

comment on column FORM_TABLE_REL.FORM_ID is '主表ID'
/

comment on column FORM_TABLE_REL.SUB_FORM_ID is '子表ID'
/

comment on column FORM_TABLE_REL.IS_DELETE is '是否删除  0：未删除 1：已删除'
/

create unique index UK_FORM_TABLE_REL_ID
    on FORM_TABLE_REL (ID)
    /

create index IDX_FORM_TABLE_REL_FORM_ID
    on FORM_TABLE_REL (FORM_ID)
    /

create index IDX_FORM_TABLE_REL_SUB_FORM_ID
    on FORM_TABLE_REL (SUB_FORM_ID)
    /

alter table FORM_TABLE_REL
    add constraint PRIMARY_FORM_TABLE_REL_ID
        primary key (ID)
    /

create table FORMDATA
(
    ID          NUMBER not null
        primary key,
    FORM_ID     NUMBER,
    LAYOUT_ID   NUMBER,
    DATA_STATUS VARCHAR2(50),
    TENANT_KEY  VARCHAR2(10),
    OPERATOR    NUMBER,
    CREATE_TIME DATE,
    UPDATE_TIME DATE,
    MODULE      VARCHAR2(50),
    CLIENT      VARCHAR2(50),
    VERSION     VARCHAR2(50),
    SPENT_TIME  NUMBER,
    IP          VARCHAR2(50),
    NAME        VARCHAR2(800),
    IS_DELETE   NUMBER default 0
)
    /

create index IDX_FORMDATA_TENANT_KEY
    on FORMDATA (TENANT_KEY)
    /

create index IDX_FORMDATA_FORMID
    on FORMDATA (FORM_ID)
    /

create index IDX_FORMDATA_LAYOUTID
    on FORMDATA (LAYOUT_ID)
    /

create index IDX_FORMDATA_OPERATOR
    on FORMDATA (OPERATOR)
    /

create index IDX_FORMDATA_MODULE
    on FORMDATA (MODULE)
    /

create index IDX_FORMDATA_DATASTATUS
    on FORMDATA (DATA_STATUS)
    /

create index IDX_FORMDATA_IS_DELETE
    on FORMDATA (IS_DELETE)
    /

create table FORMDATA_DETAIL
(
    ID            NUMBER not null
        primary key,
    FORM_DATA     NUMBER,
    FIELD_ID      NUMBER,
    SUB_FORM_ID   NUMBER,
    LAYOUT_ID     NUMBER,
    DATA_INDEX    NUMBER,
    CONTENT       VARCHAR2(500),
    TENANT_KEY    VARCHAR2(10),
    OPERATOR      NUMBER,
    CREATE_TIME   DATE,
    TYPE          VARCHAR2(50),
    STAT_DESCRIBE VARCHAR2(50),
    LONGITUDE     NUMBER,
    LATITUDE      NUMBER
)
    /

create index IDX_FORMDATA_DETAIL_TENANT_KEY
    on FORMDATA_DETAIL (TENANT_KEY)
    /

create index IDX_FORMDATA_DETAIL_FORMDATA
    on FORMDATA_DETAIL (FORM_DATA)
    /

create index IDX_FORMDATA_DETAIL_FIELDID
    on FORMDATA_DETAIL (FIELD_ID)
    /

create index IDX_FORMDATA_DETAIL_SUB_FORM_I
    on FORMDATA_DETAIL (SUB_FORM_ID)
    /

create index IDX_FORMDATA_DETAIL_CONTENT
    on FORMDATA_DETAIL (CONTENT)
    /

create table FORMDATA_OPTION
(
    ID           NUMBER not null
        primary key,
    DATA_DETAILS NUMBER,
    OPTION_ID    VARCHAR2(200),
    CONTENT      VARCHAR2(200),
    TENANT_KEY   VARCHAR2(10),
    TYPE         VARCHAR2(20),
    TARGET_ID    NUMBER(38)
)
    /

create index IDX_FORMDATA_OPTION_TENANT_KEY
    on FORMDATA_OPTION (TENANT_KEY)
    /

create index IDX_FORMDATA_OPTION_DATADETAIL
    on FORMDATA_OPTION (DATA_DETAILS)
    /

create index IDX_FORMDATA_OPTION_OPTION_ID
    on FORMDATA_OPTION (OPTION_ID)
    /

create table FORMDATA_TEXT
(
    ID           NUMBER not null
        primary key,
    DATA_DETAILS NUMBER,
    CONTENT      CLOB,
    TENANT_KEY   VARCHAR2(10),
    RICH_CONTENT CLOB
)
    /

create index IDX_FORMDATA_TEXT_TENANT_KEY
    on FORMDATA_TEXT (TENANT_KEY)
    /

create index IDX_FORMDATA_TEXT_DATADETAILS
    on FORMDATA_TEXT (DATA_DETAILS)
    /

create table FORM_FIELD_GROUP
(
    ID          NUMBER(20)   not null
        primary key,
    GROUP_NAME  VARCHAR2(64) not null,
    ICON        VARCHAR2(64),
    OPERATOR    NUMBER(20)   not null,
    IS_DELETE   NUMBER,
    TENANT_KEY  VARCHAR2(10),
    CREATE_TIME DATE         not null,
    UPDATE_TIME DATE,
    FORM_ID     NUMBER(20)   not null,
    SHOW_ORDER  FLOAT default 0
)
    /

create index IDX_FORM_FIELD_GROUP_TK
    on FORM_FIELD_GROUP (TENANT_KEY)
    /

create index IDX_FORM_FIELD_GROUP_NAME
    on FORM_FIELD_GROUP (GROUP_NAME)
    /

create index IDX_FORM_FIELD_GROUP_FI_TK
    on FORM_FIELD_GROUP (FORM_ID, TENANT_KEY)
    /

create table FORM_OPTION_TEMPLATE_CONFIG
(
    ID              NUMBER       not null primary key,
    CREATE_TIME     DATE         not null,
    UPDATE_TIME     DATE,
    CREATOR         NUMBER       not null,
    DELETE_TYPE     NUMBER       not null,
    TENANT_KEY      VARCHAR2(10) not null,
    FORM_ID         NUMBER       not null,
    FIELD_ID        NUMBER       not null,
    TEMPLATE_ID     NUMBER       not null,
    INHERITED_TYPE  VARCHAR2(10) not null,
    DROP_DOWN_LEVEL CHAR         not null,
    PARENT_FIELD    NUMBER
)
    /

create index IDX_FOTC_FIELD_ID
    on FORM_OPTION_TEMPLATE_CONFIG (FIELD_ID)
    /

create index IDX_FOTC_FORM_ID
    on FORM_OPTION_TEMPLATE_CONFIG (FORM_ID)
    /

create index IDX_FOTC_TENANT_KEY
    on FORM_OPTION_TEMPLATE_CONFIG (TENANT_KEY)
    /

create table FORM_OPTION_SUB_FILTER_CONFIG
(
    ID             NUMBER,
    CREATE_TIME    DATE         not null primary key,
    UPDATE_TIME    DATE,
    CREATOR        NUMBER       not null,
    DELETE_TYPE    NUMBER       not null,
    TENANT_KEY     VARCHAR2(10) not null,
    MAIN_FIELD     NUMBER       not null,
    SUB_FIELD      NUMBER       not null,
    FORM_ID        NUMBER       not null,
    OPTION_IDS     CLOB,
    MAIN_OPTION_ID NUMBER       not null
)
    /

create index IDX_FOSFC_TENANT_KEY
    on FORM_OPTION_SUB_FILTER_CONFIG (TENANT_KEY)
    /

create index IDX_FOSFC_FORM_ID
    on FORM_OPTION_SUB_FILTER_CONFIG (FORM_ID)
    /

create index IDX_FOSFC_MAIN_FIELD
    on FORM_OPTION_SUB_FILTER_CONFIG (MAIN_FIELD)
    /

create index IDX_FOSFC_SUB_FIELD
    on FORM_OPTION_SUB_FILTER_CONFIG (SUB_FIELD)
    /

create unique index IDX_FOSFC_MF_SF_MOI
    on FORM_OPTION_SUB_FILTER_CONFIG (MAIN_FIELD, SUB_FIELD, MAIN_OPTION_ID)
    /

create table FORM_ATTACHMENT_CONFIG
(
    ID                    NUMBER not null
        primary key,
    CREATE_TIME           DATE,
    UPDATE_TIME           DATE,
    CREATOR               NUMBER,
    DELETE_TYPE           NUMBER default 0,
    TENANT_KEY            VARCHAR2(10),
    REF_ID                NUMBER,
    FOLDER_SELECT_TYPE    NUMBER default 0,
    FOLDER_ID             NUMBER,
    CUSTOM_LIMIT_FORMAT   VARCHAR2(500),
    ATTMENT_SIZE_LIMIT    NUMBER default 3,
    CUSTOM_ATTMENT_SIZE   VARCHAR2(20),
    FORBIN_BATCH_DOWNLOAD NUMBER default 0,
    SEC_LEVEL             NUMBER default 1,
    SHOW_FORMAT           NUMBER default 0,
    ATTACH_UPLOAD_USER    NUMBER,
    ATTACH_UPLOAD_TIME    CHAR(8),
    CONFIG_TYPE           NUMBER,
    FORM_ID               NUMBER,
    FIELD_ID              NUMBER,
    FOLDER_TYPE           NUMBER default 0,
    LIMIT_TYPE            NUMBER default 0,
    OTHER_TYPE            NUMBER default 0,
    OPTION_ID             NUMBER
)
    /

create index IDX_FORM_ATTACHMENT_CONFIG_FMI
    on FORM_ATTACHMENT_CONFIG (FIELD_ID)
    /

create index IDX_FORM_ATTACHMENT_CONFIG_FDI
    on FORM_ATTACHMENT_CONFIG (FORM_ID)
    /

create index IDX_FORM_ATTACHMENT_CONFIG_TK
    on FORM_ATTACHMENT_CONFIG (TENANT_KEY)
    /

create table FORM_DATA_RELATE_CONFIG
(
    ID               NUMBER not null
        primary key,
    CREATE_TIME      DATE,
    UPDATE_TIME      DATE,
    OPERATOR         NUMBER,
    TENANT_KEY       VARCHAR2(10),
    FIELD_ID         NUMBER(38),
    EXPRESS_ID       NUMBER,
    MONITOR_FIELDS   CLOB,
    RELATE_FIELD     CLOB,
    RELATE_DATATABLE CLOB,
    RELATE_MULTIPLE  VARCHAR2(1),
    VERSION_ID       NUMBER(38),
    IS_DELETE        NUMBER,
    DELETE_TYPE      NUMBER
)
    /

create index IDX_FDRC_TENANT_KEY
    on FORM_DATA_RELATE_CONFIG (TENANT_KEY)
    /

create index IDX_FDRC_FIELD_ID
    on FORM_DATA_RELATE_CONFIG (FIELD_ID)
    /

create index IDX_FDRC_VERSION_ID
    on FORM_DATA_RELATE_CONFIG (VERSION_ID)
    /

create table FORM_VIEW_RELATE_CONFIG
(
    ID                 NUMBER not null primary key,
    CREATE_TIME        DATE,
    UPDATE_TIME        DATE,
    OPERATOR           NUMBER,
    DELETE_TYPE        NUMBER,
    TENANT_KEY         VARCHAR2(10),
    FIELD_ID           NUMBER(38),
    DISPLAY            VARCHAR2(1),
    READONLY           VARCHAR2(1),
    REQUIRED           VARCHAR2(1),
    DISPLAY_CONDITION  CLOB,
    READONLY_CONDITION CLOB,
    REQUIRED_CONDITION CLOB,
    VERSION_ID         NUMBER(38),
    IS_DELETE          NUMBER,
    DISABLE_EDIT       VARCHAR2(1),
    SINGLE_ROW         VARCHAR2(1),
    SHOW_ORDER         NUMBER default 0
)
    /

create index IDX_FVRC_FIELD_ID
    on FORM_VIEW_RELATE_CONFIG (FIELD_ID)
    /

create index IDX_FVRC_TENANT_KEY
    on FORM_VIEW_RELATE_CONFIG (TENANT_KEY)
    /

create index IDX_FVRC_VERSION_ID
    on FORM_VIEW_RELATE_CONFIG (VERSION_ID)
    /

create table FORMDATA_RECORD_LOG
(
    ID             NUMBER not null
        primary key,
    CREATE_TIME    DATE,
    TENANT_KEY     VARCHAR2(10),
    FORM_DATA_ID   NUMBER,
    DEVICE         VARCHAR2(500),
    OPERATOR_ID    NUMBER,
    MODULE_SOURCE  VARCHAR2(100),
    OPERATION_TYPE VARCHAR2(100),
    REF_ID         VARCHAR2(100),
    TERMINAL       VARCHAR2(50)
)
    /

create index IDX_FORMDATA_RECORD_LOG_FDI_RI
    on FORMDATA_RECORD_LOG (FORM_DATA_ID, REF_ID)
    /

create index IDX_FORMDATA_RECORD_LOG_TK
    on FORMDATA_RECORD_LOG (TENANT_KEY)
    /

create table FORM_DATA_DETAILS_ENCDATA
(
    ID         NUMBER         not null primary key ,
    TENANT_KEY VARCHAR2(10)   not null,
    TABLE_NAME VARCHAR2(50)   not null,
    FIELD_NAME VARCHAR2(50)   not null,
    ENC_VALUE  VARCHAR2(4000) not null,
    CRC        VARCHAR2(4000),
    CREATER    NUMBER,
    CREATED    DATE,
    MODIFIER   NUMBER,
    MODIFIED   DATE,
    SKEY       VARCHAR2(2000) not null
)
    /

create index IDX_FD_DETAILS_ENCDATA_TK
    on FORM_DATA_DETAILS_ENCDATA (TENANT_KEY)
    /

create index IDX_FD_DETAILS_ENCDATA_TN
    on FORM_DATA_DETAILS_ENCDATA (TABLE_NAME)
    /

create index IDX_FD_DETAILS_ENCDATA_FN
    on FORM_DATA_DETAILS_ENCDATA (FIELD_NAME)
    /

create table FORM_FIELDMANAGELOGS
(
    ID              NUMBER not null primary key ,
    CREATE_TIME     DATE       default sysdate,
    UPDATE_TIME     DATE       default sysdate,
    CREATOR         NUMBER     default -1,
    DELETE_TYPE     NUMBER     default (0),
    TENANT_KEY      VARCHAR2(10),
    UUID            VARCHAR2(36),
    LOG_DATE        DATE       default sysdate,
    LOG_OPERATOR    NUMBER(24),
    OPERATORNAME    VARCHAR2(50),
    TARGETID        NUMBER(24) default (-1),
    TARGETNAME      VARCHAR2(4000),
    MODULENAME      VARCHAR2(100),
    FUNCTIONNAME    VARCHAR2(100),
    INTERFACENAME   VARCHAR2(100),
    REQUESTURL      VARCHAR2(200),
    REQUESTURI      VARCHAR2(200),
    OPERATETYPE     VARCHAR2(50),
    OPERATETYPENAME VARCHAR2(100),
    OPERATEDESC     VARCHAR2(1000),
    PARAMS          CLOB,
    BELONGMAINID    VARCHAR2(36),
    CLIENTIP        VARCHAR2(200),
    GROUPID         VARCHAR2(50),
    DEVICE          VARCHAR2(200),
    GROUPNAMELABEL  VARCHAR2(500),
    REDOSERVICE     VARCHAR2(200),
    REDOCONTEXT     VARCHAR2(4000),
    CANCELSERVICE   VARCHAR2(200),
    CANCELCONTEXT   VARCHAR2(4000),
    TOTALRUNTIME    NUMBER     default (0),
    MAINRUNTIME     NUMBER     default (0),
    LOG_RESULT      VARCHAR2(4000),
    FROMTERMINAL    VARCHAR2(100),
    RESULTDESC      VARCHAR2(4000),
    OLD_CONTENT     VARCHAR2(1000),
    LINK_TYPE       VARCHAR2(20),
    LINK_ID         NUMBER     default (0),
    OLD_LINK_ID     NUMBER     default (0)
)
    /

comment on column FORM_FIELDMANAGELOGS.ID is 'ID'
/

comment on column FORM_FIELDMANAGELOGS.CREATE_TIME is '创建时间'
/

comment on column FORM_FIELDMANAGELOGS.UPDATE_TIME is '修改时间'
/

comment on column FORM_FIELDMANAGELOGS.CREATOR is '创建人id'
/

comment on column FORM_FIELDMANAGELOGS.DELETE_TYPE is '是否删除'
/

comment on column FORM_FIELDMANAGELOGS.TENANT_KEY is '租户id'
/

comment on column FORM_FIELDMANAGELOGS.UUID is '日志UUID'
/

comment on column FORM_FIELDMANAGELOGS.LOG_DATE is '操作时间'
/

comment on column FORM_FIELDMANAGELOGS.LOG_OPERATOR is '操作人'
/

comment on column FORM_FIELDMANAGELOGS.OPERATORNAME is '操作人姓名'
/

comment on column FORM_FIELDMANAGELOGS.TARGETID is '操作目标id'
/

comment on column FORM_FIELDMANAGELOGS.MODULENAME is '模块'
/

comment on column FORM_FIELDMANAGELOGS.FUNCTIONNAME is '服务（方法）'
/

comment on column FORM_FIELDMANAGELOGS.INTERFACENAME is '访问接口名'
/

comment on column FORM_FIELDMANAGELOGS.REQUESTURL is '请求全路径'
/

comment on column FORM_FIELDMANAGELOGS.REQUESTURI is '请求地址'
/

comment on column FORM_FIELDMANAGELOGS.OPERATETYPE is '操作类型'
/

comment on column FORM_FIELDMANAGELOGS.OPERATETYPENAME is '操作类型名称'
/

comment on column FORM_FIELDMANAGELOGS.OPERATEDESC is '操作详细说明'
/

comment on column FORM_FIELDMANAGELOGS.PARAMS is '涉及的相关参数'
/

comment on column FORM_FIELDMANAGELOGS.BELONGMAINID is '所属主表uuid'
/

comment on column FORM_FIELDMANAGELOGS.CLIENTIP is '操作IP'
/

comment on column FORM_FIELDMANAGELOGS.GROUPID is '分组'
/

comment on column FORM_FIELDMANAGELOGS.DEVICE is '终端信息'
/

comment on column FORM_FIELDMANAGELOGS.GROUPNAMELABEL is '分组标题'
/

comment on column FORM_FIELDMANAGELOGS.REDOSERVICE is '重做业务接口'
/

comment on column FORM_FIELDMANAGELOGS.REDOCONTEXT is '重做参数'
/

comment on column FORM_FIELDMANAGELOGS.CANCELSERVICE is '撤销业务接口'
/

comment on column FORM_FIELDMANAGELOGS.CANCELCONTEXT is '撤销参数'
/

comment on column FORM_FIELDMANAGELOGS.TOTALRUNTIME is '总运行时长'
/

comment on column FORM_FIELDMANAGELOGS.MAINRUNTIME is '主方法运行时长'
/

comment on column FORM_FIELDMANAGELOGS.LOG_RESULT is '运行结果标识'
/

comment on column FORM_FIELDMANAGELOGS.FROMTERMINAL is '来自pc web'
/

comment on column FORM_FIELDMANAGELOGS.OLD_CONTENT is '原先内容'
/

comment on column FORM_FIELDMANAGELOGS.LINK_TYPE is '链接类型'
/

comment on column FORM_FIELDMANAGELOGS.LINK_ID is '链接id'
/

comment on column FORM_FIELDMANAGELOGS.OLD_LINK_ID is '原先链接id'
/

create index IDX_FORM_FIELDMANAGELOGS_LD
    on FORM_FIELDMANAGELOGS (LOG_DATE)
    /

create index IDX_FORM_FIELDMANAGELOGS_MN
    on FORM_FIELDMANAGELOGS (MODULENAME)
    /

create index IDX_FORM_FIELDMANAGELOGS_TK
    on FORM_FIELDMANAGELOGS (TENANT_KEY)
    /

create index IDX_FORM_FIELDMANAGELOGS_U
    on FORM_FIELDMANAGELOGS (UUID)
    /

create index IDX_FORM_FIELDMANAGELOGS_OTN
    on FORM_FIELDMANAGELOGS (OPERATETYPENAME)
    /

create index IDX_FORM_FIELDMANAGELOGS_LO
    on FORM_FIELDMANAGELOGS (LOG_OPERATOR)
    /

create index IDX_FORM_FIELDMANAGELOGS_ON
    on FORM_FIELDMANAGELOGS (OPERATORNAME)
    /

create index IDX_FORM_FIELDMANAGELOGS_TN
    on FORM_FIELDMANAGELOGS (TARGETNAME)
    /

create index IDX_FORM_FIELDMANAGELOGS_FN
    on FORM_FIELDMANAGELOGS (FUNCTIONNAME)
    /

create index IDX_FORM_FIELDMANAGELOGS_TI
    on FORM_FIELDMANAGELOGS (TARGETID)
    /

create table FORM_FIELDMANAGELOGS_DETAIL
(
    ID               NUMBER not null
        primary key,
    CREATE_TIME      DATE          default sysdate,
    UPDATE_TIME      DATE          default sysdate,
    CREATOR          NUMBER        default '-1',
    DELETE_TYPE      NUMBER        default '0',
    TENANT_KEY       VARCHAR2(10),
    UUID             VARCHAR2(36),
    MAINID           VARCHAR2(36),
    DATAID           VARCHAR2(50),
    BELONGDATAID     VARCHAR2(50),
    TABLENAME        VARCHAR2(200),
    TABLENAMELABELID VARCHAR2(50)  default '-1',
    TABLENAMEDESC    VARCHAR2(50),
    FIELDNAME        VARCHAR2(200),
    FIELDNAMELABELID VARCHAR2(200) default -1,
    NEWVALUE         VARCHAR2(4000),
    OLDVALUE         VARCHAR2(4000),
    NEWREALVALUE     VARCHAR2(4000),
    OLDREALVALUE     VARCHAR2(4000),
    FIELDDESC        VARCHAR2(200),
    SHOWORDER        NUMBER        default 0,
    ISDETAIL         NUMBER        default 0,
    TEMPLATEID       VARCHAR2(50),
    TEMPLATE_CONTENT VARCHAR2(1000)
)
    /

comment on column FORM_FIELDMANAGELOGS_DETAIL.CREATE_TIME is '创建时间'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.UPDATE_TIME is '修改时间'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.CREATOR is '创建人id'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.DELETE_TYPE is '是否删除'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.TENANT_KEY is '租户id'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.UUID is '日志UUID'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.MAINID is '主表id'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.DATAID is '数据id'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.BELONGDATAID is '主表数据id'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.TABLENAME is '表名'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.TABLENAMELABELID is '表名labelid'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.TABLENAMEDESC is '对应数据库的表'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.FIELDNAME is '字段名'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.FIELDNAMELABELID is '字段名labelid'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.FIELDDESC is '字段名'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.SHOWORDER is '字段名'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.ISDETAIL is '是否明细字段'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.TEMPLATEID is '模板Id'
/

comment on column FORM_FIELDMANAGELOGS_DETAIL.TEMPLATE_CONTENT is '模板内容'
/

create index IDX_F_FMANAGELOGS_DETAIL_MI
    on FORM_FIELDMANAGELOGS_DETAIL (MAINID)
    /

create index IDX_F_FIELDMANAGELOGS_TK
    on FORM_FIELDMANAGELOGS_DETAIL (TENANT_KEY)
    /

create index IDX_F_FIELDMANAGELOGS_U
    on FORM_FIELDMANAGELOGS_DETAIL (UUID)
    /

create index IDX_F_FIELDMANAGELOGS_U_MI
    on FORM_FIELDMANAGELOGS_DETAIL (UUID, MAINID)
    /

create table FD_LINKAGE_SOURCE_SQL
(
    ID          NUMBER not null primary key ,
    ENTITY_ID   NUMBER,
    SQL_CONTEXT CLOB,
    SQL_SCRIPT  CLOB,
    TENANT_KEY  VARCHAR2(50)
)
    /

create index IDX_FD_LINKAGE_SOURCE_SQL_TK
    on FD_LINKAGE_SOURCE_SQL (TENANT_KEY)
    /

create index IDX_FD_LINKAGE_SOURCE_SQL_EI
    on FD_LINKAGE_SOURCE_SQL (ENTITY_ID)
    /

create table FD_LINKAGE_SOURCE_SQL_COLUMN
(
    ID           NUMBER not null primary key ,
    ENTITY_ID    NUMBER,
    SOURCE_FIELD VARCHAR2(50),
    SOURCE_NAME  VARCHAR2(200),
    TENANT_KEY   VARCHAR2(50)
)
    /

create index IDX_FD_LA_SOURCE_SQL_COLUMN_TK
    on FD_LINKAGE_SOURCE_SQL_COLUMN (TENANT_KEY)
    /

create index IDX_FD_LA_SOURCE_SQL_COLUMN_EI
    on FD_LINKAGE_SOURCE_SQL_COLUMN (ENTITY_ID)
    /

create table FD_LINKAGE_SOURCE_MAPPING
(
    ID                  NUMBER not null primary key ,
    ENTITY_ID           NUMBER,
    SOURCE_FIELD        VARCHAR2(50),
    SOURCE_NAME         VARCHAR2(200),
    HANDLE_MARK         VARCHAR2(20),
    TARGET_FIELD        VARCHAR2(50),
    TARGET_NAME         VARCHAR2(200),
    TARGET_TYPE         VARCHAR2(50),
    TARGET_ADDRESS      VARCHAR2(200),
    TARGET_ADDRESS_TYPE VARCHAR2(50),
    TENANT_KEY          VARCHAR2(50)
)
    /

create index IDX_FD_LA_SOURCE_MAPPING_TK
    on FD_LINKAGE_SOURCE_MAPPING (TENANT_KEY)
    /

create index IDX_FD_LA_SOURCE_MAPPING_EI
    on FD_LINKAGE_SOURCE_MAPPING (ENTITY_ID)
    /

create table FD_LINKAGE_SOURCE_EXCEL
(
    ID         NUMBER not null primary key ,
    ENTITY_ID  NUMBER,
    EXCEL_ID   NUMBER,
    EXCEL_NAME VARCHAR2(200),
    TENANT_KEY VARCHAR2(50)
)
    /

create index IDX_FD_LA_SOURCE_EXCEL_TK
    on FD_LINKAGE_SOURCE_EXCEL (TENANT_KEY)
    /

create index IDX_FD_LA_SOURCE_EXCEL_EI
    on FD_LINKAGE_SOURCE_EXCEL (ENTITY_ID)
    /

create table FD_LINKAGE_SOURCE_CONFIG_TABLE
(
    ID              NUMBER not null primary key ,
    ENTITY_ID       NUMBER,
    SOURCE_FIELD    VARCHAR2(20),
    SOURCE_NAME     VARCHAR2(200),
    TABLE_TITLE     VARCHAR2(200),
    TABLE_NICK_NAME VARCHAR2(200),
    JOIN_TYPE       VARCHAR2(200),
    JOIN_CONDITION  CLOB,
    TENANT_KEY      VARCHAR2(50)
)
    /

create index IDX_FD_LA_SE_CONFIG_TABLE_TK
    on FD_LINKAGE_SOURCE_CONFIG_TABLE (TENANT_KEY)
    /

create index IDX_FD_LA_SE_CONFIG_TABLE_EI
    on FD_LINKAGE_SOURCE_CONFIG_TABLE (ENTITY_ID)
    /

create table FD_LINKAGE_SOURCE_CONFIG_COL
(
    ID             NUMBER not null primary key ,
    ENTITY_ID      NUMBER,
    COLUMN_TABLE   VARCHAR2(50),
    COLUMN_TYPE    VARCHAR2(50),
    COLUMN_FIELD   VARCHAR2(50),
    COLUMN_TITLE   VARCHAR2(50),
    OPERATE        VARCHAR2(20),
    SOURCE_TYPE    VARCHAR2(20),
    SOURCE_FIELD   VARCHAR2(50),
    SOURCE_NAME    VARCHAR2(50),
    SOURCE_CONTENT CLOB,
    TENANT_KEY     VARCHAR2(50)
)
    /

create index IDX_FD_LA_SOURCE_CONFIG_COL_TK
    on FD_LINKAGE_SOURCE_CONFIG_COL (TENANT_KEY)
    /

create index IDX_FD_LA_SOURCE_CONFIG_COL_EI
    on FD_LINKAGE_SOURCE_CONFIG_COL (ENTITY_ID)
    /

create table FD_LINKAGE_SOURCE_CONFIG
(
    ID              NUMBER not null primary key ,
    ENTITY_ID       NUMBER,
    WHERE_CONDITION CLOB,
    ORDER_CONDITION CLOB,
    TENANT_KEY      VARCHAR2(50)
)
    /

create index IDX_FD_LA_SOURCE_CONFIG_TK
    on FD_LINKAGE_SOURCE_CONFIG (TENANT_KEY)
    /

create index IDX_FD_LA_SOURCE_CONFIG_EI
    on FD_LINKAGE_SOURCE_CONFIG (ENTITY_ID)
    /

create table FD_LINKAGE_SOURCE
(
    ID                  NUMBER not null primary key ,
    ENTITY_ID           NUMBER,
    LINKAGE_TYPE        VARCHAR2(50),
    DATA_SOURCE_ID      NUMBER,
    DATA_SOURCE_NAME    VARCHAR2(200),
    DATA_SOURCE_DB_TYPE VARCHAR2(200),
    DATA_TYPE           VARCHAR2(50),
    TENANT_KEY          VARCHAR2(50)
)
    /

create index IDX_FD_LINKAGE_SOURCE_TK
    on FD_LINKAGE_SOURCE (TENANT_KEY)
    /

create index IDX_FD_LINKAGE_SOURCE_EI
    on FD_LINKAGE_SOURCE (ENTITY_ID)
    /

create table FD_LINKAGE_MONITOR_FIELD
(
    ID           NUMBER not null primary key ,
    ENTITY_ID    NUMBER,
    TARGET_FIELD VARCHAR2(50),
    TARGET_NAME  VARCHAR2(200),
    TENANT_KEY   VARCHAR2(50)
)
    /

create index IDX_FD_LA_MONITOR_FIELD_TK
    on FD_LINKAGE_MONITOR_FIELD (TENANT_KEY)
    /

create index IDX_FD_LA_MONITOR_FIELD_EI
    on FD_LINKAGE_MONITOR_FIELD (ENTITY_ID)
    /

create table FD_LINKAGE_MONITOR_ACTION
(
    ID          NUMBER not null primary key ,
    ENTITY_ID   NUMBER,
    ACTION_TYPE VARCHAR2(200),
    ACTION_NAME VARCHAR2(200),
    TENANT_KEY  VARCHAR2(50)
)
    /

create index IDX_FD_LA_MONITOR_ACTION_TK
    on FD_LINKAGE_MONITOR_ACTION (TENANT_KEY)
    /

create index IDX_FD_LA_MONITOR_ACTION_EI
    on FD_LINKAGE_MONITOR_ACTION (ENTITY_ID)
    /

create table FD_LINKAGE_EXT
(
    ID                 NUMBER not null primary key ,
    ENTITY_ID          NUMBER,
    SUB_FORM_LIKE_TYPE VARCHAR2(50),
    SUB_FORM_ADD_TYPE  VARCHAR2(50),
    EFFECT_CONTENT     CLOB,
    TENANT_KEY         VARCHAR2(50)
)
    /

create index IDX_FD_LINKAGE_EXT_TK
    on FD_LINKAGE_EXT (TENANT_KEY)
    /

create index IDX_FD_LINKAGE_EXT_EI
    on FD_LINKAGE_EXT (ENTITY_ID)
    /

create table FD_LINKAGE
(
    ID             NUMBER not null primary key ,
    LINKAGE_NAME   VARCHAR2(255),
    LINKAGE_MODULE VARCHAR2(255),
    FORM_ID        NUMBER default '0',
    REF_ID         NUMBER default '0',
    LINKAGE_STATE  NUMBER,
    LINKAGE_TYPE   VARCHAR2(255),
    CREATOR        NUMBER,
    CREATE_TIME    DATE,
    UPDATE_TIME    DATE,
    TENANT_KEY     VARCHAR2(50)
)
    /

create index IDX_FD_LINKAGE_TENANT_KEY
    on FD_LINKAGE (TENANT_KEY)
    /

create index IDX_FD_LINKAGE_FORM_ID
    on FD_LINKAGE (FORM_ID)
    /

create index IDX_FD_LINKAGE_REF_ID
    on FD_LINKAGE (REF_ID)
    /

create table FD_EFFECT_VALUE
(
    ID           NUMBER not null primary key ,
    EFFECT_ID    NUMBER,
    EFFECT_VALUE VARCHAR2(255),
    EFFECT_NAME  VARCHAR2(255),
    TENANT_KEY   VARCHAR2(50)
)
    /

create index IDX_FD_EFFECT_VALUE_TENANT_KEY
    on FD_EFFECT_VALUE (TENANT_KEY)
    /

create index IDX_FD_EFFECT_VALUE_EFFECT_ID
    on FD_EFFECT_VALUE (EFFECT_ID)
    /

create index IDX_FD_EFFECT_VALUE_EV
    on FD_EFFECT_VALUE (EFFECT_VALUE)
    /

create table FD_EFFECT
(
    ID            NUMBER not null primary key ,
    CREATE_TIME   DATE,
    UPDATE_TIME   DATE,
    CREATOR       NUMBER,
    DELETE_TYPE   NUMBER default 0,
    REF_ID        VARCHAR2(50),
    FORM_ID       NUMBER,
    EFFECT_TYPE   VARCHAR2(50),
    EFFECT_NAME   VARCHAR2(200),
    EFFECT_MODULE VARCHAR2(50),
    TENANT_KEY    VARCHAR2(50)
)
    /

create index IDX_FD_EFFECT_TENANT_KEY
    on FD_EFFECT (TENANT_KEY)
    /

create index IDX_FD_EFFECT_REF_ID
    on FD_EFFECT (REF_ID)
    /

create index IDX_FD_EFFECT_FORM_ID
    on FD_EFFECT (FORM_ID)
    /

create table SUB_FORM_CONFIG
(
    ID               NUMBER not null primary key ,
    CREATE_TIME      DATE,
    UPDATE_TIME      DATE,
    DELETE_TYPE      NUMBER default 0,
    TENANT_KEY       VARCHAR2(10),
    SUB_FORM_ID      NUMBER,
    DEFAULT_ROWS     NUMBER,
    MAX_ROWS         NUMBER,
    REQUIRED_ROWS    NUMBER,
    FILTER_CONDITION CLOB,
    OTHER_PROPERTIES CLOB,
    VERSION_ID       NUMBER,
    CREATOR          NUMBER
)
    /

create index IDX_SUB_FORM_CONFIG_TENANT_KEY
    on SUB_FORM_CONFIG (TENANT_KEY)
    /

create index IDX_SUB_FORM_CONFIG_SUB_FORM_I
    on SUB_FORM_CONFIG (SUB_FORM_ID)
    /

create index IDX_SUB_FORM_CONFIG_VERSION_ID
    on SUB_FORM_CONFIG (VERSION_ID)
    /

create table FORM_SETTING_LOGS_DETAIL
(
    ID               NUMBER not null
        primary key,
    CREATE_TIME      DATE   default sysdate,
    UPDATE_TIME      DATE   default sysdate,
    CREATOR          NUMBER,
    DELETE_TYPE      NUMBER default 0,
    TENANT_KEY       VARCHAR2(10),
    UUID             VARCHAR2(36),
    MAINID           VARCHAR2(36),
    DATAID           VARCHAR2(50),
    BELONGDATAID     VARCHAR2(50),
    TABLENAME        VARCHAR2(200),
    TABLENAMELABELID VARCHAR2(50),
    TABLENAMEDESC    VARCHAR2(50),
    FIELDNAME        VARCHAR2(200),
    FIELDNAMELABELID VARCHAR2(50),
    NEWVALUE         CLOB,
    OLDVALUE         CLOB,
    NEWREALVALUE     CLOB,
    OLDREALVALUE     CLOB,
    FIELDDESC        VARCHAR2(200),
    SHOWORDER        NUMBER,
    ISDETAIL         NUMBER default 0
)
    /

create index IDX_F_SETTING_LOGS_DETAIL_TK
    on FORM_SETTING_LOGS_DETAIL (TENANT_KEY)
    /

create index IDX_F_SETTING_LOGS_DETAIL_MI
    on FORM_SETTING_LOGS_DETAIL (MAINID)
    /

create table FORM_SETTING_LOGS
(
    ID              NUMBER not null
        primary key,
    CREATE_TIME     DATE   default sysdate,
    UPDATE_TIME     DATE   default sysdate,
    CREATOR         NUMBER,
    DELETE_TYPE     NUMBER default 0,
    TENANT_KEY      VARCHAR2(10),
    UUID            VARCHAR2(36),
    LOG_DATE        DATE   default sysdate,
    DEVICE          VARCHAR2(500),
    LOG_OPERATOR    NUMBER,
    OPERATORNAME    VARCHAR2(100),
    TARGETID        NUMBER,
    TARGETNAME      VARCHAR2(3000),
    MODULENAME      VARCHAR2(100),
    FUNCTIONNAME    VARCHAR2(100),
    INTERFACENAME   VARCHAR2(100),
    REQUESTURL      CLOB,
    REQUESTURI      CLOB,
    OPERATETYPE     VARCHAR2(50),
    OPERATETYPENAME VARCHAR2(100),
    OPERATEDESC     VARCHAR2(3000),
    PARAMS          CLOB,
    BELONGMAINID    VARCHAR2(36),
    CLIENTIP        VARCHAR2(200),
    GROUPID         VARCHAR2(50),
    GROUPNAMELABEL  VARCHAR2(1000),
    REDOSERVICE     VARCHAR2(200),
    REDOCONTEXT     CLOB,
    CANCELSERVICE   VARCHAR2(200),
    CANCELCONTEXT   CLOB,
    TOTALRUNTIME    NUMBER,
    MAINRUNTIME     NUMBER,
    LOG_RESULT      VARCHAR2(100),
    FROMTERMINAL    VARCHAR2(100),
    RESULTDESC      CLOB,
    OLD_CONTENT     CLOB,
    LINK_TYPE       VARCHAR2(20),
    LINK_ID         NUMBER,
    OLD_LINK_ID     NUMBER
)
    /

create index IDX_FORM_SETTING_LOGS_TK
    on FORM_SETTING_LOGS (TENANT_KEY)
    /

create index IDX_FORM_SETTING_LOGS_LD
    on FORM_SETTING_LOGS (LOG_DATE)
    /

create index IDX_FORM_SETTING_LOGS_TI
    on FORM_SETTING_LOGS (TARGETID)
    /

create index IDX_FORM_SETTING_LOGS_MN
    on FORM_SETTING_LOGS (MODULENAME)
    /

create index IDX_FORM_SETTING_LOGS_FN
    on FORM_SETTING_LOGS (FUNCTIONNAME)
    /

create index IDX_FORM_SETTING_LOGS_U
    on FORM_SETTING_LOGS (UUID)
    /