create table if not exists complex_field
(
    id                  numeric(20) not null
    constraint fert_complex_field_pkey
    primary key,
    form_id             numeric(20),
    title               varchar(100),
    describe            varchar(2000),
    component_key       varchar(50),
    tenant_key          varchar(10),
    operator            numeric(20),
    create_time         timestamp,
    show_order          double precision default 0::double precision,
    other_properties    text,
    layout_component_id varchar(32),
    required            boolean,
    is_delete           integer
    );
/



create index IDX_COMPLEX_FIELD_FORM_ID
    on complex_field (form_id);
/

create table if not exists field_layout
(
    id            numeric(20) not null
    constraint fert_field_layout_pkey
    primary key,
    parent_id     numeric(20),
    field_id      numeric(20),
    field_type    varchar(10),
    layout_id     numeric(20),
    layout_detail text,
    tenant_key    varchar(10),
    operator      numeric(20),
    create_time   timestamp,
    update_time   timestamp,
    status        boolean
    );
/


create index IDX_FIELD_LAYOUT_FIELD_ID
    on field_layout (field_id);
/

create index IDX_FIELD_LAYOUT_LAYOUT_ID
    on field_layout (layout_id);
/

create index IDX_FIELD_LAYOUT_FIELD_TYPE
    on field_layout (field_type);
/

create index IDX_FIELD_LAYOUT_UPDATE_TIME
    on field_layout (update_time);
/

create table if not exists field_option
(
    id           numeric(20)           not null
    constraint fert_field_option_pkey
    primary key,
    field_id     numeric(20),
    parent_id    numeric(20),
    name         varchar(100),
    "order"      numeric(5),
    tenant_key   varchar(10),
    operator     numeric(20),
    create_time  timestamp,
    tmp_option   varchar(50),
    uid          varchar(100),
    style_config text,
    extra        text,
    archive      boolean default false not null,
    other        boolean,
    is_delete    integer
    );
/

comment on column field_option.style_config is '选项设置';
/


create index IDX_FIELD_OPTION_FIELD_ID
    on field_option (field_id);
/

create index IDX_FIELD_OPTION_PARENT_ID
    on field_option (parent_id);
/

create table if not exists field_permission
(
    id          numeric(20) not null
    constraint fert_field_permission_pkey
    primary key,
    form_id     numeric(20),
    tenant_key  varchar(20),
    module      varchar(50),
    creator     numeric(20),
    create_time timestamp,
    update_time timestamp,
    datasrc     integer,
    is_delete   integer
    );
/

comment on column field_permission.id is '主键ID';
/

comment on column field_permission.form_id is '表单ID';
/

comment on column field_permission.tenant_key is '租户key';
/

comment on column field_permission.module is '所属模块';
/

comment on column field_permission.creator is '创建人';
/

comment on column field_permission.create_time is '创建时间';
/

comment on column field_permission.update_time is '更新时间';
/

comment on column field_permission.datasrc is '是否迁移数据';
/


create index IDX_FIELD_PERMISSION_FORM_ID
    on field_permission (form_id);
/

create table if not exists field_permission_detail
(
    id            numeric(20) not null
    constraint fert_field_permission_detail_pkey
    primary key,
    field_id      numeric(20) not null,
    field_read    varchar(1)  not null,
    field_write   varchar(1)  not null,
    is_delete     varchar(1),
    permission_id numeric(20),
    datasrc       integer,
    tenant_key    varchar(20),
    required      varchar(1),
    disable_edit  varchar(1)
    );
/

comment on column field_permission_detail.id is '主键ID';
/

comment on column field_permission_detail.field_id is '表单字段ID';
/

comment on column field_permission_detail.field_read is '字段读权限（查看）';
/

comment on column field_permission_detail.field_write is '字段写权限（填写）';
/

comment on column field_permission_detail.is_delete is '是否删除(0-未删除,1-已删除)';
/

comment on column field_permission_detail.permission_id is '字段权限ID';
/

comment on column field_permission_detail.datasrc is '是否迁移数据';
/

comment on column field_permission_detail.tenant_key is '租户key';
/


create index IDX_FIELD_PERMISSION_DETAIL_FD
    on field_permission_detail (field_id);
/

create index IDX_FIELD_PERMISSION_DETAIL_PD
    on field_permission_detail (permission_id);
/

create table if not exists form
(
    id               numeric(20)               not null
    constraint fert_form_pkey
    primary key,
    name             varchar(100),
    describe         varchar(2000),
    status           varchar(50),
    source_id        numeric(20),
    ownership        varchar(50),
    tenant_key       varchar(10),
    operator         numeric(20),
    create_time      timestamp,
    update_time      timestamp,
    category_id      numeric(20),
    icon             varchar(50),
    tmp_table        numeric(20),
    tmp_layout       numeric(20),
    sort             numeric(5),
    biaoge_recommend char,
    module           varchar(50),
    review_count     numeric(10),
    export_count     numeric(10),
    copy_count       numeric(10),
    view_count       numeric(10),
    fill_count       numeric(10),
    delete_user      numeric(20),
    report           numeric(20),
    collect_status   varchar(10) default 'disable'::character varying,
    target_id        numeric(20),
    dfaption         integer,
    inherit          char        default '0'::bpchar,
    attr_name        varchar(50),
    org_id           bigint,
    is_advance       boolean     default false,
    is_multi         boolean,
    physical_table   boolean     default false not null,
    recommend        boolean,
    relateflow       boolean,
    is_delete        integer
    );
/

comment on column form.inherit is '字段权限继承';
/


create index IDX_FORM_TENANTKEY
    on form (tenant_key);
/

create index IDX_FORM_CATEGORY
    on form (category_id);
/

create index IDX_FORM_OPERATOR
    on form (operator);
/

create index idx_FORM_OWNERSHIP
    on form (ownership);
/

create index idx_FORM_MODULE
    on form (module);
/

create index idx_FORM_TARGET_ID
    on form (target_id);
/

create index IDX_FORM_SORT
    on form (sort);
/

create index IDX_FORM_CREATE_TIME
    on form (create_time);
/

create index IDX_FORM_STATUS
    on form (status);
/

create index IDX_FORM_REPORT
    on form (report);
/

create index IDX_FORM_BIAOGE_RECOMMEND
    on form (biaoge_recommend);
/

create index IDX_FORM_ORG_ID
    on form (org_id);
/

create table if not exists form_attachment_config
(
    id                    bigint not null
    constraint fert_form_attachment_config_pkey
    primary key,
    create_time           timestamp,
    update_time           timestamp,
    creator               bigint,
    delete_type           integer default 0,
    tenant_key            varchar(10),
    ref_id                bigint,
    folder_select_type    integer default 0,
    folder_id             bigint,
    custom_limit_format   varchar(500),
    attment_size_limit    integer default 3,
    custom_attment_size   varchar(20),
    show_format           integer default 0,
    config_type           integer,
    form_id               bigint,
    field_id              bigint,
    folder_type           integer default 0,
    limit_type            integer default 0,
    other_type            integer default 0,
    option_id             bigint,
    forbin_batch_download boolean default false,
    attach_upload_time    boolean,
    attach_upload_user    boolean,
    sec_level             boolean default true
    );
/

comment on column form_attachment_config.id is 'ID';
/

comment on column form_attachment_config.create_time is '创建时间';
/

comment on column form_attachment_config.update_time is '修改时间';
/

comment on column form_attachment_config.creator is '创建人id';
/

comment on column form_attachment_config.delete_type is '是否删除';
/

comment on column form_attachment_config.tenant_key is '租户KEY';
/

comment on column form_attachment_config.ref_id is '关联id(表单默认用formid，审批用wfid)';
/

comment on column form_attachment_config.folder_select_type is '附件上传目录0：固定目录 1选择目录';
/

comment on column form_attachment_config.folder_id is '附件上传目录id 固定目录为目录id';
/

comment on column form_attachment_config.custom_limit_format is '自定义的文件扩展名limit_upload_format = 6时多个请用逗号隔开，如: txt, pdf, mp3等';
/

comment on column form_attachment_config.attment_size_limit is '附件大小限制下拉框 0 1MB,1 5MB,2 10MB,3 20MB ,4 50MB,5 100MB, 6 自定义';
/

comment on column form_attachment_config.custom_attment_size is '自定义附件大小';
/

comment on column form_attachment_config.show_format is '密级下拉框 0 密级和保密期限 1仅密级';
/

comment on column form_attachment_config.config_type is '设置类型 0 通用 1自定义';
/

comment on column form_attachment_config.form_id is '关联表单ID';
/

comment on column form_attachment_config.field_id is '关联字段id';
/

comment on column form_attachment_config.folder_type is '上传目录设置下拉框0 通用，1 自定义';
/

comment on column form_attachment_config.limit_type is '限制格式设置 0 通用，1 自定义';
/

comment on column form_attachment_config.other_type is '其他设置 0 通用，1 自定义';
/

comment on column form_attachment_config.option_id is '选择目录存字段id';
/

create index IDX_FORM_ATTACHMENT_CONFIG_TK
    on form_attachment_config (tenant_key);
/

create index IDX_FORM_ATTACHMENT_CONFIG_FMI
    on form_attachment_config (form_id);
/

create index IDX_FORM_ATTACHMENT_CONFIG_FDI
    on form_attachment_config (field_id);
/

create table if not exists form_category
(
    id          numeric(20) not null
    constraint fert_form_category_pkey
    primary key,
    name        varchar(100),
    sort        numeric(5),
    tenant_key  varchar(10),
    operator    numeric(20),
    create_time timestamp,
    type        varchar(20),
    module      varchar(20)
    );
/
create index IDX_FORM_CATEGORY_TENANT_KEY
    on form_category (TENANT_KEY);
/

create table if not exists form_data_details_encdata
(
    id         bigint        not null
    constraint fert_form_data_details_encdata_pkey
    primary key,
    tenant_key varchar(10)   not null,
    table_name varchar(50)   not null,
    field_name varchar(50)   not null,
    enc_value  varchar(4000) not null,
    crc        varchar(4000),
    creater    bigint,
    created    timestamp,
    modifier   bigint,
    modified   timestamp,
    skey       varchar(2000) not null
    );
/

comment on column form_data_details_encdata.id is 'ID';
/

comment on column form_data_details_encdata.tenant_key is '租户KEY';
/

comment on column form_data_details_encdata.table_name is '数据原表名';
/

comment on column form_data_details_encdata.field_name is '数据原字段名';
/

comment on column form_data_details_encdata.enc_value is '加密值';
/

comment on column form_data_details_encdata.crc is '签名值';
/

comment on column form_data_details_encdata.creater is '创建人';
/

comment on column form_data_details_encdata.created is '创建时间';
/

comment on column form_data_details_encdata.modifier is '修改人';
/

comment on column form_data_details_encdata.modified is '修改时间';
/

comment on column form_data_details_encdata.skey is '数据秘钥（已加密）';
/

create index IDX_FD_DETAILS_ENCDATA_TK
    on form_data_details_encdata (tenant_key);
/

create index IDX_FD_DETAILS_ENCDATA_TN
    on form_data_details_encdata (table_name);
/

create index IDX_FD_DETAILS_ENCDATA_FN
    on form_data_details_encdata (field_name);
/

create table if not exists form_data_layout_rel
(
    id                 numeric(20) not null
    constraint fert_form_data_layout_rel_pkey
    primary key,
    form_data          numeric(20),
    multiple_layout_id numeric(20),
    version_id         numeric(20),
    tenant_key         varchar(10)
    );
/

comment on column form_data_layout_rel.form_data is '表单数据Id';
/

comment on column form_data_layout_rel.multiple_layout_id is '多布局Id';
/

comment on column form_data_layout_rel.version_id is '布局版本Id';
/

comment on column form_data_layout_rel.tenant_key is '租户Key';
/

create index IDX_FORM_DATA_LAYOUT_REL_FD
    on form_data_layout_rel (form_data);
/

create index IDX_FORM_DATA_LAYOUT_REL_MLI
    on form_data_layout_rel (multiple_layout_id);
/

create index IDX_FORM_DATA_LAYOUT_REL_VI
    on form_data_layout_rel (version_id);
/

create table if not exists form_data_relate_config
(
    id               numeric(20) not null
    constraint fert_form_data_relate_config_pkey
    primary key,
    field_id         numeric(20),
    express_id       bigint,
    monitor_fields   text,
    relate_field     text,
    relate_datatable text,
    relate_multiple  varchar(1),
    version_id       numeric(20),
    operator         numeric(20),
    tenant_key       varchar(10),
    create_time      timestamp,
    update_time      timestamp,
    is_delete        integer
    );
/

comment on column form_data_relate_config.id is '主键ID';
/

comment on column form_data_relate_config.field_id is '表单字段ID';
/

comment on column form_data_relate_config.express_id is 'Excel函数公式ID';
/

comment on column form_data_relate_config.monitor_fields is '普通公式';
/

comment on column form_data_relate_config.relate_field is '数据钻取';
/

comment on column form_data_relate_config.relate_datatable is '明细表钻取';
/

comment on column form_data_relate_config.relate_multiple is '钻取多选';
/

comment on column form_data_relate_config.version_id is '表单布局版本ID';
/

comment on column form_data_relate_config.operator is '创建人';
/

comment on column form_data_relate_config.tenant_key is '租户Key';
/

comment on column form_data_relate_config.create_time is '创建时间';
/

comment on column form_data_relate_config.update_time is '更新时间';
/

create index IDX_FDRC_FIELD_ID
    on form_data_relate_config (field_id);
/

create index IDX_FDRC_VERSION_ID
    on form_data_relate_config (version_id);
/

create index IDX_FDRC_TENANT_KEY
    on form_data_relate_config (tenant_key);
/

create table if not exists form_field
(
    id                  numeric(20) not null
    constraint fert_form_field_pkey
    primary key,
    form_id             numeric(20),
    sub_form_id         numeric(20),
    title               varchar(100),
    describe            varchar(2000),
    data_type           varchar(50),
    tenant_key          varchar(10),
    operator            numeric(20),
    create_time         timestamp,
    component_key       varchar(50),
    tmp_field           varchar(50),
    complex_id          numeric(20),
    update_time         timestamp,
    source_module       varchar(20),
    data_template_id    numeric(20),
    express_id          bigint,
    attr_name           varchar(50),
    show_order          double precision default 0::double precision,
    group_id            numeric(20),
    other_properties    text,
    data_key            varchar(32),
    layout_component_id varchar(32),
    default_order       smallint,
    custom_order        smallint,
    archive             boolean,
    required            boolean,
    single              boolean          default true,
    is_delete           integer,
    browser_module      varchar(32),
    browser_type        varchar(64),
    parent_id           numeric(20)
    );
/

comment on column form_field.express_id is 'Excel函数公式ID';
/

create index IDX_FORM_FIELD_FORM_ID
    on form_field (form_id);
/

create index IDX_FORM_FIELD_COMPONENT_KEY
    on form_field (component_key);
/

create index IDX_FORM_FIELD_UPDATE_TIME
    on form_field (update_time);
/

create index IDX_FORM_FIELD_COMPLEX_FIELD
    on form_field (complex_id);
/

create index IDX_FORM_FIELD_SUB_FORM_ID
    on form_field (sub_form_id);
/

create index IDX_FORM_FIELD_DATA_TEMPLATE_I
    on form_field (data_template_id);
/

create index IDX_FORM_FIELD_EXPRESS_ID
    on form_field (express_id);
/

create index IDX_FORM_FIELD_BM_BT_TK
    on form_field (browser_module, browser_type, tenant_key);
/

create index IDX_FORM_FIELD_DK_TK
    on form_field (data_key, tenant_key);
/

create table if not exists form_field_group
(
    id          numeric(20) not null
    constraint fert_form_field_group_pkey
    primary key,
    group_name  varchar(64) not null,
    icon        varchar(64),
    operator    numeric(20) not null,
    is_delete   smallint,
    tenant_key  varchar(10),
    create_time timestamp   not null,
    update_time timestamp,
    form_id     numeric(20) not null,
    show_order  double precision default 0
    );
/

comment on column form_field_group.id is 'ID';
/

comment on column form_field_group.group_name is '分组名称';
/

comment on column form_field_group.icon is '分组图标';
/

comment on column form_field_group.operator is '创建人id';
/

comment on column form_field_group.is_delete is '是否删除';
/

comment on column form_field_group.tenant_key is '租户KEY';
/

comment on column form_field_group.create_time is '创建时间';
/

comment on column form_field_group.update_time is '更新时间';
/

create index IDX_FORM_FIELD_GROUP_TK
    on form_field_group (tenant_key);
/

create index IDX_FORM_FIELD_GROUP_NAME
    on form_field_group (group_name);
/

create index IDX_FORM_FIELD_GROUP_FI_TK
    on form_field_group (form_id, tenant_key);
/

create table if not exists form_field_language
(
    id              numeric(20) not null
    constraint fert_form_field_language_pkey
    primary key,
    form_id         numeric(20),
    field_id        numeric(20) not null,
    component_key   varchar(50),
    language_detail text,
    create_time     timestamp,
    update_time     timestamp,
    tenant_key      varchar(20),
    is_delete       integer
    );
/

comment on column form_field_language.id is '主键ID';
/

comment on column form_field_language.form_id is '表单ID';
/

comment on column form_field_language.field_id is '表单字段ID';
/

comment on column form_field_language.component_key is '控件Key';
/

comment on column form_field_language.language_detail is '多语言设置明细';
/

comment on column form_field_language.create_time is '创建时间';
/

comment on column form_field_language.update_time is '更新时间';
/

comment on column form_field_language.tenant_key is '租户key';
/

create index IDX_FORM_FIELD_LANGUAGE_FORM_I
    on form_field_language (form_id);
/

create index IDX_FORM_FIELD_LANGUAGE_FIELD_I
    on form_field_language (field_id);
/

create table if not exists form_fieldmanagelogs
(
    id              bigint                         not null
    constraint fert_form_fieldmanagelogs_pkey
    primary key,
    uuid            varchar(36)                    not null,
    log_date        timestamp,
    device          varchar(500)                   not null,
    log_operator    bigint,
    operatorname    varchar(100)                   not null,
    tenant_key      varchar(10)                    not null,
    targetid        bigint    default (-1)::bigint not null,
    targetname      text                           not null,
    modulename      varchar(100)                   not null,
    functionname    varchar(100)                   not null,
    interfacename   varchar(100)                   not null,
    requesturl      varchar(200)                   not null,
    requesturi      varchar(200)                   not null,
    operatetype     varchar(50)                    not null,
    operatetypename varchar(100)                   not null,
    operatedesc     varchar(3000)                  not null,
    params          text                           not null,
    belongmainid    varchar(36)                    not null,
    clientip        varchar(50)                    not null,
    groupid         varchar(50)                    not null,
    groupnamelabel  varchar(1000)                  not null,
    redoservice     varchar(200)                   not null,
    redocontext     text                           not null,
    cancelservice   varchar(200)                   not null,
    cancelcontext   text                           not null,
    create_time     timestamp default now()        not null,
    update_time     timestamp default now()        not null,
    creator         bigint    default (-1)::bigint not null,
    delete_type     integer   default 0            not null,
    totalruntime    bigint    default 0::bigint    not null,
    mainruntime     bigint    default 0::bigint    not null,
    log_result      varchar(100),
    fromterminal    varchar(100)                   not null,
    resultdesc      text                           not null,
    old_content     varchar(3000)                  not null,
    link_type       varchar(20)                    not null,
    link_id         bigint    default 0::bigint    not null,
    old_link_id     bigint    default 0::bigint    not null
    );
/

comment on column form_fieldmanagelogs.id is 'ID';
/

comment on column form_fieldmanagelogs.uuid is '日志UUID';
/

comment on column form_fieldmanagelogs.device is '终端信息';
/

comment on column form_fieldmanagelogs.operatorname is '操作人姓名';
/

comment on column form_fieldmanagelogs.tenant_key is '租户id';
/

comment on column form_fieldmanagelogs.targetid is '操作目标id';
/

comment on column form_fieldmanagelogs.targetname is '操作目标名称';
/

comment on column form_fieldmanagelogs.modulename is '模块';
/

comment on column form_fieldmanagelogs.functionname is '服务（方法）';
/

comment on column form_fieldmanagelogs.interfacename is '访问接口名';
/

comment on column form_fieldmanagelogs.requesturl is '请求全路径';
/

comment on column form_fieldmanagelogs.requesturi is '请求地址';
/

comment on column form_fieldmanagelogs.operatetype is '操作类型';
/

comment on column form_fieldmanagelogs.operatetypename is '操作类型名称';
/

comment on column form_fieldmanagelogs.operatedesc is '操作详细说明';
/

comment on column form_fieldmanagelogs.params is '涉及的相关参数';
/

comment on column form_fieldmanagelogs.belongmainid is '所属主表uuid';
/

comment on column form_fieldmanagelogs.clientip is '操作IP';
/

comment on column form_fieldmanagelogs.groupid is '分组';
/

comment on column form_fieldmanagelogs.groupnamelabel is '分组标题';
/

comment on column form_fieldmanagelogs.redoservice is '重做业务接口';
/

comment on column form_fieldmanagelogs.redocontext is '重做参数';
/

comment on column form_fieldmanagelogs.cancelservice is '撤销业务接口';
/

comment on column form_fieldmanagelogs.cancelcontext is '撤销参数';
/

comment on column form_fieldmanagelogs.create_time is '创建时间';
/

comment on column form_fieldmanagelogs.update_time is '修改时间';
/

comment on column form_fieldmanagelogs.creator is '创建人id';
/

comment on column form_fieldmanagelogs.delete_type is '是否删除';
/

comment on column form_fieldmanagelogs.totalruntime is '总运行时长';
/

comment on column form_fieldmanagelogs.mainruntime is '主方法运行时长';
/

comment on column form_fieldmanagelogs.fromterminal is '来自pc web';
/

comment on column form_fieldmanagelogs.resultdesc is '运行结果描述';
/

comment on column form_fieldmanagelogs.old_content is '原先内容';
/

comment on column form_fieldmanagelogs.link_type is '链接类型';
/

comment on column form_fieldmanagelogs.link_id is '链接id';
/

comment on column form_fieldmanagelogs.old_link_id is '原先链接id';
/


create index IDX_FORM_FIELDMANAGELOGS_TK
    on form_fieldmanagelogs (tenant_key);
/

create index IDX_FORM_FIELDMANAGELOGS_TI
    on form_fieldmanagelogs (targetid);
/

create index IDX_FORM_FIELDMANAGELOGS_MN
    on form_fieldmanagelogs (modulename);
/

create index IDX_FORM_FIELDMANAGELOGS_FN
    on form_fieldmanagelogs (functionname);
/

create index IDX_FORM_FIELDMANAGELOGS_U
    on form_fieldmanagelogs (uuid);
/

create index IDX_FORM_FIELDMANAGE_LOGS_LD
    on form_fieldmanagelogs (log_date);
/

create table if not exists form_fieldmanagelogs_detail
(
    id               bigint                                      not null
    constraint fert_form_fieldmanagelogs_detail_pkey
    primary key,
    uuid             varchar(36)                                 not null,
    mainid           varchar(36)                                 not null,
    dataid           varchar(50)                                 not null,
    belongdataid     varchar(50)                                 not null,
    tablename        varchar(200)                                not null,
    tablenamelabelid varchar(50) default '-1'::character varying not null,
    tablenamedesc    varchar(50)                                 not null,
    fieldname        varchar(200)                                not null,
    fieldnamelabelid varchar(50) default '-1'::character varying not null,
    newvalue         text                                        not null,
    oldvalue         text                                        not null,
    newrealvalue     text                                        not null,
    oldrealvalue     text                                        not null,
    fielddesc        varchar(200)                                not null,
    showorder        integer                                     not null,
    create_time      timestamp   default now()                   not null,
    update_time      timestamp   default now()                   not null,
    creator          bigint      default (-1)::bigint            not null,
    delete_type      integer     default 0                       not null,
    tenant_key       varchar(10)                                 not null,
    isdetail         integer     default 0                       not null
    );
/

comment on column form_fieldmanagelogs_detail.id is 'ID';
/

comment on column form_fieldmanagelogs_detail.uuid is '日志UUID';
/

comment on column form_fieldmanagelogs_detail.mainid is '主表id';
/

comment on column form_fieldmanagelogs_detail.dataid is '数据id';
/

comment on column form_fieldmanagelogs_detail.belongdataid is '主表数据id';
/

comment on column form_fieldmanagelogs_detail.tablename is '表名';
/

comment on column form_fieldmanagelogs_detail.tablenamelabelid is '表名labelid';
/

comment on column form_fieldmanagelogs_detail.tablenamedesc is '对应数据库的表';
/

comment on column form_fieldmanagelogs_detail.fieldname is '字段名';
/

comment on column form_fieldmanagelogs_detail.fieldnamelabelid is '字段名labelid';
/

comment on column form_fieldmanagelogs_detail.newvalue is '更新后的值';
/

comment on column form_fieldmanagelogs_detail.oldvalue is '更新前的值';
/

comment on column form_fieldmanagelogs_detail.newrealvalue is '更新后的显示值';
/

comment on column form_fieldmanagelogs_detail.oldrealvalue is '更新前的显示值';
/

comment on column form_fieldmanagelogs_detail.fielddesc is '字段名';
/

comment on column form_fieldmanagelogs_detail.showorder is '字段名';
/

comment on column form_fieldmanagelogs_detail.create_time is '创建时间';
/

comment on column form_fieldmanagelogs_detail.update_time is '修改时间';
/

comment on column form_fieldmanagelogs_detail.creator is '创建人id';
/

comment on column form_fieldmanagelogs_detail.delete_type is '是否删除';
/

comment on column form_fieldmanagelogs_detail.tenant_key is '租户id';
/

comment on column form_fieldmanagelogs_detail.isdetail is '是否明细字段';
/


create index IDX_F_FIELDMANAGELOGS_U_MI
    on form_fieldmanagelogs_detail (uuid, mainid);
/

create index IDX_F_FIELDMANAGELOGS_U
    on form_fieldmanagelogs_detail (uuid);
/

create index IDX_F_FIELDMANAGELOGS_TK
    on form_fieldmanagelogs_detail (tenant_key);
/

create index IDX_F_FMANAGELOGS_DETAIL_MI
    on form_fieldmanagelogs_detail (mainid);
/

create table if not exists form_layout_multiple
(
    id            numeric(20) not null
    constraint fert_form_layout_multiple_pkey
    primary key,
    name          varchar(100),
    describe      varchar(2000),
    form_id       numeric(20),
    tenant_key    varchar(10),
    operator      numeric(20),
    create_time   timestamp,
    update_time   timestamp,
    version_id    numeric(20),
    layout_type   varchar(20),
    terminal_type varchar(20),
    is_default    boolean,
    is_delete     integer
    );
/

comment on column form_layout_multiple.id is '布局ID';
/

comment on column form_layout_multiple.name is '布局名称';
/

comment on column form_layout_multiple.describe is '布局描述';
/

comment on column form_layout_multiple.form_id is '表单ID';
/

comment on column form_layout_multiple.tenant_key is '租户Key';
/

comment on column form_layout_multiple.operator is '创建人';
/

comment on column form_layout_multiple.create_time is '创建时间';
/

comment on column form_layout_multiple.update_time is '更新时间';
/

comment on column form_layout_multiple.version_id is '最新版本布局ID';
/


create index IDX_FORM_LAYOUT_MULTIPLE_FORM_ID
    on form_layout_multiple (form_id);
/

create index IDX_FORM_LAYOUT_MULTIPLE_VI
    on form_layout_multiple (version_id);
/

create table if not exists form_layout_style
(
    id            numeric(20) not null
    constraint fert_form_layout_style_pkey
    primary key,
    form_id       numeric(20),
    layout_type   varchar(50),
    color_scheme  varchar(50),
    layout_detail text,
    tenant_key    varchar(10),
    operator      numeric(20),
    create_time   timestamp,
    update_time   timestamp,
    layout_html   text,
    layout_style  text,
    mobile_indexs text
    );
/
create index IDX_FORM_LAYOUT_STYLE_FORM_ID
    on form_layout_style (form_id);
/

create index IDX_FORM_LAYOUT_STYLE_TK
    on form_layout_style (TENANT_KEY);
/

create table if not exists form_layout_version
(
    id                 numeric(20) not null
    constraint fert_form_layout_version_pkey
    primary key,
    name               varchar(100),
    describe           varchar(2000),
    form_id            numeric(20),
    layout_type        varchar(50),
    color_scheme       varchar(50),
    layout_detail      text,
    tenant_key         varchar(10),
    operator           numeric(20),
    create_time        timestamp,
    update_time        timestamp,
    layout_html        text,
    mobile_indexs      text,
    multiple_layout_id numeric(20)
    );
/

comment on column form_layout_version.id is '布局版本ID';
/

comment on column form_layout_version.name is '布局名称';
/

comment on column form_layout_version.describe is '布局描述';
/

comment on column form_layout_version.form_id is '表单ID';
/

comment on column form_layout_version.layout_type is '布局类型';
/

comment on column form_layout_version.color_scheme is '配色方案';
/

comment on column form_layout_version.layout_detail is '布局明细';
/

comment on column form_layout_version.tenant_key is '租户Key';
/

comment on column form_layout_version.operator is '创建人';
/

comment on column form_layout_version.create_time is '创建时间';
/

comment on column form_layout_version.update_time is '更新时间';
/

comment on column form_layout_version.layout_html is '高级表单-布局HTML明细';
/

comment on column form_layout_version.mobile_indexs is '高级表单移动端-字段显示顺序';
/

comment on column form_layout_version.multiple_layout_id is '多布局ID';
/


create index IDX_FORM_LAYOUT_VERSION_F_ID
    on form_layout_version (form_id);
/

create index IDX_FORM_LAYOUT_VERSION_MLD
    on form_layout_version (multiple_layout_id);
/

create table if not exists form_option_sub_filter_config
(
    id             bigint,
    create_time    timestamp   not null,
    update_time    timestamp,
    creator        bigint      not null,
    delete_type    integer     not null,
    tenant_key     varchar(10) not null,
    main_field     bigint      not null,
    sub_field      bigint      not null,
    form_id        bigint      not null,
    option_ids     text,
    main_option_id bigint      not null,
    constraint fert_form_option_sub_filter_config_idx_fosfc_mso
    unique (sub_field, main_field, main_option_id)
    );
/

comment on column form_option_sub_filter_config.id is 'ID';
/

comment on column form_option_sub_filter_config.create_time is '创建时间';
/

comment on column form_option_sub_filter_config.update_time is '修改时间';
/

comment on column form_option_sub_filter_config.creator is '创建人id';
/

comment on column form_option_sub_filter_config.delete_type is '是否删除';
/

comment on column form_option_sub_filter_config.tenant_key is '租户KEY';
/

comment on column form_option_sub_filter_config.main_field is '主字段';
/

comment on column form_option_sub_filter_config.sub_field is '子字段';
/

comment on column form_option_sub_filter_config.form_id is 'FORMID';
/

comment on column form_option_sub_filter_config.option_ids is '可选择的选项列表';
/

comment on column form_option_sub_filter_config.main_option_id is '主字段选项ID';
/


create index IDX_FOSFC_TENANT_KEY
    on form_option_sub_filter_config (tenant_key);
/

create index IDX_FOSFC_FORM_ID
    on form_option_sub_filter_config (form_id);
/

create index IDX_FOSFC_MAIN_FIELD
    on form_option_sub_filter_config (main_field);
/

create index IDX_FOSFC_SUB_FIELD
    on form_option_sub_filter_config (sub_field);
/

create table if not exists form_option_template_config
(
    id              bigint      not null
    constraint fert_form_option_template_config_pkey
    primary key,
    create_time     timestamp   not null,
    update_time     timestamp,
    creator         bigint      not null,
    delete_type     integer     not null,
    tenant_key      varchar(10) not null,
    form_id         bigint      not null,
    field_id        bigint      not null,
    template_id     bigint      not null,
    inherited_type  varchar(10) not null,
    drop_down_level char        not null,
    parent_field    bigint
    );
/

comment on column form_option_template_config.id is 'ID';
/

comment on column form_option_template_config.create_time is '创建时间';
/

comment on column form_option_template_config.update_time is '修改时间';
/

comment on column form_option_template_config.creator is '创建人id';
/

comment on column form_option_template_config.delete_type is '是否删除';
/

comment on column form_option_template_config.tenant_key is '租户KEY';
/

comment on column form_option_template_config.form_id is '表单ID';
/

comment on column form_option_template_config.field_id is '字段ID';
/

comment on column form_option_template_config.template_id is '数据源模板ID';
/

comment on column form_option_template_config.inherited_type is '类型(parent, sub)';
/

comment on column form_option_template_config.drop_down_level is '下拉级别';
/

comment on column form_option_template_config.parent_field is '父级控件';
/


create index IDX_FOTC_FIELD_ID
    on form_option_template_config (field_id);
/

create index IDX_FOTC_FORM_ID
    on form_option_template_config (form_id);
/

create index IDX_FOTC_TENANT_KEY
    on form_option_template_config (tenant_key);
/

create table if not exists form_style
(
    id                 numeric(20) not null
    constraint fert_form_style_pkey
    primary key,
    form_id            numeric(20) not null,
    layout_id          numeric(20) not null,
    style_detail       text,
    style_config       text,
    update_time        timestamp default now(),
    tenant_key         varchar(10),
    style_field_config text,
    style_config_temp  text
    );
/


create index IDX_FORM_STYLE_LAYOUT_ID
    on form_style (layout_id);
/

create index IDX_FORM_STYLE_FORM_ID
    on form_style (form_id);
/

create table if not exists form_table
(
    id          numeric(20) not null
    constraint fert_form_table_pkey
    primary key,
    form_id     numeric(20) not null,
    table_name  varchar(64) not null,
    tenant_key  varchar(20) not null,
    create_time timestamp   not null,
    update_time timestamp,
    operator    varchar(64) not null
    );
/

comment on column form_table.table_name is '表名称';
/


create index IDX_FORM_TABLE_FORM_ID
    on form_table (form_id);
/

create index IDX_FORM_TABLE_NAME
    on form_table (table_name);
/

create table if not exists form_table_data_redundancy
(
    id            numeric(20)                                      not null
    constraint fert_form_table_data_redundancy_pkey
    primary key,
    form_table_id numeric(20)                                      not null,
    field_id      numeric(20)                                      not null,
    content       text                                             not null,
    create_time   timestamp                                        not null,
    update_time   timestamp,
    operator      varchar(64),
    tenant_key    varchar(20)                                      not null,
    type          varchar(50) default 'content'::character varying not null,
    target_id     text,
    content_type  text
    );
/

comment on column form_table_data_redundancy.form_table_id is '数据ID';
/

comment on column form_table_data_redundancy.field_id is '列ID';
/

comment on column form_table_data_redundancy.content is '冗余内容';
/


create index IDX_FTDR_TYPE
    on form_table_data_redundancy (type);
/

create index IDX_FTDR_FT_FI_T
    on form_table_data_redundancy (form_table_id, field_id, type);
/

create index IDX_FTDR_CREATE_TIME
    on form_table_data_redundancy (create_time);
/

create index IDX_FTDR_FIELD_ID
    on form_table_data_redundancy (field_id);
/

create index IDX_FTDR_CONTENT
    on form_table_data_redundancy (content);
/

create table if not exists form_table_data_rel
(
    id            numeric(20) not null
    constraint fert_form_table_data_rel_pkey
    primary key,
    form_table_id numeric(20) not null,
    parent_id     numeric(20) not null,
    tenant_key    varchar(20) not null,
    is_delete     integer     not null
    );
/

comment on column form_table_data_rel.form_table_id is '数据ID';
/

comment on column form_table_data_rel.parent_id is '父数据ID';
/


create index IDX_FORM_TABLE_DATA_REL_FTI
    on form_table_data_rel (form_table_id);
/

create index IDX_FORM_TABLE_DATA_REL_PI
    on form_table_data_rel (parent_id);
/

create index IDX_FTDR_FTI_PI_ID
    on form_table_data_rel (FORM_TABLE_ID, PARENT_ID, IS_DELETE);
/

create table if not exists form_table_field
(
    id          numeric(20)                                not null
    constraint fert_form_table_field_pkey
    primary key,
    field_id    numeric(20)                                not null
    constraint fert_form_table_field_unx_field_id
    unique,
    is_index    varchar(10) default '0'::character varying not null,
    column_name varchar(64)                                not null,
    tenant_key  varchar(20)                                not null,
    type_len    smallint                                   not null,
    column_type varchar(20) default ''::character varying  not null,
    dynamic     varchar(20)
    );
/

comment on column form_table_field.is_index is '列是否已有索引 索引类型';
/

comment on column form_table_field.column_name is '用户定义的列名，用户未定义则填充默认列名';
/

comment on column form_table_field.type_len is '类型长度';
/

comment on column form_table_field.column_type is '列类型';
/

comment on column form_table_field.dynamic is '列对应的数据长度（日期类型）';
/


create index UNX_FORM_TABLE_FIELD_FIELD_ID
    on form_table_field (field_id);
/

create table if not exists form_table_rel
(
    id          numeric(20) not null
    constraint fert_form_table_rel_pkey
    primary key,
    form_id     numeric(20) not null,
    sub_form_id numeric(20) not null,
    operator    varchar(64) not null,
    tenant_key  varchar(20) not null,
    create_time timestamp   not null,
    update_time timestamp,
    is_delete   integer     not null
    );
/

comment on column form_table_rel.form_id is '主表ID';
/

comment on column form_table_rel.sub_form_id is '子表ID';
/


create index IDX_FORM_TABLE_REL_FORM_ID
    on form_table_rel (form_id);
/

create index IDX_FORM_TABLE_REL_SUB_FORM_ID
    on form_table_rel (sub_form_id);
/

create table if not exists form_view_relate_config
(
    id                 numeric(20) not null
    constraint fert_form_view_relate_config_pkey
    primary key,
    field_id           numeric(20),
    display_condition  text,
    readonly_condition text,
    required_condition text,
    version_id         numeric(20),
    operator           numeric(20),
    tenant_key         varchar(10),
    create_time        timestamp,
    update_time        timestamp,
    is_delete          integer,
    display            boolean,
    readonly           boolean,
    required           boolean,
    disable_edit       varchar(1),
    single_row         varchar(1),
    show_order         double precision default 0
    );
/

comment on column form_view_relate_config.id is '主键ID';
/

comment on column form_view_relate_config.field_id is '表单字段ID';
/

comment on column form_view_relate_config.display_condition is '显示条件';
/

comment on column form_view_relate_config.readonly_condition is '只读条件';
/

comment on column form_view_relate_config.required_condition is '必填条件';
/

comment on column form_view_relate_config.version_id is '表单布局版本ID';
/

comment on column form_view_relate_config.operator is '创建人';
/

comment on column form_view_relate_config.tenant_key is '租户Key';
/

comment on column form_view_relate_config.create_time is '创建时间';
/

comment on column form_view_relate_config.update_time is '更新时间';
/


create index IDX_FVRC_FIELD_ID
    on form_view_relate_config (field_id);
/

create index IDX_FVRC_VERSION_ID
    on form_view_relate_config (version_id);
/

create index IDX_FVRC_TENANT_KEY
    on form_view_relate_config (tenant_key);
/

create table if not exists formdata
(
    id          numeric(38) not null
    constraint fert_formdata_pkey
    primary key,
    form_id     numeric(38),
    layout_id   numeric(38),
    data_status varchar(50),
    tenant_key  varchar(10),
    operator    numeric(38),
    create_time timestamp,
    update_time timestamp,
    module      varchar(50),
    client      varchar(50),
    version     varchar(50),
    spent_time  numeric(38),
    ip          varchar(50),
    name        varchar(800),
    is_delete   integer default 0
    );
/

comment on column formdata.id is 'ID';
/

comment on column formdata.form_id is '表单ID';
/

comment on column formdata.layout_id is '布局ID';
/

comment on column formdata.data_status is '是否删除';
/

comment on column formdata.tenant_key is '租户ID';
/

comment on column formdata.operator is '操作人';
/

comment on column formdata.create_time is '创建时间';
/

comment on column formdata.update_time is '更新时间';
/

comment on column formdata.module is '模块';
/

comment on column formdata.client is '客户端';
/

comment on column formdata.version is '版本';
/

comment on column formdata.spent_time is '时间';
/

comment on column formdata.ip is 'IP';
/

comment on column formdata.name is '名称';
/


create index IDX_FORMDATA_TENANT_KEY
    on formdata (tenant_key);
/

create index IDX_FORMDATA_FORMID
    on formdata (form_id);
/

create index IDX_FORMDATA_LAYOUTID
    on formdata (layout_id);
/

create index IDX_FORMDATA_OPERATOR
    on formdata (operator);
/

create index fert_formdataformdata_tenantkey
    on formdata (tenant_key);
/

create index IDX_FORMDATA_MODULE
    on formdata (module);
/

create index IDX_FORMDATA_DATASTATUS
    on formdata (data_status);
/

create index IDX_FORMDATA_IS_DELETE
    on formdata (IS_DELETE);
/

create table if not exists formdata_detail
(
    id            numeric(38) not null
    constraint fert_formdata_detail_pkey
    primary key,
    form_data     numeric(38),
    field_id      numeric(38),
    sub_form_id   numeric(38),
    layout_id     numeric(38),
    data_index    numeric(38),
    content       varchar(500),
    tenant_key    varchar(10),
    operator      numeric(38),
    create_time   timestamp,
    type          varchar(50),
    stat_describe varchar(50),
    longitude     double precision,
    latitude      double precision
    );
/

comment on column formdata_detail.id is 'ID';
/

comment on column formdata_detail.form_data is '表单ID';
/

comment on column formdata_detail.field_id is '字段ID';
/

comment on column formdata_detail.sub_form_id is '明细表ID';
/

comment on column formdata_detail.layout_id is '布局ID';
/

comment on column formdata_detail.data_index is '明细表数据行号';
/

comment on column formdata_detail.content is '内容';
/

comment on column formdata_detail.tenant_key is '租户KEY';
/

comment on column formdata_detail.operator is '创建人';
/

comment on column formdata_detail.create_time is '创建时间';
/

comment on column formdata_detail.type is '类型';
/

comment on column formdata_detail.stat_describe is '描述字段';
/

comment on column formdata_detail.longitude is '经度';
/

comment on column formdata_detail.latitude is '纬度';
/


create index IDX_FORMDATA_DETAIL_TENANT_KEY
    on formdata_detail (tenant_key);
/

create index IDX_FORMDATA_DETAIL_FORMDATA
    on formdata_detail (form_data);
/

create index IDX_FORMDATA_DETAIL_FIELDID
    on formdata_detail (field_id);
/

create index IDX_FORMDATA_DETAIL_SUB_FORM_I
    on formdata_detail (sub_form_id);
/


create index IDX_FORMDATA_DETAIL_CONTENT
    on formdata_detail (CONTENT);
/

create table if not exists formdata_log
(
    id                numeric(20) not null
    constraint fert_formdata_log_pkey
    primary key,
    form_data         numeric(20),
    content           text,
    new_content       text,
    field_name        varchar(100),
    field_id          numeric(20),
    sub_form_id       numeric(20),
    data_index        numeric(5),
    component_key     varchar(50),
    client            varchar(50),
    version           varchar(50),
    tenant_key        varchar(10),
    operator          numeric(20),
    create_time       timestamp,
    source_id         numeric(20),
    source_name       varchar(500),
    source_module     varchar(20),
    external_operator numeric(20),
    sources           text,
    layout_id         numeric(20),
    record_id         bigint
    );
/

comment on column formdata_log.layout_id is '所属布局版本Id';
/


create index IDX_FORMDATA_LOG_FORM_DATA
    on formdata_log (form_data);
/

create index IDX_FORMDATA_LOG_FIELD_ID
    on formdata_log (field_id);
/

create index IDX_FORMDATA_LOG_SUB_FORM_ID
    on formdata_log (sub_form_id);
/

create index IDX_FORMDATA_LOG_SOURCE_ID
    on formdata_log (source_id);
/

create index IDX_FORMDATA_LOG_LAYOUT_ID
    on formdata_log (layout_id);
/

create index IDX_FORMDATA_LOG_RECORD_ID
    on formdata_log (record_id);
/

create table if not exists formdata_option
(
    id           numeric(38) not null
    constraint fert_formdata_option_pkey
    primary key,
    data_details numeric(38),
    option_id    varchar(200),
    content      varchar(200),
    tenant_key   varchar(10),
    type         varchar(20),
    target_id    numeric(38),
    form_data    numeric(20)
    );
/

comment on column formdata_option.id is 'ID';
/

comment on column formdata_option.data_details is '数据明细ID';
/

comment on column formdata_option.option_id is '选项ID';
/

comment on column formdata_option.content is '内容';
/

comment on column formdata_option.tenant_key is '租户KEY';
/

comment on column formdata_option.type is '类型';
/

comment on column formdata_option.target_id is '目标ID';
/


create index IDX_FORMDATA_OPTION_TENANT_KEY
    on formdata_option (tenant_key);
/

create index IDX_FORMDATA_OPTION_DATADETAIL
    on formdata_option (data_details);
/

create index IDX_FORMDATA_OPTION_OPTION_ID
    on formdata_option (option_id);
/

create table if not exists formdata_record_log
(
    id             bigint not null
    constraint fert_formdata_record_log_pkey
    primary key,
    create_time    timestamp,
    tenant_key     varchar(10),
    form_data_id   bigint,
    device         varchar(500),
    operator_id    bigint,
    module_source  varchar(100),
    operation_type varchar(100),
    ref_id         varchar(100),
    terminal       varchar(50)
    );
/

comment on column formdata_record_log.id is 'ID';
/

comment on column formdata_record_log.create_time is '创建时间';
/

comment on column formdata_record_log.tenant_key is '租户KEY';
/

comment on column formdata_record_log.form_data_id is '表单数据id';
/

comment on column formdata_record_log.device is '终端信息';
/

comment on column formdata_record_log.operator_id is '操作人';
/

comment on column formdata_record_log.module_source is '模块';
/

comment on column formdata_record_log.operation_type is '操作类型';
/

comment on column formdata_record_log.ref_id is '分组编码';
/

comment on column formdata_record_log.terminal is '客户端';
/


create index IDX_FORMDATA_RECORD_LOG_TK
    on formdata_record_log (tenant_key);
/

create index IDX_FORMDATA_RECORD_LOG_FDI_RI
    on formdata_record_log (form_data_id, ref_id);
/

create table if not exists formdata_serial
(
    id           numeric(20) not null
    constraint fert_formdata_serial_pkey
    primary key,
    form_data    numeric(20) not null,
    field_id     numeric(20) not null,
    content      varchar(1000),
    create_time  timestamp default now(),
    tenant_key   varchar(10),
    option_id    numeric(20),
    date_content varchar(1000)
    );
/

comment on column formdata_serial.form_data is '表单数据';
/

comment on column formdata_serial.field_id is '表单字段';
/

comment on column formdata_serial.content is '序列号';
/

comment on column formdata_serial.option_id is '选项控件选项ID';
/

comment on column formdata_serial.date_content is '日期控件内容';
/


create index IDX_FORMDATA_SERIAL_FORM_DATA
    on formdata_serial (form_data);
/

create index IDX_FORMDATA_SERIAL_FIELD_ID
    on formdata_serial (field_id);
/

create index IDX_FORMDATA_SERIAL_CREATETIME
    on formdata_serial (create_time);
/

create index IDX_FORMDATA_SERIAL_OPTION_ID
    on formdata_serial (option_id);
/

create index IDX_FORMDATA_SERIAL_FI_CT
    on formdata_serial (FIELD_ID, CREATE_TIME);
/

create table if not exists formdata_sharding_key
(
    id         numeric(20) not null
    constraint fert_formdata_sharding_key_pkey
    primary key,
    tenant_key varchar(50) not null
    );
/


create table if not exists formdata_sharding_sql
(
    id          numeric(20) not null
    constraint fert_formdata_sharding_sql_pkey
    primary key,
    content     varchar(5000),
    create_time timestamp default now(),
    TENANT_KEY varchar(10) default 'all_teams'
    );
/


create table if not exists formdata_text
(
    id           numeric(38) not null
    constraint fert_formdata_text_pkey
    primary key,
    data_details numeric(38),
    content      text,
    tenant_key   varchar(10),
    rich_content text
    );
/

comment on column formdata_text.id is 'ID';
/

comment on column formdata_text.data_details is '明细ID';
/

comment on column formdata_text.content is '文本';
/

comment on column formdata_text.tenant_key is '租户ID';
/

comment on column formdata_text.rich_content is '富文本';
/


create index IDX_FORMDATA_TEXT_TENANT_KEY
    on formdata_text (tenant_key);
/

create index IDX_FORMDATA_TEXT_DATADETAILS
    on formdata_text (data_details);
/

create table if not exists panel_field
(
    id                  numeric(20) not null
    constraint fert_panel_field_pkey
    primary key,
    form_id             numeric(20),
    component_key       varchar(50),
    tenant_key          varchar(10),
    title               varchar(100),
    describe            varchar(2000),
    show_order          double precision default 0::double precision,
    other_properties    text,
    layout_component_id varchar(32),
    is_delete           integer
    );
/
create index IDX_PANEL_FIELD_FORM_ID
    on panel_field (FORM_ID);
/

create table if not exists sub_form
(
    id                  numeric(20) not null
    constraint fert_sub_form_pkey
    primary key,
    form_id             numeric(20),
    tenant_key          varchar(10),
    tmp_sub_table       varchar(50),
    title               varchar(100),
    describe            varchar(2000),
    default_rows        numeric(5),
    data_table          varchar(100),
    data_key            varchar(32),
    layout_component_id varchar(32),
    show_order          double precision default 0::double precision,
    other_properties    text,
    is_delete           integer,
    create_time         timestamp,
    update_time         timestamp
    );
/


create index IDX_SUB_FORM_FORM_ID
    on sub_form (form_id);
/

create table if not exists fd_linkage_source_sql
(
    id          bigint not null
    constraint fert_fd_linkage_source_sql_pkey
    primary key,
    entity_id   bigint,
    sql_context text,
    sql_script  text,
    tenant_key  varchar(50)
    );
/


create index IDX_FD_LINKAGE_SOURCE_SQL_TK
    on fd_linkage_source_sql (tenant_key);
/

create index IDX_FD_LINKAGE_SOURCE_SQL_EI
    on fd_linkage_source_sql (entity_id);
/

create table if not exists fd_linkage_source_sql_column
(
    id           bigint not null
    constraint fert_fd_linkage_source_sql_column_pkey
    primary key,
    entity_id    bigint,
    source_field varchar(50),
    source_name  varchar(200),
    tenant_key   varchar(50)
    );
/


create index IDX_FD_LA_SOURCE_SQL_COLUMN_TK
    on fd_linkage_source_sql_column (tenant_key);
/

create index IDX_FD_LA_SOURCE_SQL_COLUMN_EI
    on fd_linkage_source_sql_column (entity_id);
/


create table if not exists fd_linkage_source_mapping
(
    id                  bigint not null
    constraint fert_fd_linkage_source_mapping_pkey
    primary key,
    entity_id           bigint,
    source_field        varchar(50),
    source_name         varchar(200),
    handle_mark         varchar(20),
    target_field        varchar(50),
    target_name         varchar(200),
    target_type         varchar(50),
    target_address      varchar(200),
    target_address_type varchar(50),
    tenant_key          varchar(50)
    );
/


create index IDX_FD_LA_SOURCE_MAPPING_TK
    on fd_linkage_source_mapping (tenant_key);
/

create index IDX_FD_LA_SOURCE_MAPPING_EI
    on fd_linkage_source_mapping (entity_id);
/

create table if not exists fd_linkage_source_excel
(
    id         bigint not null
    constraint fert_fd_linkage_source_excel_pkey
    primary key,
    entity_id  bigint,
    excel_id   bigint,
    excel_name varchar(200),
    tenant_key varchar(50)
    );
/


create index IDX_FD_LA_SOURCE_EXCEL_TK
    on fd_linkage_source_excel (tenant_key);
/

create index IDX_FD_LA_SOURCE_EXCEL_EI
    on fd_linkage_source_excel (entity_id);
/


create table if not exists fd_linkage_source_config_table
(
    id              bigint not null
    constraint fert_fd_linkage_source_config_table_pkey
    primary key,
    entity_id       bigint,
    source_field    varchar(20),
    source_name     varchar(200),
    table_title     varchar(200),
    table_nick_name varchar(200),
    join_type       varchar(200),
    join_condition  text,
    tenant_key      varchar(50)
    );
/


create index IDX_FD_LA_SE_CONFIG_TABLE_TK
    on fd_linkage_source_config_table (tenant_key);
/

create index IDX_FD_LA_SE_CONFIG_TABLE_EI
    on fd_linkage_source_config_table (entity_id);
/

create table if not exists fd_linkage_source_config_col
(
    id             bigint not null
    constraint fert_fd_linkage_source_config_col_pkey
    primary key,
    entity_id      bigint,
    column_table   varchar(50),
    column_type    varchar(50),
    column_field   varchar(50),
    column_title   varchar(50),
    operate        varchar(20),
    source_type    varchar(20),
    source_field   varchar(50),
    source_name    varchar(50),
    source_content text,
    tenant_key     varchar(50)
    );
/


create index IDX_FD_LA_SOURCE_CONFIG_COL_TK
    on fd_linkage_source_config_col (tenant_key);
/

create index IDX_FD_LA_SOURCE_CONFIG_COL_EI
    on fd_linkage_source_config_col (entity_id);
/

create table if not exists fd_linkage_source_config
(
    id              bigint not null
    constraint fert_fd_linkage_source_config_pkey
    primary key,
    entity_id       bigint,
    where_condition text,
    order_condition text,
    tenant_key      varchar(50)
    );
/


create index IDX_FD_LA_SE_CONFIG_TK
    on fd_linkage_source_config (tenant_key);
/

create index IDX_FD_LA_SE_CONFIG_EI
    on fd_linkage_source_config (entity_id);
/

create table if not exists fd_linkage_source
(
    id                  bigint not null
    constraint fert_fd_linkage_source_pkey
    primary key,
    entity_id           bigint,
    linkage_type        varchar(50),
    data_source_id      bigint,
    data_source_name    varchar(200),
    data_source_db_type varchar(200),
    data_type           varchar(50),
    tenant_key          varchar(50)
    );
/


create index IDX_FD_LA_SOURCE_TK
    on fd_linkage_source (tenant_key);
/

create index IDX_FD_LA_SOURCE_EI
    on fd_linkage_source (entity_id);
/

create table if not exists fd_linkage_monitor_field
(
    id           bigint not null
    constraint fert_fd_linkage_monitor_field_pkey
    primary key,
    entity_id    bigint,
    target_field varchar(50),
    target_name  varchar(200),
    tenant_key   varchar(50)
    );
/


create index IDX_FD_LA_MONITOR_FIELD_TK
    on fd_linkage_monitor_field (tenant_key);
/

create index IDX_FD_LA_MONITOR_FIELD_EI
    on fd_linkage_monitor_field (entity_id);
/

create table if not exists fd_linkage_monitor_action
(
    id          bigint not null
    constraint fert_fd_linkage_monitor_action_pkey
    primary key,
    entity_id   bigint,
    action_type varchar(200),
    action_name varchar(200),
    tenant_key  varchar(50)
    );
/


create index IDX_FD_LA_MONITOR_ACTION_TK
    on fd_linkage_monitor_action (tenant_key);
/

create index IDX_FD_LA_MONITOR_ACTION_EI
    on fd_linkage_monitor_action (entity_id);
/

create table if not exists fd_linkage_ext
(
    id                 bigint not null
    constraint fert_fd_linkage_ext_pkey
    primary key,
    entity_id          bigint,
    sub_form_like_type varchar(50),
    sub_form_add_type  varchar(50),
    effect_content     text,
    tenant_key         varchar(50)
    );
/


create index IDX_FD_LINKAGE_EXT_TK
    on fd_linkage_ext (entity_id);
/

create index IDX_FD_LINKAGE_EXT_EI
    on fd_linkage_ext (entity_id);
/

create table if not exists fd_linkage
(
    id             bigint not null
    constraint fert_fd_linkage_pkey
    primary key,
    linkage_name   varchar(255),
    linkage_module varchar(255),
    form_id        bigint default 0::bigint,
    ref_id         bigint default 0::bigint,
    linkage_state  integer,
    linkage_type   varchar(255),
    creator        bigint,
    create_time    timestamp,
    update_time    timestamp,
    tenant_key     varchar(50)
    );
/


create index IDX_FD_LINKAGE_TENANT_KEY
    on fd_linkage (tenant_key);
/

create index IDX_FD_LINKAGE_FORM_ID
    on fd_linkage (form_id);
/

create index IDX_FD_LINKAGE_REF_ID
    on fd_linkage (ref_id);
/


create table if not exists fd_effect_value
(
    id           bigint not null
    constraint fert_fd_effect_value_pkey
    primary key,
    effect_id    bigint,
    effect_value varchar(255),
    effect_name  varchar(255),
    tenant_key   varchar(50)
    );
/


create index IDX_FD_EFFECT_VALUE_TENANT_KEY
    on fd_effect_value (tenant_key);
/

create index IDX_FD_EFFECT_VALUE_EFFECT_ID
    on fd_effect_value (effect_id);
/

create index IDX_FD_EFFECT_VALUE_EV
    on fd_effect_value (effect_value);
/

create table if not exists fd_effect
(
    id            bigint not null
    constraint fert_fd_effect_pkey
    primary key,
    create_time   timestamp,
    update_time   timestamp,
    creator       bigint,
    delete_type   integer default 0,
    ref_id        varchar(50),
    form_id       bigint,
    effect_type   varchar(50),
    effect_name   varchar(200),
    effect_module varchar(50),
    tenant_key    varchar(50)
    );
/


create index IDX_FD_EFFECT_TENANT_KEY
    on fd_effect (tenant_key);
/

create index IDX_FD_EFFECT_REF_ID
    on fd_effect (ref_id);
/

create index IDX_FD_EFFECT_FORM_ID
    on fd_effect (form_id);
/

create table if not exists sub_form_config
(
    id               bigint not null
    constraint fert_sub_form_config_pkey
    primary key,
    create_time      timestamp,
    update_time      timestamp,
    delete_type      integer default 0,
    tenant_key       varchar(10),
    sub_form_id      bigint,
    default_rows     integer,
    max_rows         integer,
    required_rows    integer,
    filter_condition text,
    other_properties text,
    version_id       bigint,
    creator          bigint
    );
/


create index IDX_SUB_FORM_CONFIG_TENANT_KEY
    on sub_form_config (tenant_key);
/

create index IDX_SUB_FORM_CONFIG_SUB_FORM_I
    on sub_form_config (sub_form_id);
/

create index IDX_SUB_FORM_CONFIG_VERSION_ID
    on sub_form_config (version_id);
/

create table if not exists form_setting_logs_detail
(
    id               bigint not null
    primary key,
    create_time      timestamp default now(),
    update_time      timestamp default now(),
    creator          bigint,
    delete_type      integer   default 0,
    tenant_key       varchar(10),
    uuid             varchar(36),
    mainid           varchar(36),
    dataid           varchar(50),
    belongdataid     varchar(50),
    tablename        varchar(200),
    tablenamelabelid varchar(50),
    tablenamedesc    varchar(50),
    fieldname        varchar(200),
    fieldnamelabelid varchar(50),
    newvalue         text,
    oldvalue         text,
    newrealvalue     text,
    oldrealvalue     text,
    fielddesc        varchar(200),
    showorder        integer,
    isdetail         integer   default 0
    );
/


create index IDX_F_SETTING_LOGS_DETAIL_TK
    on form_setting_logs_detail (tenant_key);
/

create index IDX_F_SETTING_LOGS_DETAIL_MI
    on form_setting_logs_detail (mainid);
/

create table if not exists form_setting_logs
(
    id              bigint not null
    primary key,
    create_time     timestamp default now(),
    update_time     timestamp default now(),
    creator         bigint,
    delete_type     integer   default 0,
    tenant_key      varchar(10),
    uuid            varchar(36),
    log_date        timestamp default now(),
    device          varchar(500),
    log_operator    bigint,
    operatorname    varchar(100),
    targetid        bigint,
    targetname      varchar(3000),
    modulename      varchar(100),
    functionname    varchar(100),
    interfacename   varchar(100),
    requesturl      text,
    requesturi      text,
    operatetype     varchar(50),
    operatetypename varchar(100),
    operatedesc     varchar(3000),
    params          text,
    belongmainid    varchar(36),
    clientip        varchar(200),
    groupid         varchar(50),
    groupnamelabel  varchar(1000),
    redoservice     varchar(200),
    redocontext     text,
    cancelservice   varchar(200),
    cancelcontext   text,
    totalruntime    bigint,
    mainruntime     bigint,
    log_result      varchar(100),
    fromterminal    varchar(100),
    resultdesc      text,
    old_content     text,
    link_type       varchar(20),
    link_id         bigint,
    old_link_id     bigint
    );
/


create index IDX_FORM_SETTING_LOGS_TK
    on form_setting_logs (tenant_key);
/

create index IDX_FORM_SETTING_LOGS_LD
    on form_setting_logs (log_date);
/

create index IDX_FORM_SETTING_LOGS_TI
    on form_setting_logs (targetid);
/

create index IDX_FORM_SETTING_LOGS_MN
    on form_setting_logs (modulename);
/

create index IDX_FORM_SETTING_LOGS_FN
    on form_setting_logs (functionname);
/

create index IDX_FORM_SETTING_LOGS_U
    on form_setting_logs (uuid);
/