create table complex_field
(
    ID                  decimal(20) not null
        primary key,
    FORM_ID             decimal(20),
    TITLE               nvarchar(100),
    DESCRIBE            nvarchar(2000),
    COMPONENT_KEY       nvarchar(50),
    REQUIRED            nchar,
    IS_DELETE           nchar,
    TENANT_KEY          nvarchar(10),
    OPERATOR            decimal(20),
    CREATE_TIME         datetime,
    show_order          float default 0,
    other_properties    nvarchar(max),
    layout_component_id varchar(32)
)
    go

create index IDX_COMPLEX_FIELD_FORM_ID
    on complex_field (FORM_ID)
    go

create table fd_effect
(
    id            bigint not null
        primary key,
    create_time   datetime,
    update_time   datetime,
    creator       bigint,
    delete_type   int default 0,
    ref_id        nvarchar(50),
    form_id       bigint,
    effect_type   nvarchar(50),
    effect_name   nvarchar(200),
    effect_module nvarchar(50),
    tenant_key    nvarchar(50)
)
    go

create index IDX_FD_EFFECT_TENANT_KEY
    on fd_effect (tenant_key)
    go

create index IDX_FD_EFFECT_REF_ID
    on fd_effect (ref_id)
    go

create index IDX_FD_EFFECT_FORM_ID
    on fd_effect (form_id)
    go

create table fd_effect_value
(
    id           bigint not null
        primary key,
    effect_id    bigint,
    effect_value nvarchar(255),
    effect_name  nvarchar(255),
    tenant_key   nvarchar(50)
)
    go

create index IDX_FD_EFFECT_VALUE_TENANT_KEY
    on fd_effect_value (tenant_key)
    go

create index IDX_FD_EFFECT_VALUE_EFFECT_ID
    on fd_effect_value (effect_id)
    go

create index IDX_FD_EFFECT_VALUE_EV
    on fd_effect_value (effect_value)
    go

create table fd_linkage
(
    id             bigint not null
        primary key,
    linkage_name   nvarchar(255),
    linkage_module nvarchar(255),
    form_id        bigint default '0',
    ref_id         bigint default '0',
    linkage_state  int,
    linkage_type   nvarchar(255),
    creator        bigint,
    create_time    datetime,
    update_time    datetime,
    tenant_key     nvarchar(50)
)
    go

create index IDX_FD_LINKAGE_TENANT_KEY
    on fd_linkage (tenant_key)
    go

create index IDX_FD_LINKAGE_FORM_ID
    on fd_linkage (form_id)
    go

create index IDX_FD_LINKAGE_REF_ID
    on fd_linkage (ref_id)
    go

create table fd_linkage_ext
(
    id                 bigint not null
        primary key,
    entity_id          bigint,
    sub_form_like_type nvarchar(50),
    sub_form_add_type  nvarchar(50),
    effect_content     ntext,
    tenant_key         nvarchar(50)
)
    go

create index IDX_FD_LINKAGE_EXT_TK
    on fd_linkage_ext (tenant_key)
    go

create index IDX_FD_LINKAGE_EXT_EI
    on fd_linkage_ext (entity_id)
    go

create table fd_linkage_monitor_action
(
    id          bigint not null
        primary key,
    entity_id   bigint,
    action_type nvarchar(200),
    action_name nvarchar(200),
    tenant_key  nvarchar(50)
)
    go

create index IDX_FD_LA_MONITOR_ACTION_TK
    on fd_linkage_monitor_action (tenant_key)
    go

create index IDX_FD_LA_MONITOR_ACTION_EI
    on fd_linkage_monitor_action (entity_id)
    go

create table fd_linkage_monitor_field
(
    id           bigint not null
        primary key,
    entity_id    bigint,
    target_field nvarchar(50),
    target_name  nvarchar(200),
    tenant_key   nvarchar(50)
)
    go

create index IDX_FD_LA_MONITOR_FIELD_TK
    on fd_linkage_monitor_field (tenant_key)
    go

create index IDX_FD_LA_MONITOR_FIELD_EI
    on fd_linkage_monitor_field (entity_id)
    go

create table fd_linkage_source
(
    id                  bigint not null
        primary key,
    entity_id           bigint,
    linkage_type        nvarchar(50),
    data_source_id      bigint,
    data_source_name    nvarchar(200),
    data_source_db_type nvarchar(200),
    data_type           nvarchar(50),
    tenant_key          nvarchar(50)
)
    go

create index IDX_FD_LINKAGE_SOURCE_TK
    on fd_linkage_source (tenant_key)
    go

create index IDX_FD_LINKAGE_SOURCE_EI
    on fd_linkage_source (entity_id)
    go

create table fd_linkage_source_config
(
    id              bigint not null
        primary key,
    entity_id       bigint,
    where_condition ntext,
    order_condition ntext,
    tenant_key      nvarchar(50)
)
    go

create index IDX_FD_LA_SOURCE_CONFIG_TK
    on fd_linkage_source_config (tenant_key)
    go

create index IDX_FD_LA_SOURCE_CONFIG_EI
    on fd_linkage_source_config (entity_id)
    go

create table fd_linkage_source_config_col
(
    id             bigint not null
        primary key,
    entity_id      bigint,
    column_table   nvarchar(50),
    column_type    nvarchar(50),
    column_field   nvarchar(50),
    column_title   nvarchar(50),
    operate        nvarchar(20),
    source_type    nvarchar(20),
    source_field   nvarchar(50),
    source_name    nvarchar(50),
    source_content ntext,
    tenant_key     nvarchar(50)
)
    go

create index IDX_FD_LA_SOURCE_CONFIG_COL_TK
    on fd_linkage_source_config_col (tenant_key)
    go

create index IDX_FD_LA_SOURCE_CONFIG_COL_EI
    on fd_linkage_source_config_col (entity_id)
    go

create table fd_linkage_source_config_table
(
    id              bigint not null
        primary key,
    entity_id       bigint,
    source_field    nvarchar(20),
    source_name     nvarchar(200),
    table_title     nvarchar(200),
    table_nick_name nvarchar(200),
    join_type       nvarchar(200),
    join_condition  ntext,
    tenant_key      nvarchar(50)
)
    go

create index IDX_FD_LA_SE_CONFIG_TABLE_TK
    on fd_linkage_source_config_table (tenant_key)
    go

create index IDX_FD_LA_SE_CONFIG_TABLE_EI
    on fd_linkage_source_config_table (entity_id)
    go

create table fd_linkage_source_excel
(
    id         bigint not null
        primary key,
    entity_id  bigint,
    excel_id   bigint,
    excel_name nvarchar(200),
    tenant_key nvarchar(50)
)
    go

create index IDX_FD_LA_SOURCE_EXCEL_TK
    on fd_linkage_source_excel (tenant_key)
    go

create index IDX_FD_LA_SOURCE_EXCEL_EI
    on fd_linkage_source_excel (entity_id)
    go

create table fd_linkage_source_mapping
(
    id                  bigint not null
        primary key,
    entity_id           bigint,
    source_field        nvarchar(50),
    source_name         nvarchar(200),
    handle_mark         nvarchar(20),
    target_field        nvarchar(50),
    target_name         nvarchar(200),
    target_type         nvarchar(50),
    target_address      nvarchar(200),
    target_address_type nvarchar(50),
    tenant_key          nvarchar(50)
)
    go

create index IDX_FD_LA_SOURCE_MAPPING_TK
    on fd_linkage_source_mapping (tenant_key)
    go

create index IDX_FD_LA_SOURCE_MAPPING_EI
    on fd_linkage_source_mapping (entity_id)
    go

create table fd_linkage_source_sql
(
    id          bigint not null
        primary key,
    entity_id   bigint,
    sql_context ntext,
    sql_script  ntext,
    tenant_key  nvarchar(50)
)
    go

create index IDX_FD_LINKAGE_SOURCE_SQL_TK
    on fd_linkage_source_sql (tenant_key)
    go

create index IDX_FD_LINKAGE_SOURCE_SQL_EI
    on fd_linkage_source_sql (entity_id)
    go

create table fd_linkage_source_sql_column
(
    id           bigint not null
        primary key,
    entity_id    bigint,
    source_field nvarchar(50),
    source_name  nvarchar(200),
    tenant_key   nvarchar(50)
)
    go

create index IDX_FD_LA_SOURCE_SQL_COLUMN_TK
    on fd_linkage_source_sql_column (tenant_key)
    go

create index IDX_FD_LA_SOURCE_SQL_COLUMN_EI
    on fd_linkage_source_sql_column (entity_id)
    go

create table field_layout
(
    ID            decimal(20) not null
        primary key,
    PARENT_ID     decimal(20),
    FIELD_ID      decimal(20),
    FIELD_TYPE    nvarchar(10),
    LAYOUT_ID     decimal(20),
    LAYOUT_DETAIL nvarchar(max),
    TENANT_KEY    nvarchar(10),
    OPERATOR      decimal(20),
    CREATE_TIME   datetime,
    UPDATE_TIME   datetime,
    STATUS        nchar
)
    go

exec sp_addextendedproperty 'MS_Description', '字段状态：0-最新版本，1-历史版本', 'SCHEMA', 'dbo', 'TABLE', 'field_layout', 'COLUMN',
     'STATUS'
go

create index IDX_FIELD_LAYOUT_FIELD_ID
    on field_layout (FIELD_ID)
    go

create index IDX_FIELD_LAYOUT_LAYOUT_ID
    on field_layout (LAYOUT_ID)
    go

create index IDX_FIELD_LAYOUT_FIELD_TYPE
    on field_layout (FIELD_TYPE)
    go

create index IDX_FIELD_LAYOUT_UPDATE_TIME
    on field_layout (UPDATE_TIME)
    go

create table field_option
(
    ID           decimal(20)       not null
        primary key,
    FIELD_ID     decimal(20),
    PARENT_ID    decimal(20),
    NAME         nvarchar(100),
    [ORDER]      decimal(5),
    OTHER        nchar,
    IS_DELETE    nchar,
    TENANT_KEY   nvarchar(10),
    OPERATOR     decimal(20),
    CREATE_TIME  datetime,
    TMP_OPTION   nvarchar(50),
    UID          nvarchar(100),
    style_config nvarchar(max),
    extra        nvarchar(max),
    archive      tinyint default 0 not null
    )
    go

exec sp_addextendedproperty 'MS_Description', '选项设置', 'SCHEMA', 'dbo', 'TABLE', 'field_option', 'COLUMN', 'style_config'
go

create index IDX_FIELD_OPTION_FIELD_ID
    on field_option (FIELD_ID)
    go

create index IDX_FIELD_OPTION_PARENT_ID
    on field_option (PARENT_ID)
    go

create table field_permission
(
    ID          decimal(20) not null
        primary key,
    FORM_ID     decimal(20),
    TENANT_KEY  nvarchar(20),
    MODULE      nvarchar(50),
    CREATOR     decimal(20),
    CREATE_TIME datetime,
    UPDATE_TIME datetime,
    IS_DELETE   nvarchar,
    datasrc     int
)
    go

exec sp_addextendedproperty 'MS_Description', '字段权限', 'SCHEMA', 'dbo', 'TABLE', 'field_permission'
go

exec sp_addextendedproperty 'MS_Description', '主键ID', 'SCHEMA', 'dbo', 'TABLE', 'field_permission', 'COLUMN', 'ID'
go

exec sp_addextendedproperty 'MS_Description', '表单ID', 'SCHEMA', 'dbo', 'TABLE', 'field_permission', 'COLUMN', 'FORM_ID'
go

exec sp_addextendedproperty 'MS_Description', '租户key', 'SCHEMA', 'dbo', 'TABLE', 'field_permission', 'COLUMN',
     'TENANT_KEY'
go

exec sp_addextendedproperty 'MS_Description', '所属模块', 'SCHEMA', 'dbo', 'TABLE', 'field_permission', 'COLUMN', 'MODULE'
go

exec sp_addextendedproperty 'MS_Description', '创建人', 'SCHEMA', 'dbo', 'TABLE', 'field_permission', 'COLUMN', 'CREATOR'
go

exec sp_addextendedproperty 'MS_Description', '创建时间', 'SCHEMA', 'dbo', 'TABLE', 'field_permission', 'COLUMN',
     'CREATE_TIME'
go

exec sp_addextendedproperty 'MS_Description', '更新时间', 'SCHEMA', 'dbo', 'TABLE', 'field_permission', 'COLUMN',
     'UPDATE_TIME'
go

exec sp_addextendedproperty 'MS_Description', '是否删除(0-未删除,1-已删除)', 'SCHEMA', 'dbo', 'TABLE', 'field_permission',
     'COLUMN', 'IS_DELETE'
go

exec sp_addextendedproperty 'MS_Description', '是否迁移数据', 'SCHEMA', 'dbo', 'TABLE', 'field_permission', 'COLUMN',
     'datasrc'
go

create index IDX_FIELD_PERMISSION_FORM_ID
    on field_permission (FORM_ID)
    go

create table field_permission_detail
(
    ID            decimal(20) not null
        primary key,
    FIELD_ID      decimal(20) not null,
    FIELD_READ    nvarchar    not null,
    FIELD_WRITE   nvarchar    not null,
    IS_DELETE     nvarchar,
    PERMISSION_ID decimal(20),
    datasrc       int,
    TENANT_KEY    nvarchar(20),
    required      nvarchar,
    disable_edit  nvarchar
)
    go

exec sp_addextendedproperty 'MS_Description', '字段权限详情', 'SCHEMA', 'dbo', 'TABLE', 'field_permission_detail'
go

exec sp_addextendedproperty 'MS_Description', '主键ID', 'SCHEMA', 'dbo', 'TABLE', 'field_permission_detail', 'COLUMN',
     'ID'
go

exec sp_addextendedproperty 'MS_Description', '表单字段ID', 'SCHEMA', 'dbo', 'TABLE', 'field_permission_detail', 'COLUMN',
     'FIELD_ID'
go

exec sp_addextendedproperty 'MS_Description', '字段读权限（查看）', 'SCHEMA', 'dbo', 'TABLE', 'field_permission_detail',
     'COLUMN', 'FIELD_READ'
go

exec sp_addextendedproperty 'MS_Description', '字段写权限（填写）', 'SCHEMA', 'dbo', 'TABLE', 'field_permission_detail',
     'COLUMN', 'FIELD_WRITE'
go

exec sp_addextendedproperty 'MS_Description', '是否删除(0-未删除,1-已删除)', 'SCHEMA', 'dbo', 'TABLE', 'field_permission_detail',
     'COLUMN', 'IS_DELETE'
go

exec sp_addextendedproperty 'MS_Description', '字段权限ID', 'SCHEMA', 'dbo', 'TABLE', 'field_permission_detail', 'COLUMN',
     'PERMISSION_ID'
go

exec sp_addextendedproperty 'MS_Description', '是否迁移数据', 'SCHEMA', 'dbo', 'TABLE', 'field_permission_detail', 'COLUMN',
     'datasrc'
go

exec sp_addextendedproperty 'MS_Description', '租户key', 'SCHEMA', 'dbo', 'TABLE', 'field_permission_detail', 'COLUMN',
     'TENANT_KEY'
go

create index IDX_FIELD_PERMISSION_DETAIL_FD
    on field_permission_detail (FIELD_ID)
    go

create index IDX_FIELD_PERMISSION_DETAIL_PD
    on field_permission_detail (PERMISSION_ID)
    go

create table form
(
    ID               decimal(20)                    not null
        primary key,
    NAME             nvarchar(100),
    DESCRIBE         nvarchar(2000),
    STATUS           nvarchar(50),
    SOURCE_ID        decimal(20),
    OWNERSHIP        nvarchar(50),
    TENANT_KEY       nvarchar(10),
    OPERATOR         decimal(20),
    CREATE_TIME      datetime,
    UPDATE_TIME      datetime,
    IS_DELETE        nchar,
    CATEGORY_ID      decimal(20),
    ICON             nvarchar(50),
    TMP_TABLE        decimal(20),
    TMP_LAYOUT       decimal(20),
    SORT             decimal(5),
    RECOMMEND        nchar,
    BIAOGE_RECOMMEND nchar,
    MODULE           nvarchar(50),
    RELATEFLOW       nchar,
    REVIEW_COUNT     decimal(10),
    EXPORT_COUNT     decimal(10),
    COPY_COUNT       decimal(10),
    VIEW_COUNT       decimal(10),
    FILL_COUNT       decimal(10),
    DELETE_USER      decimal(20),
    REPORT           decimal(20),
    collect_status   nvarchar(10)
        constraint form_df_collect_status default 'disable',
    TARGET_ID        decimal(20),
    DFAPTION         int,
    IS_ADVANCE       tinyint
        constraint form_df_IS_ADVANCE default 0,
    inherit          nchar
        constraint form_df_inherit default '0',
    IS_MULTI         nchar,
    ATTR_NAME        nvarchar(50),
    PHYSICAL_TABLE   tinyint
        constraint form_df_PHYSICAL_TABLE default 0 not null,
    org_id           bigint
)
    go

exec sp_addextendedproperty 'MS_Description', '字段权限继承', 'SCHEMA', 'dbo', 'TABLE', 'form', 'COLUMN', 'inherit'
go

exec sp_addextendedproperty 'MS_Description', '是否为多布局表单：0-否，1-是', 'SCHEMA', 'dbo', 'TABLE', 'form', 'COLUMN', 'IS_MULTI'
go

exec sp_addextendedproperty 'MS_Description', '是否是物理表 0 不是 1是', 'SCHEMA', 'dbo', 'TABLE', 'form', 'COLUMN',
     'PHYSICAL_TABLE'
go

create index IDX_FORM_TENANTKEY
    on form (TENANT_KEY)
    go

create index IDX_FORM_CATEGORY
    on form (CATEGORY_ID)
    go

create index IDX_FORM_OPERATOR
    on form (OPERATOR)
    go

create index IDX_FORM_OWNERSHIP
    on form (OWNERSHIP)
    go

create index IDX_FORM_MODULE
    on form (MODULE)
    go

create index IDX_FORM_TARGET_ID
    on form (TARGET_ID)
    go

create index IDX_FORM_SORT
    on form (SORT)
    go

create index IDX_FORM_STATUS
    on form (STATUS)
    go

create index IDX_FORM_REPORT
    on form (REPORT)
    go

create index IDX_FORM_BIAOGE_RECOMMEND
    on form (BIAOGE_RECOMMEND)
    go

create index IDX_FORM_ORG_ID
    on form (org_id)
    go

create index IDX_FORM_CREATE_TIME
    on form (CREATE_TIME)
    go

create table form_attachment_config
(
    id                    bigint not null
        primary key,
    create_time           datetime,
    update_time           datetime,
    creator               bigint,
    delete_type           int default 0,
    tenant_key            nvarchar(10),
    ref_id                bigint,
    folder_select_type    int default 0,
    folder_id             bigint,
    custom_limit_format   nvarchar(500),
    attment_size_limit    int default 3,
    custom_attment_size   nvarchar(20),
    forbin_batch_download int default 0,
    sec_level             int default 1,
    show_format           int default 0,
    attach_upload_user    bigint,
    config_type           int,
    form_id               bigint,
    field_id              bigint,
    folder_type           int default 0,
    limit_type            int default 0,
    other_type            int default 0,
    option_id             bigint,
    attach_upload_time    int
)
    go

create index IDX_FORM_ATTACHMENT_CONFIG_TK
    on form_attachment_config (tenant_key)
    go

create index IDX_FORM_ATTACHMENT_CONFIG_FMI
    on form_attachment_config (form_id)
    go

create index IDX_FORM_ATTACHMENT_CONFIG_FDI
    on form_attachment_config (field_id)
    go

create table form_category
(
    ID          decimal(20) not null
        primary key,
    NAME        nvarchar(100),
    SORT        decimal(5),
    TENANT_KEY  nvarchar(10),
    OPERATOR    decimal(20),
    CREATE_TIME datetime,
    type        nvarchar(20),
    module      nvarchar(20)
)
    go

create index IDX_FORM_CATEGORY_TENANT_KEY
    on form_category (TENANT_KEY)
    go

create table form_data_details_encdata
(
    id         bigint         not null
        primary key,
    tenant_key nvarchar(10)   not null,
    table_name nvarchar(50)   not null,
    field_name nvarchar(50)   not null,
    enc_value  nvarchar(4000) not null,
    crc        nvarchar(4000),
    creater    bigint,
    created    datetime,
    modifier   bigint,
    modified   datetime,
    skey       nvarchar(2000) not null
)
    go

create index IDX_FD_DETAILS_ENCDATA_TK
    on form_data_details_encdata (tenant_key)
    go

create index IDX_FD_DETAILS_ENCDATA_TN
    on form_data_details_encdata (table_name)
    go

create index IDX_FD_DETAILS_ENCDATA_FN
    on form_data_details_encdata (field_name)
    go

create table form_data_layout_rel
(
    ID                 decimal(20) not null
        primary key,
    FORM_DATA          decimal(20),
    MULTIPLE_LAYOUT_ID decimal(20),
    VERSION_ID         decimal(20),
    TENANT_KEY         nvarchar(10)
)
    go

exec sp_addextendedproperty 'MS_Description', '表单数据Id', 'SCHEMA', 'dbo', 'TABLE', 'form_data_layout_rel', 'COLUMN',
     'FORM_DATA'
go

exec sp_addextendedproperty 'MS_Description', '多布局Id', 'SCHEMA', 'dbo', 'TABLE', 'form_data_layout_rel', 'COLUMN',
     'MULTIPLE_LAYOUT_ID'
go

exec sp_addextendedproperty 'MS_Description', '布局版本Id', 'SCHEMA', 'dbo', 'TABLE', 'form_data_layout_rel', 'COLUMN',
     'VERSION_ID'
go

exec sp_addextendedproperty 'MS_Description', '租户Key', 'SCHEMA', 'dbo', 'TABLE', 'form_data_layout_rel', 'COLUMN',
     'TENANT_KEY'
go

create index IDX_FORM_DATA_LAYOUT_REL_FD
    on form_data_layout_rel (FORM_DATA)
    go

create index IDX_FORM_DATA_LAYOUT_REL_MLI
    on form_data_layout_rel (MULTIPLE_LAYOUT_ID)
    go

create index IDX_FORM_DATA_LAYOUT_REL_VI
    on form_data_layout_rel (VERSION_ID)
    go

create table form_data_relate_config
(
    id               bigint not null
        primary key,
    create_time      datetime,
    update_time      datetime,
    operator         bigint,
    delete_type      int,
    tenant_key       nvarchar(10),
    field_id         decimal(38),
    express_id       bigint,
    monitor_fields   nvarchar(max),
    relate_field     nvarchar(max),
    relate_datatable nvarchar(max),
    relate_multiple  nvarchar,
    version_id       decimal(38),
    is_delete        int
)
    go

create index IDX_FDRC_TENANT_KEY
    on form_data_relate_config (tenant_key)
    go

create index IDX_FDRC_FIELD_ID
    on form_data_relate_config (field_id)
    go

create index IDX_FDRC_VERSION_ID
    on form_data_relate_config (version_id)
    go

create table form_field
(
    ID                  decimal(20) not null
        primary key,
    FORM_ID             decimal(20),
    SUB_FORM_ID         decimal(20),
    TITLE               nvarchar(100),
    DESCRIBE            nvarchar(2000),
    DATA_TYPE           nvarchar(50),
    REQUIRED            nchar,
    IS_DELETE           nchar,
    TENANT_KEY          nvarchar(10),
    OPERATOR            decimal(20),
    CREATE_TIME         datetime,
    COMPONENT_KEY       nvarchar(50),
    TMP_FIELD           nvarchar(50),
    COMPLEX_ID          decimal(20),
    UPDATE_TIME         datetime,
    SOURCE_MODULE       nvarchar(20),
    DATA_TEMPLATE_ID    decimal(20),
    EXPRESS_ID          bigint,
    ATTR_NAME           nvarchar(50),
    show_order          float default 0,
    group_id            decimal(20),
    other_properties    nvarchar(max),
    single              tinyint       default 1,
    data_key            varchar(32),
    layout_component_id varchar(32),
    archive             tinyint       default 0,
    browser_module      nvarchar(32),
    browser_type        nvarchar(64),
    parent_id           decimal(20),
    custom_order        smallint,
    default_order       smallint
)
    go

exec sp_addextendedproperty 'MS_Description', 'Excel函数公式ID', 'SCHEMA', 'dbo', 'TABLE', 'form_field', 'COLUMN',
     'EXPRESS_ID'
go

create index IDX_FORM_FIELD_FORM_ID
    on form_field (FORM_ID)
    go

create index IDX_FORM_FIELD_COMPONENT_KEY
    on form_field (COMPONENT_KEY)
    go

create index IDX_FORM_FIELD_COMPLEX_FIELD
    on form_field (COMPLEX_ID)
    go

create index IDX_FORM_FIELD_SUB_FORM_ID
    on form_field (SUB_FORM_ID)
    go

create index IDX_FORM_FIELD_DATA_TEMPLATE_I
    on form_field (DATA_TEMPLATE_ID)
    go

create index IDX_FORM_FIELD_EXPRESS_ID
    on form_field (EXPRESS_ID)
    go

create index IDX_FORM_FIELD_BM_BT_TK
    on form_field (browser_module, browser_type, TENANT_KEY)
    go

create index IDX_FORM_FIELD_DK_TK
    on form_field (data_key, TENANT_KEY)
    go

create index IDX_FORM_FIELD_UPDATE_TIME
    on form_field (UPDATE_TIME)
    go

create table form_field_group
(
    id          decimal(38)  not null
        primary key,
    group_name  nvarchar(64) not null,
    icon        nvarchar(64),
    operator    decimal(20)  not null,
    is_delete   tinyint,
    tenant_key  nvarchar(10),
    create_time datetime     not null,
    update_time datetime,
    form_id     decimal(20)  not null,
    show_order  float
)
    go

create index IDX_FORM_FIELD_GROUP_TK
    on form_field_group (tenant_key)
    go

create index IDX_FORM_FIELD_GROUP_NAME
    on form_field_group (group_name)
    go

create index IDX_FORM_FIELD_GROUP_FI_TK
    on form_field_group (form_id, tenant_key)
    go

create table form_field_language
(
    ID              decimal(20) not null
        primary key,
    FORM_ID         decimal(20),
    FIELD_ID        decimal(20) not null,
    COMPONENT_KEY   nvarchar(50),
    LANGUAGE_DETAIL nvarchar(max),
    IS_DELETE       nchar,
    CREATE_TIME     datetime,
    UPDATE_TIME     datetime,
    TENANT_KEY      nvarchar(20)
)
    go

exec sp_addextendedproperty 'MS_Description', '主键ID', 'SCHEMA', 'dbo', 'TABLE', 'form_field_language', 'COLUMN', 'ID'
go

exec sp_addextendedproperty 'MS_Description', '表单ID', 'SCHEMA', 'dbo', 'TABLE', 'form_field_language', 'COLUMN',
     'FORM_ID'
go

exec sp_addextendedproperty 'MS_Description', '表单字段ID', 'SCHEMA', 'dbo', 'TABLE', 'form_field_language', 'COLUMN',
     'FIELD_ID'
go

exec sp_addextendedproperty 'MS_Description', '控件Key', 'SCHEMA', 'dbo', 'TABLE', 'form_field_language', 'COLUMN',
     'COMPONENT_KEY'
go

exec sp_addextendedproperty 'MS_Description', '多语言设置明细', 'SCHEMA', 'dbo', 'TABLE', 'form_field_language', 'COLUMN',
     'LANGUAGE_DETAIL'
go

exec sp_addextendedproperty 'MS_Description', '国际化信息是否删除：0-否 1-是', 'SCHEMA', 'dbo', 'TABLE', 'form_field_language',
     'COLUMN', 'IS_DELETE'
go

exec sp_addextendedproperty 'MS_Description', '创建时间', 'SCHEMA', 'dbo', 'TABLE', 'form_field_language', 'COLUMN',
     'CREATE_TIME'
go

exec sp_addextendedproperty 'MS_Description', '更新时间', 'SCHEMA', 'dbo', 'TABLE', 'form_field_language', 'COLUMN',
     'UPDATE_TIME'
go

exec sp_addextendedproperty 'MS_Description', '租户key', 'SCHEMA', 'dbo', 'TABLE', 'form_field_language', 'COLUMN',
     'TENANT_KEY'
go

create index IDX_FORM_FIELD_LANGUAGE_FORM_I
    on form_field_language (FORM_ID)
    go

create index IDX_FORM_FIELD_LANGUAGE_FIELD_I
    on form_field_language (FIELD_ID)
    go

create table form_fieldmanagelogs
(
    id              bigint not null
        primary key,
    create_time     datetime2 default getdate(),
    update_time     datetime2 default getdate(),
    creator         bigint    default '-1',
    delete_type     bigint    default 0,
    tenant_key      nvarchar(10),
    uuid            nvarchar(36),
    log_date        datetime2 default getdate(),
    device          nvarchar(500),
    log_operator    bigint    default '-1',
    operatorname    nvarchar(100),
    targetid        bigint    default '-1',
    targetname      nvarchar(3000),
    modulename      nvarchar(100),
    functionname    nvarchar(100),
    interfacename   nvarchar(100),
    requesturl      nvarchar(200),
    requesturi      nvarchar(200),
    operatetype     nvarchar(50),
    operatetypename nvarchar(100),
    operatedesc     nvarchar(3000),
    params          ntext,
    belongmainid    nvarchar(36),
    clientip        nvarchar(200),
    groupid         nvarchar(50),
    groupnamelabel  nvarchar(1000),
    redoservice     nvarchar(200),
    redocontext     nvarchar(3000),
    cancelservice   nvarchar(200),
    cancelcontext   nvarchar(3000),
    totalruntime    bigint    default 0,
    mainruntime     bigint    default 0,
    log_result      nvarchar(100),
    fromterminal    nvarchar(100),
    resultdesc      nvarchar(3000),
    old_content     nvarchar(3000),
    link_type       nvarchar(20),
    link_id         bigint    default 0,
    old_link_id     bigint    default 0
)
    go

create index IDX_FORM_FIELDMANAGE_LOGS_LD
    on form_fieldmanagelogs (log_date)
    go

create index IDX_FORM_FIELDMANAGELOGS_TK
    on form_fieldmanagelogs (tenant_key)
    go

create index IDX_FORM_FIELDMANAGELOGS_U
    on form_fieldmanagelogs (uuid)
    go

create index IDX_FORM_FIELDMANAGELOGS_TI
    on form_fieldmanagelogs (targetid)
    go

create index IDX_FORM_FIELDMANAGELOGS_MN
    on form_fieldmanagelogs (modulename)
    go

create index IDX_FORM_FIELDMANAGELOGS_FN
    on form_fieldmanagelogs (functionname)
    go

create table form_fieldmanagelogs_detail
(
    id               bigint not null
        primary key,
    create_time      datetime2 default getdate(),
    update_time      datetime2 default getdate(),
    creator          bigint,
    delete_type      bigint,
    tenant_key       nvarchar(10),
    uuid             nvarchar(36),
    mainid           nvarchar(36),
    dataid           nvarchar(50),
    belongdataid     nvarchar(50),
    tableName        nvarchar(200),
    tablenamelabelid nvarchar(50),
    tablenamedesc    nvarchar(50),
    fieldName        nvarchar(200),
    fieldnamelabelid nvarchar(200),
    newValue         ntext,
    oldValue         ntext,
    newrealvalue     ntext,
    oldrealvalue     ntext,
    fieldDesc        varchar(200),
    showorder        bigint    default 0,
    isdetail         bigint    default 0
)
    go

create index IDX_F_FIELDMANAGELOGS_TK
    on form_fieldmanagelogs_detail (tenant_key)
    go

create index IDX_F_FMANAGELOGS_DETAIL_MI
    on form_fieldmanagelogs_detail (mainid)
    go

create index IDX_F_FIELDMANAGELOGS_U_MI
    on form_fieldmanagelogs_detail (uuid, mainid)
    go

create index IDX_F_FIELDMANAGELOGS_U
    on form_fieldmanagelogs_detail (uuid)
    go

create table form_layout_multiple
(
    ID            decimal(20) not null
        primary key,
    NAME          nvarchar(100),
    DESCRIBE      nvarchar(2000),
    FORM_ID       decimal(20),
    TENANT_KEY    nvarchar(10),
    OPERATOR      decimal(20),
    CREATE_TIME   datetime,
    UPDATE_TIME   datetime,
    IS_DEFAULT    nchar,
    IS_DELETE     nchar,
    VERSION_ID    decimal(20),
    layout_type   nvarchar(20),
    terminal_type nvarchar(20)
)
    go

exec sp_addextendedproperty 'MS_Description', '表单多布局', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_multiple'
go

exec sp_addextendedproperty 'MS_Description', '布局ID', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_multiple', 'COLUMN', 'ID'
go

exec sp_addextendedproperty 'MS_Description', '布局名称', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_multiple', 'COLUMN', 'NAME'
go

exec sp_addextendedproperty 'MS_Description', '布局描述', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_multiple', 'COLUMN',
     'DESCRIBE'
go

exec sp_addextendedproperty 'MS_Description', '表单ID', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_multiple', 'COLUMN',
     'FORM_ID'
go

exec sp_addextendedproperty 'MS_Description', '租户Key', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_multiple', 'COLUMN',
     'TENANT_KEY'
go

exec sp_addextendedproperty 'MS_Description', '创建人', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_multiple', 'COLUMN',
     'OPERATOR'
go

exec sp_addextendedproperty 'MS_Description', '创建时间', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_multiple', 'COLUMN',
     'CREATE_TIME'
go

exec sp_addextendedproperty 'MS_Description', '更新时间', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_multiple', 'COLUMN',
     'UPDATE_TIME'
go

exec sp_addextendedproperty 'MS_Description', '是否为默认布局(0-否, 1-是)', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_multiple',
     'COLUMN', 'IS_DEFAULT'
go

exec sp_addextendedproperty 'MS_Description', '是否为删除(0-未删除, 1-回收站, 2-彻底删除)', 'SCHEMA', 'dbo', 'TABLE',
     'form_layout_multiple', 'COLUMN', 'IS_DELETE'
go

exec sp_addextendedproperty 'MS_Description', '最新版本布局ID', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_multiple', 'COLUMN',
     'VERSION_ID'
go

create index IDX_FORM_LAYOUT_MULTIPLE_FORM_ID
    on form_layout_multiple (FORM_ID)
    go

create index IDX_FORM_LAYOUT_MULTIPLE_VI
    on form_layout_multiple (VERSION_ID)
    go

create table form_layout_style
(
    ID            decimal(20) not null
        primary key,
    FORM_ID       decimal(20),
    LAYOUT_TYPE   nvarchar(50),
    COLOR_SCHEME  nvarchar(50),
    LAYOUT_DETAIL nvarchar(max),
    TENANT_KEY    nvarchar(10),
    OPERATOR      decimal(20),
    CREATE_TIME   datetime,
    UPDATE_TIME   datetime,
    LAYOUT_HTML   nvarchar(max),
    LAYOUT_STYLE  nvarchar(max),
    MOBILE_INDEXS nvarchar(max)
)
    go

create index IDX_FORM_LAYOUT_STYLE_FORM_ID
    on form_layout_style (FORM_ID)
    go

create index IDX_FORM_LAYOUT_STYLE_TK
    on form_layout_style (TENANT_KEY)
    go

create table form_layout_version
(
    ID                 decimal(20) not null
        primary key,
    NAME               nvarchar(100),
    DESCRIBE           nvarchar(2000),
    FORM_ID            decimal(20),
    LAYOUT_TYPE        nvarchar(50),
    COLOR_SCHEME       nvarchar(50),
    LAYOUT_DETAIL      nvarchar(max),
    TENANT_KEY         nvarchar(10),
    OPERATOR           decimal(20),
    CREATE_TIME        datetime,
    UPDATE_TIME        datetime,
    LAYOUT_HTML        nvarchar(max),
    MOBILE_INDEXS      nvarchar(max),
    MULTIPLE_LAYOUT_ID decimal(20)
)
    go

exec sp_addextendedproperty 'MS_Description', '表单布局历史版本', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version'
go

exec sp_addextendedproperty 'MS_Description', '布局版本ID', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version', 'COLUMN', 'ID'
go

exec sp_addextendedproperty 'MS_Description', '布局名称', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version', 'COLUMN', 'NAME'
go

exec sp_addextendedproperty 'MS_Description', '布局描述', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version', 'COLUMN',
     'DESCRIBE'
go

exec sp_addextendedproperty 'MS_Description', '表单ID', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version', 'COLUMN',
     'FORM_ID'
go

exec sp_addextendedproperty 'MS_Description', '布局类型', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version', 'COLUMN',
     'LAYOUT_TYPE'
go

exec sp_addextendedproperty 'MS_Description', '配色方案', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version', 'COLUMN',
     'COLOR_SCHEME'
go

exec sp_addextendedproperty 'MS_Description', '布局明细', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version', 'COLUMN',
     'LAYOUT_DETAIL'
go

exec sp_addextendedproperty 'MS_Description', '租户Key', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version', 'COLUMN',
     'TENANT_KEY'
go

exec sp_addextendedproperty 'MS_Description', '创建人', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version', 'COLUMN',
     'OPERATOR'
go

exec sp_addextendedproperty 'MS_Description', '创建时间', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version', 'COLUMN',
     'CREATE_TIME'
go

exec sp_addextendedproperty 'MS_Description', '更新时间', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version', 'COLUMN',
     'UPDATE_TIME'
go

exec sp_addextendedproperty 'MS_Description', '高级表单-布局HTML明细', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version',
     'COLUMN', 'LAYOUT_HTML'
go

exec sp_addextendedproperty 'MS_Description', '高级表单移动端-字段显示顺序', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version',
     'COLUMN', 'MOBILE_INDEXS'
go

exec sp_addextendedproperty 'MS_Description', '多布局ID', 'SCHEMA', 'dbo', 'TABLE', 'form_layout_version', 'COLUMN',
     'MULTIPLE_LAYOUT_ID'
go

create index IDX_FORM_LAYOUT_VERSION_F_ID
    on form_layout_version (FORM_ID)
    go

create index IDX_FORM_LAYOUT_VERSION_MLD
    on form_layout_version (MULTIPLE_LAYOUT_ID)
    go

create table form_option_sub_filter_config
(
    id             bigint,
    create_time    datetime     not null,
    update_time    datetime,
    creator        bigint       not null,
    delete_type    int          not null,
    tenant_key     nvarchar(10) not null,
    main_field     bigint       not null,
    sub_field      bigint       not null,
    form_id        bigint       not null,
    option_ids     ntext,
    main_option_id bigint       not null
)
    go

create index IDX_FOSFC_TENANT_KEY
    on form_option_sub_filter_config (tenant_key)
    go

create index IDX_FOSFC_FORM_ID
    on form_option_sub_filter_config (form_id)
    go

create index IDX_FOSFC_MAIN_FIELD
    on form_option_sub_filter_config (main_field)
    go

create index IDX_FOSFC_SUB_FIELD
    on form_option_sub_filter_config (sub_field)
    go

create unique index IDX_FOSFC_MF_SF_MOI
    on form_option_sub_filter_config (main_field, sub_field, main_option_id)
    go

create table form_option_template_config
(
    id              bigint       not null
        primary key,
    create_time     datetime     not null,
    update_time     datetime,
    creator         bigint       not null,
    delete_type     int          not null,
    tenant_key      nvarchar(10) not null,
    form_id         bigint       not null,
    field_id        bigint       not null,
    template_id     bigint       not null,
    inherited_type  nvarchar(10) not null,
    drop_down_level nchar        not null,
    parent_field    bigint
)
    go

create index IDX_FOTC_FIELD_ID
    on form_option_template_config (field_id)
    go

create index IDX_FOTC_FORM_ID
    on form_option_template_config (form_id)
    go

create index IDX_FOTC_TENANT_KEY
    on form_option_template_config (tenant_key)
    go

create table form_setting_logs
(
    id              bigint not null
        primary key,
    create_time     datetime default getdate(),
    update_time     datetime default getdate(),
    creator         bigint,
    delete_type     int      default 0,
    tenant_key      nvarchar(10),
    uuid            nvarchar(36),
    log_date        datetime default getdate(),
    device          nvarchar(500),
    log_operator    bigint,
    operatorname    nvarchar(100),
    targetid        bigint,
    targetname      nvarchar(3000),
    modulename      nvarchar(100),
    functionname    nvarchar(100),
    interfacename   nvarchar(100),
    requesturl      ntext,
    requesturi      ntext,
    operatetype     nvarchar(50),
    operatetypename nvarchar(100),
    operatedesc     nvarchar(3000),
    params          ntext,
    belongmainid    nvarchar(36),
    clientip        nvarchar(200),
    groupid         nvarchar(50),
    groupnamelabel  nvarchar(1000),
    redoservice     nvarchar(200),
    redocontext     ntext,
    cancelservice   nvarchar(200),
    cancelcontext   ntext,
    totalruntime    bigint,
    mainruntime     bigint,
    log_result      nvarchar(100),
    fromterminal    nvarchar(100),
    resultdesc      ntext,
    old_content     ntext,
    link_type       nvarchar(20),
    link_id         bigint,
    old_link_id     bigint
)
    go

create index IDX_FORM_SETTING_LOGS_TK
    on form_setting_logs (tenant_key)
    go

create index IDX_FORM_SETTING_LOGS_LD
    on form_setting_logs (log_date)
    go

create index IDX_FORM_SETTING_LOGS_TI
    on form_setting_logs (targetid)
    go

create index IDX_FORM_SETTING_LOGS_MN
    on form_setting_logs (modulename)
    go

create index IDX_FORM_SETTING_LOGS_FN
    on form_setting_logs (functionname)
    go

create index IDX_FORM_SETTING_LOGS_U
    on form_setting_logs (uuid)
    go

create table form_setting_logs_detail
(
    id               bigint not null
        primary key,
    create_time      datetime default getdate(),
    update_time      datetime default getdate(),
    creator          bigint,
    delete_type      int      default 0,
    tenant_key       nvarchar(10),
    uuid             nvarchar(36),
    mainid           nvarchar(36),
    dataid           nvarchar(50),
    belongdataid     nvarchar(50),
    tablename        nvarchar(200),
    tablenamelabelid nvarchar(50),
    tablenamedesc    nvarchar(50),
    fieldname        nvarchar(200),
    fieldnamelabelid nvarchar(50),
    newvalue         ntext,
    oldvalue         ntext,
    newrealvalue     ntext,
    oldrealvalue     ntext,
    fielddesc        nvarchar(200),
    showorder        int,
    isdetail         int      default 0
)
    go

create index IDX_F_SETTING_LOGS_DETAIL_TK
    on form_setting_logs_detail (tenant_key)
    go

create index IDX_F_SETTING_LOGS_DETAIL_MI
    on form_setting_logs_detail (mainid)
    go

create table form_style
(
    ID                 decimal(20) not null
        primary key,
    FORM_ID            decimal(20) not null,
    LAYOUT_ID          decimal(20) not null,
    STYLE_DETAIL       nvarchar(max),
    STYLE_CONFIG       nvarchar(max),
    UPDATE_TIME        datetime2(0)
        constraint form_style_df_UPDATE_TIME default getdate(),
    TENANT_KEY         nvarchar(10),
    STYLE_FIELD_CONFIG nvarchar(max),
    style_config_temp  nvarchar(max),
    serial_no          bigint
)
    go

create index IDX_FORM_STYLE_LAYOUT_ID
    on form_style (LAYOUT_ID)
    go

create index IDX_FORM_STYLE_FORM_ID
    on form_style (FORM_ID)
    go

create table form_table
(
    ID          decimal(20)  not null
        primary key,
    FORM_ID     decimal(20)  not null,
    TABLE_NAME  nvarchar(64) not null,
    TENANT_KEY  nvarchar(20) not null,
    CREATE_TIME datetime,
    UPDATE_TIME datetime,
    OPERATOR    nvarchar(64) not null
)
    go

exec sp_addextendedproperty 'MS_Description', '表名称', 'SCHEMA', 'dbo', 'TABLE', 'form_table', 'COLUMN', 'TABLE_NAME'
go

create index IDX_FORM_TABLE_FORM_ID
    on form_table (FORM_ID)
    go

create index IDX_FORM_TABLE_NAME
    on form_table (TABLE_NAME)
    go

create table form_table_data_redundancy
(
    ID            decimal(20)                                           not null
        primary key,
    FORM_TABLE_ID decimal(20)                                           not null,
    FIELD_ID      decimal(20)                                           not null,
    CONTENT       nvarchar(max)                                         not null,
    CREATE_TIME   datetime,
    UPDATE_TIME   datetime,
    OPERATOR      nvarchar(64),
    TENANT_KEY    nvarchar(20)                                          not null,
    TYPE          nvarchar(50)
        constraint form_table_data_redundancy_df_TYPE default 'content' not null,
    TARGET_ID     ntext,
    CONTENT_TYPE  ntext
)
    go

exec sp_addextendedproperty 'MS_Description', '数据ID', 'SCHEMA', 'dbo', 'TABLE', 'form_table_data_redundancy', 'COLUMN',
     'FORM_TABLE_ID'
go

exec sp_addextendedproperty 'MS_Description', '列ID', 'SCHEMA', 'dbo', 'TABLE', 'form_table_data_redundancy', 'COLUMN',
     'FIELD_ID'
go

exec sp_addextendedproperty 'MS_Description', '冗余内容', 'SCHEMA', 'dbo', 'TABLE', 'form_table_data_redundancy', 'COLUMN',
     'CONTENT'
go

create index IDX_FTDR_TYPE
    on form_table_data_redundancy (TYPE)
    go

create index IDX_FTDR_FT_FI_T
    on form_table_data_redundancy (FORM_TABLE_ID, FIELD_ID, TYPE)
    go

create index IDX_FTDR_CREATE_TIME
    on form_table_data_redundancy (CREATE_TIME)
    go

create index IDX_FTDR_FIELD_ID
    on form_table_data_redundancy (FIELD_ID)
    go

create table form_table_data_rel
(
    ID            decimal(20)                                 not null
        primary key,
    FORM_TABLE_ID decimal(20)                                 not null,
    PARENT_ID     decimal(20)                                 not null,
    TENANT_KEY    nvarchar(20)                                not null,
    IS_DELETE     tinyint
        constraint form_table_data_rel_df_IS_DELETE default 0 not null
)
    go

exec sp_addextendedproperty 'MS_Description', '数据ID', 'SCHEMA', 'dbo', 'TABLE', 'form_table_data_rel', 'COLUMN',
     'FORM_TABLE_ID'
go

exec sp_addextendedproperty 'MS_Description', '父数据ID', 'SCHEMA', 'dbo', 'TABLE', 'form_table_data_rel', 'COLUMN',
     'PARENT_ID'
go

exec sp_addextendedproperty 'MS_Description', '0:未删除1：已删除', 'SCHEMA', 'dbo', 'TABLE', 'form_table_data_rel', 'COLUMN',
     'IS_DELETE'
go

create index IDX_FORM_TABLE_DATA_REL_FTI
    on form_table_data_rel (FORM_TABLE_ID)
    go

create index IDX_FORM_TABLE_DATA_REL_PI
    on form_table_data_rel (PARENT_ID)
    go

create index IDX_FTDR_FTI_PI_ID
    on form_table_data_rel (FORM_TABLE_ID, PARENT_ID, IS_DELETE)
    go

create table form_table_field
(
    ID          decimal(20)                                   not null
        primary key,
    FIELD_ID    decimal(20)                                   not null,
    IS_INDEX    nvarchar(10)
        constraint form_table_field_df_IS_INDEX default '0'   not null,
    COLUMN_NAME nvarchar(64)                                  not null,
    TENANT_KEY  nvarchar(20)                                  not null,
    TYPE_LEN    smallint                                      not null,
    COLUMN_TYPE nvarchar(20)
        constraint form_table_field_df_COLUMN_TYPE default '' not null,
    DYNAMIC     nvarchar(20)
)
    go

exec sp_addextendedproperty 'MS_Description', '列是否已有索引 索引类型', 'SCHEMA', 'dbo', 'TABLE', 'form_table_field', 'COLUMN',
     'IS_INDEX'
go

exec sp_addextendedproperty 'MS_Description', '用户定义的列名，用户未定义则填充默认列名', 'SCHEMA', 'dbo', 'TABLE', 'form_table_field',
     'COLUMN', 'COLUMN_NAME'
go

exec sp_addextendedproperty 'MS_Description', '类型长度', 'SCHEMA', 'dbo', 'TABLE', 'form_table_field', 'COLUMN', 'TYPE_LEN'
go

exec sp_addextendedproperty 'MS_Description', '列类型', 'SCHEMA', 'dbo', 'TABLE', 'form_table_field', 'COLUMN',
     'COLUMN_TYPE'
go

exec sp_addextendedproperty 'MS_Description', '列对应的数据长度（日期类型）', 'SCHEMA', 'dbo', 'TABLE', 'form_table_field', 'COLUMN',
     'DYNAMIC'
go

create unique index UNX_FORM_TABLE_FIELD_FIELD_ID
    on form_table_field (FIELD_ID)
    go

create table form_table_rel
(
    ID          decimal(20)                              not null
        primary key,
    FORM_ID     decimal(20)                              not null,
    SUB_FORM_ID decimal(20)                              not null,
    OPERATOR    nvarchar(64)                             not null,
    TENANT_KEY  nvarchar(20)                             not null,
    CREATE_TIME datetime,
    UPDATE_TIME datetime,
    IS_DELETE   tinyint
        constraint form_table_rel_df_IS_DELETE default 0 not null
)
    go

exec sp_addextendedproperty 'MS_Description', '主表ID', 'SCHEMA', 'dbo', 'TABLE', 'form_table_rel', 'COLUMN', 'FORM_ID'
go

exec sp_addextendedproperty 'MS_Description', '子表ID', 'SCHEMA', 'dbo', 'TABLE', 'form_table_rel', 'COLUMN',
     'SUB_FORM_ID'
go

exec sp_addextendedproperty 'MS_Description', '是否删除  0：未删除 1：已删除', 'SCHEMA', 'dbo', 'TABLE', 'form_table_rel', 'COLUMN',
     'IS_DELETE'
go

create index IDX_FORM_TABLE_REL_FORM_ID
    on form_table_rel (FORM_ID)
    go

create index IDX_FORM_TABLE_REL_SUB_FORM_ID
    on form_table_rel (SUB_FORM_ID)
    go

create table form_view_relate_config
(
    id                 bigint not null
        primary key,
    create_time        datetime,
    update_time        datetime,
    operator           bigint,
    delete_type        int,
    tenant_key         nvarchar(10),
    field_id           decimal(38),
    display            nvarchar,
    readonly           nvarchar,
    required           nvarchar,
    display_condition  nvarchar(max),
    readonly_condition nvarchar(max),
    required_condition nvarchar(max),
    version_id         decimal(38),
    is_delete          int,
    disable_edit       nvarchar,
    single_row         nvarchar,
    show_order         float
        constraint show_order_defalut default 0
)
    go

create index IDX_FVRC_FIELD_ID
    on form_view_relate_config (field_id)
    go

create index IDX_FVRC_VERSION_ID
    on form_view_relate_config (tenant_key)
    go

create index IDX_FVRC_TENANT_KEY
    on form_view_relate_config (version_id)
    go

create table formdata
(
    ID          decimal(38) not null
        primary key,
    FORM_ID     decimal(38),
    LAYOUT_ID   decimal(38),
    DATA_STATUS nvarchar(50),
    TENANT_KEY  nvarchar(10),
    OPERATOR    decimal(38),
    CREATE_TIME datetime,
    UPDATE_TIME datetime,
    MODULE      nvarchar(50),
    CLIENT      nvarchar(50),
    VERSION     nvarchar(50),
    SPENT_TIME  decimal(38),
    IP          nvarchar(50),
    name        nvarchar(800),
    IS_DELETE   tinyint default 0
)
    go

create index IDX_FORMDATA_TENANT_KEY
    on formdata (TENANT_KEY)
    go

create index IDX_FORMDATA_FORMID
    on formdata (FORM_ID)
    go

create index IDX_FORMDATA_LAYOUTID
    on formdata (LAYOUT_ID)
    go

create index IDX_FORMDATA_OPERATOR
    on formdata (OPERATOR)
    go

create index IDX_FORMDATA_MODULE
    on formdata (MODULE)
    go

create index IDX_FORMDATA_DATASTATUS
    on formdata (DATA_STATUS)
    go

create index IDX_FORMDATA_IS_DELETE
    on formdata (IS_DELETE)
    go

create table formdata_detail
(
    ID            decimal(38) not null
        primary key,
    FORM_DATA     decimal(38),
    FIELD_ID      decimal(38),
    SUB_FORM_ID   decimal(38),
    LAYOUT_ID     decimal(38),
    DATA_INDEX    decimal(38),
    CONTENT       nvarchar(500),
    TENANT_KEY    nvarchar(10),
    OPERATOR      decimal(38),
    CREATE_TIME   datetime,
    TYPE          nvarchar(50),
    STAT_DESCRIBE nvarchar(50),
    LONGITUDE     decimal(16, 13),
    LATITUDE      decimal(16, 13)
)
    go

create index IDX_FORMDATA_DETAIL_TENANT_KEY
    on formdata_detail (TENANT_KEY)
    go

create index IDX_FORMDATA_DETAIL_FORMDATA
    on formdata_detail (FORM_DATA)
    go

create index IDX_FORMDATA_DETAIL_FIELDID
    on formdata_detail (FIELD_ID)
    go

create index IDX_FORMDATA_DETAIL_SUB_FORM_I
    on formdata_detail (SUB_FORM_ID)
    go

create index IDX_FORMDATA_DETAIL_CONTENT
    on formdata_detail (CONTENT)
    go

create table formdata_log
(
    ID                decimal(20) not null
        primary key,
    FORM_DATA         decimal(20),
    CONTENT           nvarchar(max),
    NEW_CONTENT       nvarchar(max),
    FIELD_NAME        nvarchar(100),
    FIELD_ID          decimal(20),
    SUB_FORM_ID       decimal(20),
    DATA_INDEX        decimal(5),
    COMPONENT_KEY     nvarchar(50),
    CLIENT            nvarchar(50),
    VERSION           nvarchar(50),
    TENANT_KEY        nvarchar(10),
    OPERATOR          decimal(20),
    CREATE_TIME       datetime,
    SOURCE_ID         decimal(20),
    SOURCE_NAME       nvarchar(500),
    SOURCE_MODULE     nvarchar(20),
    EXTERNAL_OPERATOR decimal(20),
    SOURCES           nvarchar(max),
    LAYOUT_ID         decimal(20),
    record_id         bigint
)
    go

exec sp_addextendedproperty 'MS_Description', '所属布局版本Id', 'SCHEMA', 'dbo', 'TABLE', 'formdata_log', 'COLUMN',
     'LAYOUT_ID'
go

create index IDX_FORMDATA_LOG_FORM_DATA
    on formdata_log (FORM_DATA)
    go

create index IDX_FORMDATA_LOG_FIELD_ID
    on formdata_log (FIELD_ID)
    go

create index IDX_FORMDATA_LOG_SUB_FORM_ID
    on formdata_log (SUB_FORM_ID)
    go

create index IDX_FORMDATA_LOG_SOURCE_ID
    on formdata_log (SOURCE_ID)
    go

create index IDX_FORMDATA_LOG_LAYOUT_ID
    on formdata_log (LAYOUT_ID)
    go

create index IDX_FORMDATA_LOG_RECORD_ID
    on formdata_log (record_id)
    go

create table formdata_option
(
    ID           decimal(38) not null
        primary key,
    DATA_DETAILS decimal(38),
    OPTION_ID    nvarchar(200),
    CONTENT      nvarchar(200),
    TENANT_KEY   nvarchar(10),
    TYPE         nvarchar(20),
    target_id    decimal(38)
)
    go

create index IDX_FORMDATA_OPTION_TENANT_KEY
    on formdata_option (TENANT_KEY)
    go

create index IDX_FORMDATA_OPTION_DATADETAIL
    on formdata_option (DATA_DETAILS)
    go

create index IDX_FORMDATA_OPTION_OPTION_ID
    on formdata_option (OPTION_ID)
    go

create table formdata_record_log
(
    id             bigint not null
        primary key,
    create_time    datetime,
    tenant_key     nvarchar(10),
    form_data_id   bigint,
    device         nvarchar(500),
    operator_id    bigint,
    module_source  nvarchar(100),
    operation_type nvarchar(100),
    ref_id         nvarchar(100),
    terminal       nvarchar(50)
)
    go

create index IDX_FORMDATA_RECORD_LOG_TK
    on formdata_record_log (tenant_key)
    go

create index IDX_FORMDATA_RECORD_LOG_FDI_RI
    on formdata_record_log (form_data_id, ref_id)
    go

create table formdata_serial
(
    ID           decimal(20) not null
        primary key,
    FORM_DATA    decimal(20) not null,
    FIELD_ID     decimal(20) not null,
    CONTENT      nvarchar(1000),
    CREATE_TIME  datetime2(0)
        constraint formdata_serial_df_CREATE_TIME default getdate(),
    TENANT_KEY   nvarchar(10),
    OPTION_ID    decimal(20),
    DATE_CONTENT nvarchar(1000),
    serial_no    bigint
)
    go

exec sp_addextendedproperty 'MS_Description', '表单数据', 'SCHEMA', 'dbo', 'TABLE', 'formdata_serial', 'COLUMN', 'FORM_DATA'
go

exec sp_addextendedproperty 'MS_Description', '表单字段', 'SCHEMA', 'dbo', 'TABLE', 'formdata_serial', 'COLUMN', 'FIELD_ID'
go

exec sp_addextendedproperty 'MS_Description', '序列号', 'SCHEMA', 'dbo', 'TABLE', 'formdata_serial', 'COLUMN', 'CONTENT'
go

exec sp_addextendedproperty 'MS_Description', '选项控件选项ID', 'SCHEMA', 'dbo', 'TABLE', 'formdata_serial', 'COLUMN',
     'OPTION_ID'
go

exec sp_addextendedproperty 'MS_Description', '日期控件内容', 'SCHEMA', 'dbo', 'TABLE', 'formdata_serial', 'COLUMN',
     'DATE_CONTENT'
go

create index IDX_FORMDATA_SERIAL_FORM_DATA
    on formdata_serial (FORM_DATA)
    go

create index IDX_FORMDATA_SERIAL_FIELD_ID
    on formdata_serial (FIELD_ID)
    go

create index IDX_FORMDATA_SERIAL_CREATETIME
    on formdata_serial (CREATE_TIME)
    go

create index IDX_FORMDATA_SERIAL_OPTION_ID
    on formdata_serial (OPTION_ID)
    go

create index IDX_FORMDATA_SERIAL_FI_CT
    on formdata_serial (FIELD_ID, CREATE_TIME)
    go

create table formdata_sharding_key
(
    ID         decimal(20)  not null
        primary key,
    TENANT_KEY nvarchar(50) not null
)
    go

create table formdata_sharding_sql
(
    ID          decimal(20) not null
        primary key,
    CONTENT     nvarchar(max),
    TENANT_KEY nvarchar(10) default 'all_teams',
    CREATE_TIME datetime2(0)
        constraint formdata_sharding_sql_df_CREATE_TIME default getdate()
)
    go

create table formdata_text
(
    ID           decimal(38) not null
        primary key,
    DATA_DETAILS decimal(38),
    CONTENT      nvarchar(max),
    TENANT_KEY   nvarchar(10),
    RICH_CONTENT nvarchar(max)
)
    go

create index IDX_FORMDATA_TEXT_TENANT_KEY
    on formdata_text (TENANT_KEY)
    go

create index IDX_FORMDATA_TEXT_DATADETAILS
    on formdata_text (DATA_DETAILS)
    go

create table panel_field
(
    ID                  decimal(20) not null
        primary key,
    FORM_ID             decimal(20),
    COMPONENT_KEY       nvarchar(50),
    IS_DELETE           nchar,
    TENANT_KEY          nvarchar(10),
    TITLE               nvarchar(100),
    DESCRIBE            nvarchar(2000),
    show_order          float default 0,
    other_properties    nvarchar(max),
    layout_component_id varchar(32)
)
    go

create index IDX_PANEL_FIELD_FORM_ID
    on panel_field (FORM_ID)
    go

create table sub_form
(
    ID                  decimal(20) not null
        primary key,
    FORM_ID             decimal(20),
    IS_DELETE           nchar,
    TENANT_KEY          nvarchar(10),
    TMP_SUB_TABLE       nvarchar(50),
    TITLE               nvarchar(100),
    DESCRIBE            nvarchar(2000),
    DEFAULT_ROWS        decimal(5),
    data_table          nvarchar(100),
    data_key            varchar(32),
    show_order          float default 0,
    other_properties    nvarchar(max),
    layout_component_id varchar(32),
    create_time         datetime,
    update_time         datetime
)
    go

create index IDX_SUB_FORM_FORM_ID
    on sub_form (FORM_ID)
    go

create table sub_form_config
(
    id               bigint not null
        primary key,
    create_time      datetime,
    update_time      datetime,
    delete_type      int default 0,
    tenant_key       nvarchar(10),
    sub_form_id      bigint,
    default_rows     int,
    max_rows         int,
    required_rows    int,
    filter_condition nvarchar(max),
    other_properties nvarchar(max),
    version_id       bigint,
    creator          bigint
)
    go

create index IDX_SUB_FORM_CONFIG_TENANT_KEY
    on sub_form_config (tenant_key)
    go

create index IDX_SUB_FORM_CONFIG_SUB_FORM_I
    on sub_form_config (sub_form_id)
    go

create index IDX_SUB_FORM_CONFIG_VERSION_ID
    on sub_form_config (version_id)
    go